@@ -19,6 +19,10 @@ int main( int /*argc*/, char ** argv)
   // Initialize ImageMagick install location for Windows
   MagickIncarnate(*argv);
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
   try {
 
     //
@@ -43,7 +47,7 @@ int main( int /*argc*/, char ** argv)
     string textColor = "red";
 
     // Font to use for text
-    string textFont = "@Generic.ttf";
+    string textFont = string("@") + srcdir + "Generic.ttf";
 
     // Font point size
     int textFontPointSize = 16;
