@@ -1,6 +1,6 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999
+// Copyright Bob Friesenhahn, 1999, 2000
 //
 // Simple demo program for Magick++
 //
@@ -24,6 +24,13 @@ int main( int /*argc*/, char ** argv)
   // Initialize ImageMagick install location for Windows
   MagickIncarnate(*argv);
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
+  // Common font to use.
+  string font = string("@") + srcdir + "Generic.ttf";
+
   try {
 
     //
@@ -34,12 +41,12 @@ int main( int /*argc*/, char ** argv)
     null.size( "70x70" );
     null.read( "null:black" );
 
-    Image model( "model.miff" );
+    Image model( srcdir + "model.miff" );
     model.label( "Magick++" );
     model.borderColor( "black" );
     model.backgroundColor( "black" );
 
-    Image smile( "smile.miff" );
+    Image smile( srcdir + "smile.miff" );
     smile.label( "Smile" );
     smile.borderColor( "black" );
 
@@ -61,15 +68,18 @@ int main( int /*argc*/, char ** argv)
 
     cout << "  annotate ..." << endl;
     example.label( "Annotate" );
-    example.font( "@Generic.ttf" );
+    example.density( "72x72" );
+    example.fontPointsize( 18 );
+    example.font( font );
     example.strokeColor( "gold" );
-    example.annotate( "Magick++", "+0+10", NorthGravity );
+    example.fillColor( "gold" );
+    example.annotate( "Magick++", "+0+20", NorthGravity );
     images.push_back( example );
 
     cout << "  blur ..." << endl;
     example = model;
     example.label( "Blur" );
-    example.blur( 3 );
+    example.blur( 0, 1.5 );
     images.push_back( example );
 
     cout << "  gaussian blur ..." << endl;
@@ -159,12 +169,12 @@ int main( int /*argc*/, char ** argv)
     example.gamma( 1.6 );
     images.push_back( example );
 
-    cout << "  gradation ..." << endl;
-    Image gradation;
-    gradation.size( "130x194" );
-    gradation.read( "gradation:#20a0ff-#ffff00" );
-    gradation.label( "Gradation" );
-    images.push_back( gradation );
+    cout << "  gradient ..." << endl;
+    Image gradient;
+    gradient.size( "130x194" );
+    gradient.read( "gradient:#20a0ff-#ffff00" );
+    gradient.label( "Gradient" );
+    images.push_back( gradient );
 
     cout << "  grayscale ..." << endl;
     example = model;
@@ -182,7 +192,7 @@ int main( int /*argc*/, char ** argv)
     cout << "  modulate ..." << endl;
     example = model;
     example.label( "Modulate" );
-    example.modulate( -3, -3, -3 );
+    example.modulate( 110, 110, 110 );
     images.push_back( example );
 
     cout << "  monochrome ..." << endl;
@@ -306,7 +316,7 @@ int main( int /*argc*/, char ** argv)
     title.read( "xc:black" );
 
     title.density( "72x72" );
-    title.font( "@Generic.ttf" );
+    title.font( font );
     title.fontPointsize( 80 );
     title.strokeColor( "white" );
     title.fillColor( "white" );
@@ -324,7 +334,7 @@ int main( int /*argc*/, char ** argv)
     list<Image> montage;
 
     Image& imageRef = images.front();
-    imageRef.font( "@Generic.ttf" );
+    imageRef.font( font );
     imageRef.strokeColor( "#600" );
 
     MontageFramed montageOpts;
@@ -332,7 +342,7 @@ int main( int /*argc*/, char ** argv)
     montageOpts.borderWidth( 1 );
     montageOpts.compose( OverCompositeOp );
     montageOpts.fileName( "Magick++" );
-    montageOpts.font( "@Generic.ttf" );
+    montageOpts.font( font );
     montageOpts.geometry( "130x194+10+5>" );
     montageOpts.gravity( CenterGravity );
     montageOpts.pointSize( 18 );
@@ -345,7 +355,7 @@ int main( int /*argc*/, char ** argv)
     Image& final = montage.front();
     final.composite( title, "+90+50", OverCompositeOp );
 
-    final.font( "@Generic.ttf" );
+    final.font( font );
     final.fontPointsize( 18 );
     final.strokeColor( "#600" );
     final.annotate( "Every thing you see on this page was created with the "\
