@@ -22,6 +22,13 @@ int main( int /*argc*/, char ** argv)
   // Initialize ImageMagick install location for Windows
   MagickIncarnate(*argv);
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
+  // Common font to use.
+  string font = string("@") + srcdir + "Generic.ttf";
+
   try {
 
     //
@@ -40,7 +47,7 @@ int main( int /*argc*/, char ** argv)
     poly_coord.push_back( Coordinate(190,290) );
     poly_coord.push_back( Coordinate(30,290) );
 
-    Image texture( "tile.miff" );
+    Image texture( srcdir + "tile.miff" );
     image.penTexture( texture );
     image.draw( DrawablePolygon( poly_coord ) );
     texture.isValid( false );
@@ -52,7 +59,7 @@ int main( int /*argc*/, char ** argv)
     image.strokeColor( "black" );
     image.fillColor( "red" );
     image.lineWidth( 5 );
-    image.draw( DrawableEllipse( 100,100, 100,150, 0,360 ) );
+    image.draw( DrawableEllipse( 100,100, 50,75, 0,360 ) );
     image.fillColor( Color() ); // Clear out fill color
 
     //
@@ -62,9 +69,6 @@ int main( int /*argc*/, char ** argv)
     image.lineWidth( 5 );
     list<Drawable> drawlist;
 
-    // Add ellipse to list
-    drawlist.push_back( DrawableEllipse( 100,100, 100,150, 0,360 ) );
-
     // Add polygon to list
     poly_coord.clear();
     poly_coord.push_back( Coordinate(30,30) );
@@ -84,19 +88,22 @@ int main( int /*argc*/, char ** argv)
     // Draw text
     //
     image.fillColor( "red" );
-    image.font( "@Generic.ttf" );
+    image.strokeColor( "red" );
+    image.font( font );
     image.fontPointsize( 18 );
-    image.annotate( "Hello world!", "+150+10" );
+    image.annotate( "Hello world!", "+150+20" );
 
     image.fillColor( "blue" );
-    image.font( "@Generic.ttf" );
+    image.strokeColor( "blue" );
+    image.font( font );
     image.fontPointsize( 14 );
-    image.annotate( "Goodbye cruel world!", "+150+28" );
+    image.annotate( "Goodbye cruel world!", "+150+38" );
 
     image.fillColor( "black" );
-    image.font( "@Generic.ttf" );
+    image.strokeColor( "black" );
+    image.font( font );
     image.fontPointsize( 14 );
-    image.annotate( "I'm climbing the wall!", "+280+150",
+    image.annotate( "I'm climbing the wall!", "+280+120",
                     NorthWestGravity, 90.0);
     //image.display();
     //
