@@ -1,6 +1,6 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999
+// Copyright Bob Friesenhahn, 1999, 2000
 //
 // Geometry implementation
 //
@@ -12,6 +12,8 @@
 #include <iomanip>
 #include <strstream>
 
+#include <ctype.h> // for isdigit
+
 using namespace std;
 
 #include "Magick++/Geometry.h"
@@ -191,7 +193,7 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
   strcpy(geom,geometry_.c_str());
   if ( geom[0] != '-' &&
        geom[0] != '+' &&
-       !isdigit((int)geom[0]) )
+       !isdigit(static_cast<int>(geom[0])))
     {
       char *pageptr = PostscriptGeometry( geom );
       if ( pageptr )
