@@ -9,6 +9,7 @@
 
 #include <string>
 #include <iostream>
+#include <strstream>
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
@@ -20,6 +21,10 @@ using namespace std;
 #include "Magick++/Pixels.h"
 #include "Magick++/Include.h"
 
+const std::string Magick::borderGeometryDefault = "6x6+0+0";
+const std::string Magick::frameGeometryDefault  = "25x25+6+6";
+const std::string Magick::raiseGeometryDefault  = "6x6+0+0";
+
 //
 // Friend functions to compare Image objects
 //
@@ -132,6 +137,18 @@ Magick::Image::Image ( const Blob &blob_,
   read( blob_, size_, magick_ );
 }
 
+// Construct an image based on an array of raw pixels, of specified
+// type and mapping, in memory
+Magick::Image::Image ( const unsigned int width_,
+                       const unsigned int height_,
+                       const std::string &map_,
+                       const StorageType type_,
+                       const void *pixels_ )
+  : _imgRef(new ImageRef)
+{
+  read( width_, height_, map_.c_str(), type_, pixels_ );
+}
+
 // Default constructor
 Magick::Image::Image( void )
   : _imgRef(new ImageRef)
@@ -152,7 +169,7 @@ Magick::Image::~Image()
   if ( doDelete )
     {
       delete _imgRef;
-      _imgRef = (ImageRef*)NULL;
+      _imgRef = 0;
     }
 }
 
@@ -174,14 +191,14 @@ void Magick::Image::addNoise( NoiseType noiseType_ )
 void Magick::Image::annotate ( const std::string &text_,
 			       const Geometry &location_ )
 {
-  annotate ( text_, location_,  NorthWestGravity, (double)0 );
+  annotate ( text_, location_,  NorthWestGravity, 0 );
 }
 // Text, location, & gravity
 void Magick::Image::annotate ( const std::string &text_,
 			       const Geometry &location_,
 			       GravityType gravity_ )
 {
-  annotate ( text_, location_, gravity_, (double)0 );
+  annotate ( text_, location_, gravity_, 0 );
 }
 // Text, location, degrees, gravity
 void Magick::Image::annotate ( const std::string &text_,
@@ -239,12 +256,12 @@ void Magick::Image::annotate ( const std::string &text_,
 }
 
 // Blur image
-void Magick::Image::blur( unsigned int order_ )
+void Magick::Image::blur( const double radius_, const double sigma_ )
 {
   ExceptionInfo exceptionInfo;
   GetExceptionInfo( &exceptionInfo );
   MagickLib::Image* newImage =
-    BlurImage( image(), order_, &exceptionInfo);
+    BlurImage( image(), radius_, sigma_, &exceptionInfo);
   replaceImage( newImage );
   throwException( exceptionInfo );
 }
@@ -265,15 +282,14 @@ void Magick::Image::border( const Geometry &geometry_ )
   throwException( exceptionInfo );
 }
 
-
 // Charcoal-effect image
-void Magick::Image::charcoal( unsigned int order_ )
+void Magick::Image::charcoal( const double radius_, const double sigma_ )
 {
   quantizeDither( true );
   quantizeColorSpace( GRAYColorspace );
   quantize( );
-  edge( order_ );
-  blur( order_ );
+  edge( radius_ );
+  blur( radius_, sigma_ );
   normalize( );
   negate( true );
 }
@@ -300,29 +316,37 @@ void Magick::Image::chop( const Geometry &geometry_ )
 }
 
 // Colorize
-void Magick::Image::colorize ( const Color &opaqueColor_,
+void Magick::Image::colorize ( const unsigned int opacityRed_,
+                               const unsigned int opacityGreen_,
+                               const unsigned int opacityBlue_,
 			       const Color &penColor_ )
 {
-  if ( !opaqueColor_.isValid() )
-    {
-      throwException( OptionError,
-		      "Opaque color argument is invalid");
-    }
-
   if ( !penColor_.isValid() )
-    {
-      throwException( OptionError,
-		      "Pen color argument is invalid");
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Pen color argument is invalid");
+  }
+
+  char opacity[MaxTextExtent + 1];
+  ostrstream buffstr( opacity, sizeof(opacity));
+  buffstr << opacityRed_ << "/"
+          << opacityGreen_ << "/"
+          << opacityBlue_
+          << ends;
 
   ExceptionInfo exceptionInfo;
   GetExceptionInfo( &exceptionInfo );
   MagickLib::Image* newImage =
-    ColorizeImage ( image(), std::string(opaqueColor_).c_str(),
-		    penColor_, &exceptionInfo );
+  ColorizeImage ( image(), opacity,
+		  penColor_, &exceptionInfo );
   replaceImage( newImage );
   throwException( exceptionInfo );
 }
+void Magick::Image::colorize ( const unsigned int opacity_,
+			       const Color &penColor_ )
+{
+  colorize( opacity_, opacity_, opacity_, penColor_ );
+}
 
 // Composite two images
 void Magick::Image::composite ( const Image &compositeImage_,
@@ -341,7 +365,7 @@ void Magick::Image::composite ( const Image &compositeImage_,
 
   Geometry offset( 0, 0, xOffset_, yOffset_ );
 
-  ParseImageGeometry (((std::string)offset).c_str(),
+  ParseImageGeometry ((static_cast<std::string>(offset)).c_str(),
 		      &x, &y,
 		      &width, &height );
 
@@ -362,7 +386,7 @@ void Magick::Image::composite ( const Image &compositeImage_,
   unsigned int width = columns();
   unsigned int height = rows();
 
-  ParseImageGeometry (((std::string)offset_).c_str(),
+  ParseImageGeometry (static_cast<std::string>(offset_).c_str(),
 		      &x, &y,
 		      &width, &height );
 
@@ -506,16 +530,19 @@ void Magick::Image::display( void )
 }
 
 // Draw on image using single drawable
-void Magick::Image::draw ( const Drawable &drawable_ )
+void Magick::Image::draw ( const Magick::Drawable &drawable_ )
 {
   modifyImage();
 
   DrawInfo *drawInfo
     = options()->drawInfo();
 
-  drawInfo->primitive = const_cast<char*>(drawable_.primitive().c_str());
-  //cout << "Primitive:" << drawInfo->primitive << endl;
+  ostrstream primitive;
+  primitive << drawable_ << ends;
+  drawInfo->primitive = primitive.str();
+
   DrawImage( image(), drawInfo );
+
   drawInfo->primitive = 0;
 
   throwImageException();
@@ -524,22 +551,33 @@ void Magick::Image::draw ( const Drawable &drawable_ )
 // Draw on image using a drawable list
 void Magick::Image::draw ( const std::list<Magick::Drawable> &drawable_ )
 {
+  modifyImage();
+
+  DrawInfo *drawInfo
+    = options()->drawInfo();
+
+  ostrstream primitive;
+  bool firstPrimitive = true;
+
   std::list<Magick::Drawable>::const_iterator p = drawable_.begin();
-  std::string primitives;
   while ( p != drawable_.end() )
     {
-      if (primitives.length() != 0 )
-	primitives.append( " " );
-      primitives.append( p->primitive() );
+      if ( !firstPrimitive )
+	primitive << endl;
+      primitive << *p;
+      firstPrimitive = false;
       ++p;
     }
-  Magick::Drawable drawable;
-  drawable.primitive( primitives );
-  draw( drawable );
+
+  drawInfo->primitive = primitive.str();
+  DrawImage( image(), drawInfo );
+  drawInfo->primitive = 0;
+
+  throwImageException();
 }
 
 // Hilight edges in image
-void Magick::Image::edge ( unsigned int factor_ )
+void Magick::Image::edge ( double factor_ )
 {
   ExceptionInfo exceptionInfo;
   GetExceptionInfo( &exceptionInfo );
@@ -550,12 +588,12 @@ void Magick::Image::edge ( unsigned int factor_ )
 }
 
 // Emboss image (hilight edges)
-void Magick::Image::emboss ( unsigned int order_ )
+void Magick::Image::emboss ( const double radius_, const double sigma_ )
 {
   ExceptionInfo exceptionInfo;
   GetExceptionInfo( &exceptionInfo );
   MagickLib::Image* newImage =
-    EmbossImage( image(), order_, &exceptionInfo );
+    EmbossImage( image(), radius_, sigma_, &exceptionInfo );
   replaceImage( newImage );
   throwException( exceptionInfo );
 }
@@ -638,10 +676,10 @@ void Magick::Image::floodFillTexture( unsigned int x_, unsigned int y_,
 
   // Test arguments to ensure they are within the image.
   if ( y_ > rows() || x_ > columns() )
-    {
-      throwException( OptionError,
-		      "Access outside of image boundary" );
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Access outside of image boundary" );
+  }
 
   // Set drawing texture
   options()->penTexture(texture_.constImage());
@@ -657,7 +695,7 @@ void Magick::Image::floodFillTexture( unsigned int x_, unsigned int y_,
                           x_, // const int x_offset
                           y_, // const int y_offset
                           FloodfillMethod // const PaintMethod method
-                          );
+      );
   throwImageException();
 }
 void Magick::Image::floodFillTexture( const Magick::Geometry &point_,
@@ -828,16 +866,16 @@ void Magick::Image::matteFloodfill ( const Color &target_ ,
 				     Magick::PaintMethod method_ )
 {
   if ( !target_.isValid() )
-    {
-      throwException( OptionError,
-		      "Target color argument is invalid" );
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Target color argument is invalid" );
+  }
 
   modifyImage();
 
   PixelPacket rllPacket = target_;
   MatteFloodfillImage ( image(), rllPacket, matte_,
-				   x_, y_, method_ );
+			x_, y_, method_ );
   throwImageException();
 }
 
@@ -911,15 +949,15 @@ void Magick::Image::opaque ( const Color &opaqueColor_,
 			     const Color &penColor_ )
 {
   if ( !opaqueColor_.isValid() )
-    {
-      throwException( OptionError,
-		      "Opaque color argument is invalid" );
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Opaque color argument is invalid" );
+  }
   if ( !penColor_.isValid() )
-    {
-      throwException( OptionError,
-		      "Pen color argument is invalid" );
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Pen color argument is invalid" );
+  }
 
   modifyImage();
   OpaqueImage ( image(), opaqueColor_, penColor_ );
@@ -991,6 +1029,8 @@ void Magick::Image::read ( const std::string &imageSpec_ )
     ReadImage( imageInfo(), &exceptionInfo );
   replaceImage( image );
   throwException( exceptionInfo );
+  if ( image )
+    throwException( image->exception );
 }
 
 // Read image of specified size into current object
@@ -1012,6 +1052,8 @@ void Magick::Image::read ( const Blob &blob_ )
 		 blob_.length(), &exceptionInfo );
   replaceImage( image );
   throwException( exceptionInfo );
+  if ( image )
+    throwException( image->exception );
 }
 
 // Read image of specified size from in-memory BLOB
@@ -1066,6 +1108,23 @@ void Magick::Image::read ( const Blob &blob_,
   read( blob_ );
 }
 
+// Read image based on raw pixels in memory (ConstituteImage)
+void Magick::Image::read ( const unsigned int width_,
+                           const unsigned int height_,
+                           const std::string &map_,
+                           const StorageType type_,
+                           const void *pixels_ )
+{
+  ExceptionInfo exceptionInfo;
+  GetExceptionInfo( &exceptionInfo );
+  MagickLib::Image* image =
+    ConstituteImage( width_, height_, map_.c_str(), type_, pixels_, &exceptionInfo );
+  replaceImage( image );
+  throwException( exceptionInfo );
+  if ( image )
+    throwException( image->exception );
+}
+
 // Reduce noise in image
 void Magick::Image::reduceNoise ( unsigned int order_ )
 {
@@ -1123,7 +1182,7 @@ void Magick::Image::sample ( const Geometry &geometry_ )
   unsigned int width = columns();
   unsigned int height = rows();
 
-  ParseImageGeometry (((std::string)geometry_).c_str(),
+  ParseImageGeometry (static_cast<std::string>(geometry_).c_str(),
 		      &x, &y,
 		      &width, &height );
 
@@ -1143,7 +1202,7 @@ void Magick::Image::scale ( const Geometry &geometry_ )
   unsigned int width = columns();
   unsigned int height = rows();
 
-  ParseImageGeometry (((std::string)geometry_).c_str(),
+  ParseImageGeometry (static_cast<std::string>(geometry_).c_str(),
 		      &x, &y,
 		      &width, &height );
 
@@ -1190,14 +1249,15 @@ void Magick::Image::shade ( double azimuth_,
 }
 
 // Sharpen pixels in image
-void Magick::Image::sharpen ( unsigned int order_ )
+void Magick::Image::sharpen ( const double radius_, const double sigma_ )
 {
   ExceptionInfo exceptionInfo;
   GetExceptionInfo( &exceptionInfo );
   MagickLib::Image* newImage =
     SharpenImage( image(),
-			     order_,
-			     &exceptionInfo );
+                  radius_,
+                  sigma_,
+                  &exceptionInfo );
   replaceImage( newImage );
   throwException( exceptionInfo );
 }
@@ -1297,7 +1357,7 @@ void Magick::Image::threshold ( double threshold_ )
 void Magick::Image::transform ( const Geometry &imageGeometry_ )
 {
   modifyImage();
-  TransformImage ( &(image()), (char *)0,
+  TransformImage ( &(image()), 0,
 		   std::string(imageGeometry_).c_str() );
   throwImageException();
 }
@@ -1315,10 +1375,10 @@ void Magick::Image::transform ( const Geometry &imageGeometry_,
 void Magick::Image::transparent ( const Color &color_ )
 {
   if ( !color_.isValid() )
-    {
-      throwException( OptionError,
-		      "Color argument is invalid" );
-    }
+  {
+    throwExceptionExplicit( OptionError,
+			    "Color argument is invalid" );
+  }
 
   std::string color = color_;
 
@@ -1405,6 +1465,20 @@ void Magick::Image::write ( Blob *blob_,
   throwImageException();
 }
 
+// Write image to an array of pixels with storage type specified
+// by user (DispatchImage), e.g.
+// image.write( 0, 0, 640, 1, "RGB", 0, pixels );
+void Magick::Image::write ( const int x_,
+                            const int y_,
+                            const unsigned int columns_,
+                            const unsigned int rows_,
+                            const std::string &map_,
+                            const StorageType type_,
+                            void *pixels_ )
+{
+  DispatchImage( image(), x_, y_, columns_, rows_, map_.c_str(), type_, pixels_ );
+  throwImageException();
+}
 
 // Zoom image
 void Magick::Image::zoom( const Geometry &geometry_ )
@@ -1416,7 +1490,7 @@ void Magick::Image::zoom( const Geometry &geometry_ )
   unsigned int width = columns();
   unsigned int height = rows();
 
-  ParseImageGeometry (((std::string)geometry_).c_str(),
+  ParseImageGeometry (static_cast<std::string>(geometry_).c_str(),
 		      &x, &y,
 		      &width, &height );
 
@@ -1640,8 +1714,8 @@ void Magick::Image::classType ( Magick::ClassType class_ )
       // color map and then set to DirectClass type.
       modifyImage();
       SyncImage( image() );
-      LiberateMemory( (void**)&(image()->colormap) );
-      image()->c_class = (MagickLib::ClassType)DirectClass;
+      LiberateMemory( reinterpret_cast<void**>(&(image()->colormap)) );
+      image()->c_class = static_cast<MagickLib::ClassType>(DirectClass);
       return;
     }
 
@@ -1651,12 +1725,12 @@ void Magick::Image::classType ( Magick::ClassType class_ )
       modifyImage();
       quantizeColors(MaxRGB + 1);
       quantize();
-      image()->c_class = (MagickLib::ClassType)PseudoClass;
+      image()->c_class = static_cast<MagickLib::ClassType>(PseudoClass);
     }
 }
 Magick::ClassType Magick::Image::classType ( void ) const
 {
-  return (Magick::ClassType)constImage()->c_class;
+  return static_cast<Magick::ClassType>(constImage()->c_class);
 }
 
 void Magick::Image::colorFuzz ( double fuzz_ )
@@ -1675,20 +1749,20 @@ void Magick::Image::colorMap ( unsigned int index_,
 			       const Color &color_ )
 {
   if ( !color_.isValid() )
-    throwException( OptionError,
-		    "Color argument is invalid");
+    throwExceptionExplicit( OptionError,
+			    "Color argument is invalid");
   
   if ( constImage()->c_class != PseudoClass )
-    throwException( OptionError,
-		    "Image class does not support colormap");
+    throwExceptionExplicit( OptionError,
+			    "Image class does not support colormap");
 
   if ( index_ > constImage()->colors )
-    throwException( OptionError,
-		    "Color index is greater than maximum image color index");
+    throwExceptionExplicit( OptionError,
+			    "Color index is greater than maximum image color index");
 
   if ( !constImage()->colormap )
-    throwException( OptionError,
-		    "Image does not contain colormap");
+    throwExceptionExplicit( OptionError,
+			    "Image does not contain colormap");
 
   modifyImage();
 
@@ -1698,16 +1772,16 @@ void Magick::Image::colorMap ( unsigned int index_,
 Magick::Color Magick::Image::colorMap ( unsigned int index_ ) const
 {
   if ( constImage()->c_class != PseudoClass )
-    throwException( OptionError,
-		    "Image class does not support colormap");
+    throwExceptionExplicit( OptionError,
+			    "Image class does not support colormap");
 
   if ( !constImage()->colormap )
-    throwException( CorruptImageError,
-		    "Image does not contain colormap");
+    throwExceptionExplicit( CorruptImageError,
+			    "Image does not contain colormap");
 
   if ( index_ > constImage()->colors )
-    throwException( OptionError,
-		    "Color index is greater than maximum image color index");
+    throwExceptionExplicit( OptionError,
+			    "Color index is greater than maximum image color index");
 
   PixelPacket *color = constImage()->colormap + index_;
   return Magick::Color( color->red, color->green, color->blue );
@@ -1856,8 +1930,8 @@ std::string Magick::Image::directory ( void ) const
   if ( constImage()->directory )
     return std::string( constImage()->directory );
 
-  throwException( CorruptImageWarning,
-		  "Image does not contain a directory");
+  throwExceptionExplicit( CorruptImageWarning,
+			  "Image does not contain a directory");
 
   return std::string();
 }
@@ -1929,14 +2003,14 @@ std::string Magick::Image::format ( void ) const
 {
   //  return options()->format ( );
   const MagickInfo * magick_info
-    = GetMagickInfo( constImage()->magick );
+  = GetMagickInfo( constImage()->magick );
 
-  if (( magick_info != (MagickInfo *)0 ) && 
+  if (( magick_info != 0 ) && 
       ( *magick_info->description != '\0' ))
     return std::string(magick_info->description);
 
-  throwException( CorruptImageWarning,
-		  "Unrecognized image magick type");
+  throwExceptionExplicit( CorruptImageWarning,
+			  "Unrecognized image magick type");
 
   return std::string();
 }
@@ -1949,12 +2023,12 @@ double Magick::Image::gamma ( void ) const
 Magick::Geometry Magick::Image::geometry ( void ) const
 {
   if ( constImage()->geometry )
-    {
-      return Geometry(constImage()->geometry);
-    }
+  {
+    return Geometry(constImage()->geometry);
+  }
 
-  throwException( OptionWarning,
-		  "Image does not contain a geometry");
+  throwExceptionExplicit( OptionWarning,
+			  "Image does not contain a geometry");
 
   return Geometry();
 }
@@ -1978,7 +2052,7 @@ unsigned int Magick::Image::gifDisposeMethod ( void ) const
 void Magick::Image::iccColorProfile( const Magick::Blob &colorProfile_ )
 {
   ProfileInfo * color_profile = &(image()->color_profile);
-  LiberateMemory( (void**)&color_profile->info );
+  LiberateMemory( reinterpret_cast<void**>(&color_profile->info) );
   color_profile->length = 0;
 
   if ( colorProfile_.data() != 0 )
@@ -2011,7 +2085,7 @@ Magick::InterlaceType Magick::Image::interlaceType ( void ) const
 void Magick::Image::iptcProfile( const Magick::Blob &iptcProfile_ )
 {
   ProfileInfo * iptc_profile = &(image()->iptc_profile);
-  LiberateMemory( (void**)&iptc_profile->info );
+  LiberateMemory( reinterpret_cast<void**>(&iptc_profile->info) );
   iptc_profile->length = 0;
 
   if ( iptcProfile_.data() != 0 )
@@ -2170,8 +2244,8 @@ Magick::Geometry Magick::Image::montageGeometry ( void ) const
   if ( constImage()->montage )
     return Magick::Geometry(constImage()->montage);
 
-  throwException( CorruptImageWarning,
-		  "Image does not contain a montage" );
+  throwExceptionExplicit( CorruptImageWarning,
+			  "Image does not contain a montage" );
 
   return Magick::Geometry();
 }
@@ -2219,9 +2293,9 @@ Magick::Image  Magick::Image::penTexture ( void  ) const
       GetExceptionInfo( &exceptionInfo );
       MagickLib::Image* image =
 	CloneImage( const_cast<MagickLib::Image *>(tmpTexture),
-			       tmpTexture->columns,
-			       tmpTexture->rows,
-			       (int)true,
+			       0,
+			       0,
+			       static_cast<int>(true),
 			       &exceptionInfo);
       texture.replaceImage( image );
       throwException( exceptionInfo );
@@ -2233,37 +2307,37 @@ void Magick::Image::pixelColor ( unsigned int x_, unsigned int y_,
 				 const Color &color_ )
 {
   if ( color_.isValid() )
-    {
-      // Test arguments to ensure they are within the image.
-      if ( y_ > rows() || x_ > columns() )
-	throwException( OptionError,
-			"Access outside of image boundary" );
+  {
+    // Test arguments to ensure they are within the image.
+    if ( y_ > rows() || x_ > columns() )
+      throwExceptionExplicit( OptionError,
+			      "Access outside of image boundary" );
       
-      modifyImage();
+    modifyImage();
 
-      // Set image to DirectClass
-      classType( DirectClass );
+    // Set image to DirectClass
+    classType( DirectClass );
 
-      // Get pixel view
-      Pixels pixels(*this);
-      // Set pixel value
-      *(pixels.get(x_, y_, 1, 1 )) = color_;
-      // Tell ImageMagick that pixels have been updated
-      pixels.sync();
+    // Get pixel view
+    Pixels pixels(*this);
+    // Set pixel value
+    *(pixels.get(x_, y_, 1, 1 )) = color_;
+    // Tell ImageMagick that pixels have been updated
+    pixels.sync();
 
-      return;
-    }
+    return;
+  }
 
-  throwException( OptionError,
-		  "Color argument is invalid" );
+  throwExceptionExplicit( OptionError,
+			  "Color argument is invalid" );
 }
 Magick::Color Magick::Image::pixelColor ( unsigned int x_,
 					  unsigned int y_ )
 {
   // Test arguments to ensure they are within the image.
   if ( y_ > rows() || x_ > columns() )
-    throwException( OptionError,
-		    "Access outside of image boundary" );
+    throwExceptionExplicit( OptionError,
+			    "Access outside of image boundary" );
 
   // Get pixel view
   Pixels pixels(*this);
@@ -2343,7 +2417,7 @@ void Magick::Image::renderingIntent ( Magick::RenderingIntent renderingIntent_ )
 }
 Magick::RenderingIntent Magick::Image::renderingIntent ( void ) const
 {
-  return (Magick::RenderingIntent)constImage()->rendering_intent;
+  return static_cast<Magick::RenderingIntent>(constImage()->rendering_intent);
 }
 
 void Magick::Image::resolutionUnits ( Magick::ResolutionType resolutionUnits_ )
@@ -2450,12 +2524,54 @@ std::string Magick::Image::tileName ( void ) const
 
 unsigned long Magick::Image::totalColors ( void )
 {
-  return GetNumberColors( image(), (FILE *) NULL);
+  return GetNumberColors( image(), 0);
+}
+
+// Origin of coordinate system to use when annotating with text or drawing
+void Magick::Image::transformOrigin ( double x_, double y_ )
+{
+  modifyImage();
+  options()->transformOrigin( x_, y_ );
+}
+
+// Rotation to use when annotating with text or drawing
+void Magick::Image::transformRotation ( double angle_ )
+{
+  modifyImage();
+  options()->transformRotation( angle_ );
+}
+
+// Reset transformation parameters to default
+void Magick::Image::transformReset ( void )
+{
+  modifyImage();
+  options()->transformReset();
+}
+
+// Scale to use when annotating with text or drawing
+void Magick::Image::transformScale ( double sx_, double sy_ )
+{
+  modifyImage();
+  options()->transformScale( sx_, sy_ );
+}
+
+// Skew to use in X axis when annotating with text or drawing
+void Magick::Image::transformSkewX ( double skewx_ )
+{
+  modifyImage();
+  options()->transformSkewX( skewx_ );
+}
+
+// Skew to use in Y axis when annotating with text or drawing
+void Magick::Image::transformSkewY ( double skewy_ )
+{
+  modifyImage();
+  options()->transformSkewY( skewy_ );
 }
 
 Magick::ImageType Magick::Image::type ( void ) const
 {
-  return (Magick::ImageType)MagickLib::GetImageType( const_cast<MagickLib::Image *>(constImage()) );
+  return static_cast<Magick::ImageType>(MagickLib::GetImageType(const_cast<MagickLib::Image *>(constImage())));
 }
 
 void Magick::Image::verbose ( bool verboseFlag_ )
@@ -2526,7 +2642,7 @@ Magick::Image Magick::Image::operator=( const Magick::Image &image_ )
     {
       // Delete old image reference with associated image and options.
       delete _imgRef;
-      _imgRef = (Magick::ImageRef*)0;
+      _imgRef = 0;
     }
   // Use new image reference
   _imgRef = image_._imgRef;
@@ -2552,7 +2668,7 @@ Magick::PixelPacket* Magick::Image::getPixels ( int x_, int y_,
 						unsigned int rows_ )
 {
   modifyImage();
-  Magick::PixelPacket* p = GetImagePixels( image(),
+  Magick::PixelPacket* p = (*GetImagePixels)( image(),
                                            x_, y_,
                                            columns_, rows_ );
   throwImageException();
@@ -2567,7 +2683,7 @@ Magick::PixelPacket* Magick::Image::setPixels ( int x_, int y_,
 						unsigned int rows_ )
 {
   modifyImage();
-  Magick::PixelPacket* p = SetImagePixels( image(),
+  Magick::PixelPacket* p = (*SetImagePixels)( image(),
                                            x_, y_,
                                            columns_, rows_ );
   throwImageException();
@@ -2577,7 +2693,7 @@ Magick::PixelPacket* Magick::Image::setPixels ( int x_, int y_,
 // Transfers the image cache pixels to the image.
 void Magick::Image::syncPixels ( void )
 {
-  SyncImagePixels( image() );
+  (*SyncImagePixels)( image() );
   throwImageException();
 }
 
@@ -2666,8 +2782,8 @@ void Magick::Image::modifyImage( void )
   GetExceptionInfo( &exceptionInfo );
   MagickLib::Image* newImage =
     CloneImage( image,
-		image->columns,
-		image->rows,
+		0,
+		0,
 		true,
 		&exceptionInfo);
   replaceImage( newImage );
@@ -2739,11 +2855,11 @@ Magick::ImageRef::~ImageRef( void )
   if ( _image )
     {
       DestroyImages( _image );
-      _image = (MagickLib::Image *)NULL;
+      _image = 0;
     }
 
   delete _options;
-  _options = (Options *)NULL;
+  _options = 0;
 }
 
 //
