@@ -26,9 +26,9 @@ namespace Magick
   class Image;
   class ImageRef;
 
-  const std::string borderGeometryDefault = "6x6+0+0";
-  const std::string frameGeometryDefault  = "25x25+6+6";
-  const std::string raiseGeometryDefault  = "6x6+0+0";
+  extern const std::string borderGeometryDefault;
+  extern const std::string frameGeometryDefault;
+  extern const std::string raiseGeometryDefault;
 
   // Compare two Image objects regardless of LHS/RHS
   // Image sizes and signatures are used as basis of comparison
@@ -68,6 +68,14 @@ namespace Magick
     // Construct Image of specified size, and format from in-memory BLOB
     Image ( const Blob &blob_, const Geometry &size, const std::string &magick_ );
 
+    // Construct an image based on an array of raw pixels, of
+    // specified type and mapping, in memory
+    Image ( const unsigned int width_,
+            const unsigned int height_,
+            const std::string &map_,
+            const StorageType type_,
+            const void *pixels_ );
+
     // Default constructor
     Image( void );
     
@@ -103,22 +111,33 @@ namespace Magick
 			       GravityType gravity_ = NorthWestGravity);
     
     // Blur image with specified blur factor
-    // The order_ parameter represents the order of the pixel neighborhood.
-    void            blur ( unsigned int order_ );
+    // The radius_ parameter specifies the radius of the Gaussian, in
+    // pixels, not counting the center pixel.  The sigma_ parameter
+    // specifies the standard deviation of the Laplacian, in pixels.
+    void            blur ( const double radius_ = 1, const double sigma_ = 0.5  );
     
     // Border image (add border to image)
     void            border ( const Geometry &geometry_ = borderGeometryDefault );
     
     // Charcoal effect image (looks like charcoal sketch)
-    void            charcoal ( unsigned int order_ = 3 );
+    // The radius_ parameter specifies the radius of the Gaussian, in
+    // pixels, not counting the center pixel.  The sigma_ parameter
+    // specifies the standard deviation of the Laplacian, in pixels.
+    void            charcoal ( const double radius_ = 1, const double sigma_ = 0.5 );
     
     // Chop image (remove vertical or horizontal subregion of image)
     // FIXME: describe how geometry argument is used to select either horizontal or
     // vertical subregion of image.
     void            chop ( const Geometry &geometry_ );
     
-    // Colorize opaque color in image using pen color
-    void            colorize ( const Color &opaqueColor_,
+    // Colorize image with pen color, using specified percent opacity
+    // for red, green, and blue quantums
+    void            colorize ( const unsigned int opacityRed_,
+                               const unsigned int opacityGreen_,
+                               const unsigned int opacityBlue_,
+			       const Color &penColor_ );
+    // Colorize image with pen color, using specified percent opacity.
+    void            colorize ( const unsigned int opacity_,
 			       const Color &penColor_ );
     
     // Comment image (add comment string to image)
@@ -159,11 +178,13 @@ namespace Magick
     void            draw ( const std::list<Magick::Drawable> &drawable_ );
     
     // Edge image (hilight edges in image)
-    void            edge ( unsigned int order_ );
+    void            edge ( double order_ );
     
     // Emboss image (hilight edges with 3D effect)
-    void            emboss ( void );
-    void            emboss ( unsigned int order_ );
+    // The radius_ parameter specifies the radius of the Gaussian, in
+    // pixels, not counting the center pixel.  The sigma_ parameter
+    // specifies the standard deviation of the Laplacian, in pixels.
+    void            emboss ( const double radius_ = 1, const double sigma_ = 0.5);
     
     // Enhance image (minimize noise)
     void            enhance ( void );
@@ -322,6 +343,15 @@ namespace Magick
 			   const Geometry    &size_,
 			   const std::string &magick_ );
 
+    // Read image from an array of raw pixels, with specified storage
+    // type (ConstituteImage), e.g.
+    // image.read( 640, 480, "RGB", 0, pixels );
+    void            read ( const unsigned int width_,
+                           const unsigned int height_,
+                           const std::string &map_,
+                           const StorageType type_,
+                           const void *pixels_ );
+
     // Reduce noise in image using a noise peak elimination filter
     void            reduceNoise ( void );
     void            reduceNoise ( unsigned int order_ );
@@ -354,7 +384,10 @@ namespace Magick
 			    bool   colorShading_ = false );
     
     // Sharpen pixels in image
-    void            sharpen ( unsigned int order_ );
+    // The radius_ parameter specifies the radius of the Gaussian, in
+    // pixels, not counting the center pixel.  The sigma_ parameter
+    // specifies the standard deviation of the Laplacian, in pixels.
+    void            sharpen ( const double radius_ = 1, const double sigma_ = 0.5 );
     
     // Shear image (create parallelogram by sliding image by X or Y axis)
     void            shear ( double xShearAngle_,
@@ -408,6 +441,17 @@ namespace Magick
     void            write ( Blob *blob_,
 			    const std::string &magick_,
 			    unsigned int depth_ );
+
+    // Write image to an array of pixels with storage type specified
+    // by user (DispatchImage), e.g.
+    // image.write( 0, 0, 640, 1, "RGB", 0, pixels );
+    void            write ( const int x_,
+                            const int y_,
+                            const unsigned int columns_,
+                            const unsigned int rows_,
+                            const std::string& map_,
+                            const StorageType type_,
+                            void *pixels_ );
     
     // Zoom image to specified size.
     void            zoom ( const Geometry &geometry_ );
@@ -693,6 +737,24 @@ namespace Magick
     // Number of colors in the image
     unsigned long   totalColors ( void );
 
+    // Origin of coordinate system to use when annotating with text or drawing
+    void            transformOrigin ( double x_, double y_ );
+
+    // Rotation to use when annotating with text or drawing
+    void            transformRotation ( double angle_ );
+
+    // Reset transformation parameters to default
+    void            transformReset ( void );
+
+    // Scale to use when annotating with text or drawing
+    void            transformScale ( double sx_, double sy_ );
+
+    // Skew to use in X axis when annotating with text or drawing
+    void            transformSkewX ( double skewx_ );
+
+    // Skew to use in Y axis when annotating with text or drawing
+    void            transformSkewY ( double skewy_ );
+
     // Image type
     ImageType       type ( void ) const;
 
@@ -857,13 +919,6 @@ inline Magick::Options * Magick::ImageRef::options ( void )
 // Image
 //
 
-// Emboss image
-inline void Magick::Image::emboss ( void )
-{
-  // Value of three provides legacy embossing effect
-  emboss( 3 );
-}
-
 // Reduce noise in image using a noise peak elimination filter
 inline void Magick::Image::reduceNoise ( void )
 {
