@@ -64,6 +64,7 @@ namespace MagickLib
 #undef VERSION
 
 #include <magick/api.h>
+#undef inline // Remove possible definition from config.h
 
 #undef class
 }
@@ -287,11 +288,27 @@ namespace Magick
   // IndexPacket type
   using MagickLib::IndexPacket;
 
+  // StorageType type
+  using MagickLib::StorageType;
+  using MagickLib::CharPixel;
+  using MagickLib::ShortPixel;
+  using MagickLib::IntegerPixel;
+  using MagickLib::FloatPixel;
+  using MagickLib::DoublePixel;
+
+  // Decoration types
+  using MagickLib::DecorationType;
+  using MagickLib::NoDecoration;
+  using MagickLib::UnderlineDecoration;
+  using MagickLib::OverlineDecoration;
+  using MagickLib::LineThroughDecoration;
+
 #if defined(MAGICK_IMPLEMENTATION)
   //
   // ImageMagick symbols used in implementation code
   //
   using MagickLib::AddNoiseImage;
+  using MagickLib::AffineInfo;
   using MagickLib::AllocateImage;
   using MagickLib::AcquireMemory;
   using MagickLib::AnnotateImage;
@@ -315,6 +332,7 @@ namespace Magick
   using MagickLib::ColorFloodfillImage;
   using MagickLib::ColorizeImage;
   using MagickLib::CompositeImage;
+  using MagickLib::ConstituteImage;
   using MagickLib::ContrastImage;
   using MagickLib::CorruptImageError;
   using MagickLib::CorruptImageWarning;
@@ -332,6 +350,7 @@ namespace Magick
   using MagickLib::DestroyMagickInfo;
   using MagickLib::DestroyPostscriptGeometry;
   using MagickLib::DestroyQuantizeInfo;
+  using MagickLib::DispatchImage;
   using MagickLib::DisplayImages;
   using MagickLib::DrawImage;
   using MagickLib::DrawInfo;
