@@ -1,6 +1,6 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999
+// Copyright Bob Friesenhahn, 1999, 2000
 //
 // Definition and implementation of template functions for using
 // Magick::Image with STL containers.
@@ -19,103 +19,6 @@
 
 namespace Magick
 {
-  //
-  // STL Algorithm declarations
-  //
-
-  // Animate a set of images (display animation).
-  template <class InputIterator>
-  void animateImages( InputIterator first_,
-		      InputIterator last_ );
-
-  // Append a set of images.
-  // All the input images must have the same width or height. Images
-  // of the same width are stacked top-to-bottom. Images of the same
-  // height are stacked left-to-right. If the stack is false,
-  // rectangular images are stacked left-to-right otherwise
-  // top-to-bottom.
-  template <class InputIterator>
-  void appendImages( Image *appendedImage_,
-		     InputIterator first_,
-		     InputIterator last_,
-		     bool stack_ );
-
-  // Average a set of images.
-  // All the input images must be the same size in pixels.
-  template <class InputIterator>
-  void averageImages( Image *averagedImage_,
-		      InputIterator first_,
-		      InputIterator last_ );
-
-  // Merge a sequence of images.
-  // This is useful for GIF animation sequences that have page
-  // offsets and disposal methods.
-  // The images are modified in-place. No pointer re-assignments are performed.
-  template <class InputIterator>
-  void coalesceImages( InputIterator first_,
-		       InputIterator last_ );
-
-  // Display a set of images.
-  template <class InputIterator>
-  void displayImages( InputIterator first_,
-		      InputIterator last_ );
-
-  // Replace the colors of a sequence of images with the closest color
-  // from a reference image.
-  // Set dither_ to true to enable dithering.  Set measureError_ to
-  // true in order to evaluate quantization error.
-  template <class InputIterator>
-  void mapImages( InputIterator first_,
-		  InputIterator last_,
-		  const Image& mapImage_,
-		  bool dither_,
-		  bool measureError_ );
-
-  // Create a composite image by combining several separate images.
-  template <class Container, class InputIterator>
-  void montageImages( Container *montageImages_,
-		      InputIterator first_,
-		      InputIterator last_,
-		      const Montage &montageOpts_ );
-
-  // Morph a set of images
-  template <class InputIterator, class Container >
-  void morphImages( Container *morphedImages_,
-		    InputIterator first_,
-		    InputIterator last_,
-		    unsigned int frames_ );
-
-  // Quantize colors in images using current quantization settings
-  // Set measureError_ to true in order to measure quantization error
-  template <class InputIterator>
-  void quantizeImages( InputIterator first_,
-		       InputIterator last_,
-		       bool measureError_ );
-
-  // Read images into existing container (appending to container)
-  template <class Container>
-  void readImages( Container *sequence_,
-		   const std::string &imageSpec_ );
-  template <class Container>
-  // Read images from BLOB
-  void readImages( Container *sequence_,
-		   const Blob &blob_ );
-
-  // Write images to file.
-  // Set adjoin_ to false to write a set of image frames via a
-  // wildcard imageSpec_ (e.g. image%02d.miff).
-  template <class InputIterator>
-  void writeImages( InputIterator first_,
-		    InputIterator last_,
-		    const std::string &imageSpec_,
-		    bool adjoin_ );
-  template <class InputIterator>
-  // Write images to a BLOB
-  void writeImages( InputIterator first_,
-		    InputIterator last_,
-		    Blob *blob_,
-		    bool adjoin_ );
-
   //
   // STL function object declarations/definitions
   //
@@ -183,15 +86,17 @@ namespace Magick
   class blurImage : public std::unary_function<Image&,void>
   {
   public:
-    blurImage( unsigned int order_ )
-      : _order( order_ ) { }
+    blurImage( const double radius_ = 1, const double sigma_ = 0.5 )
+      : _radius( radius_ ),
+        _sigma( sigma_ ){ }
 
     void operator()( Image &image_ )
       {
-	image_.blur( _order );
+	image_.blur( _radius, _sigma );
       }
   private:
-    const unsigned int _order;
+    const double _radius;
+    const double _sigma;
   };
 
   // Border image (add border to image)
@@ -213,15 +118,17 @@ namespace Magick
   class charcoalImage : public std::unary_function<Image&,void>
   {
   public:
-    charcoalImage( unsigned int order_ = 3  )
-      : _order( order_ ) { }
+    charcoalImage( const double radius_ = 1, const double sigma_ = 0.5  )
+      : _radius( radius_ ),
+        _sigma( sigma_ ) { }
 
     void operator()( Image &image_ )
       {
-	image_.charcoal( _order );
+	image_.charcoal( _radius, _sigma );
       }
   private:
-    const unsigned int _order;
+    const double _radius;
+    const double _sigma;
   };
 
   // Chop image (remove vertical or horizontal subregion of image)
@@ -239,21 +146,33 @@ namespace Magick
     const Geometry _geometry;
   };
 
-  // Colorize opaque color in image using pen color
+  // Colorize image using pen color at specified percent opacity
   class colorizeImage : public std::unary_function<Image&,void>
   {
   public:
-    colorizeImage( const Color &opaqueColor_,
+    colorizeImage( const unsigned int opacityRed_,
+                   const unsigned int opacityGreen_,
+                   const unsigned int opacityBlue_,
 		   const Color &penColor_ )
-      : _opaqueColor( opaqueColor_ ),
+      : _opacityRed ( opacityRed_ ),
+        _opacityGreen ( opacityGreen_ ),
+        _opacityBlue ( opacityBlue_ ),
+	_penColor( penColor_ ) { }
+    colorizeImage( const unsigned int opacity_,
+                   const Color &penColor_ )
+      : _opacityRed ( opacity_ ),
+        _opacityGreen ( opacity_ ),
+        _opacityBlue ( opacity_ ),
 	_penColor( penColor_ ) { }
 
     void operator()( Image &image_ )
       {
-	image_.colorize( _opaqueColor, _penColor );
+	image_.colorize( _opacityRed, _opacityGreen, _opacityBlue, _penColor );
       }
   private:
-    const Color _opaqueColor;
+    const unsigned int _opacityRed;
+    const unsigned int _opacityGreen;
+    const unsigned int _opacityBlue;
     const Color _penColor;
   };
 
@@ -421,16 +340,19 @@ namespace Magick
   {
   public:
     embossImage( void )
-      : _order(3) { }
-    embossImage( unsigned int order_ )
-      : _order(order_) { }
+      : _radius( 1 ),
+        _sigma( 0.5 ) { }
+    embossImage( const double radius_, const double sigma_ )
+      : _radius( radius_ ),
+        _sigma( sigma_ ) { }
 
     void operator()( Image &image_ )
       {
-	image_.emboss( _order );
+	image_.emboss( _radius, _sigma );
       }
   private:
-    const unsigned int _order;
+    const double _radius;
+    const double _sigma;
   };
 
   // Enhance image (minimize noise)
@@ -1044,15 +966,17 @@ namespace Magick
   class sharpenImage : public std::unary_function<Image&,void>
   {
   public:
-    sharpenImage( unsigned int order_ )
-      : _order( order_ ) { }
+    sharpenImage( const double radius_ = 1, const double sigma_ = 0.5 )
+      : _radius( radius_ ),
+        _sigma( sigma_ ) { }
 
     void operator()( Image &image_ )
       {
-	image_.sharpen( _order );
+	image_.sharpen( _radius, _sigma );
       }
   private:
-    const unsigned int _order;
+    const double _radius;
+    const double _sigma;
   };
 
   // Shear image (create parallelogram by sliding image by X or Y axis)
@@ -2164,7 +2088,7 @@ namespace Magick
 		      const Montage &montageOpts_ ) {
 
     MagickLib::MontageInfo* montageInfo =
-      (MagickLib::MontageInfo*)MagickLib::AcquireMemory(sizeof(MagickLib::MontageInfo));
+      static_cast<MagickLib::MontageInfo*>(MagickLib::AcquireMemory(sizeof(MagickLib::MontageInfo)));
     MagickLib::ImageInfo* imageInfo = first_->imageInfo();
     MagickLib::GetMontageInfo( imageInfo, montageInfo );
 
@@ -2205,7 +2129,7 @@ namespace Magick
     MagickLib::Image *images = MagickLib::MontageImages( first_->image(),
 							 montageInfo,
 							 &exceptionInfo );
-    if ( images != (MagickLib::Image *)NULL )
+    if ( images != 0 )
       {
 	Magick::Options options;
 	insertImages( montageImages_, images, options );
@@ -2387,7 +2311,7 @@ namespace Magick
   void linkImages( InputIterator first_,
 		   InputIterator last_ ) {
 
-    MagickLib::Image* previous = (MagickLib::Image*) NULL;
+    MagickLib::Image* previous = 0;
     int scene = 0;
     for ( InputIterator iter = first_; iter != last_; ++iter )
       {
@@ -2399,10 +2323,10 @@ namespace Magick
 	MagickLib::Image* current = iter->image();
 
 	current->previous = previous;
-	current->next     = (MagickLib::Image*) NULL;
-	current->orphan   = (int)false; // In a list
+	current->next     = 0;
+	current->orphan   = static_cast<int>(false); // In a list
 
-	if ( previous != (MagickLib::Image*) NULL)
+	if ( previous != 0)
 	  previous->next = current;
 
 	current->scene=scene;
@@ -2418,9 +2342,9 @@ namespace Magick
     for( InputIterator iter = first_; iter != last_; ++iter )
       {
 	MagickLib::Image* image = iter->image();
-	image->previous = (MagickLib::Image*) NULL;
-	image->next = (MagickLib::Image*) NULL;
-	image->orphan = (int)true; // Stand-alone
+	image->previous = 0;
+	image->next = 0;
+	image->orphan = static_cast<int>(true); // Stand-alone
       }
   }
 
@@ -2434,10 +2358,10 @@ namespace Magick
 	do
 	  {
 	    MagickLib::Image* next_image = image->next;
-	    image->next = (MagickLib::Image *)NULL;
+	    image->next = 0;
 	  
-	    if (next_image != (MagickLib::Image *)NULL)
-	      next_image->previous=(MagickLib::Image *)NULL;
+	    if (next_image != 0)
+	      next_image->previous=0;
 	  
 	    sequence_->push_back( Magick::Image( image, &options_ ) );
 	  
