@@ -12,17 +12,20 @@
 #include <string>
 #include <stdlib.h>
 #include <iostream>
+#include <math.h>
 #include "Magick++/Options.h"
 #include "Magick++/Functions.h"
 #include "Magick++/Exception.h"
 #include "Magick++/Include.h"
 
+#define DegreesToRadians(x) ((x)*3.14159265358979323846/180.0)
+
 // Constructor
 Magick::Options::Options( void )
-  : _imageInfo((ImageInfo*)AcquireMemory( sizeof(ImageInfo) ) ),
-    _quantizeInfo((QuantizeInfo*)AcquireMemory( sizeof(QuantizeInfo) )),
-    _annotateInfo((AnnotateInfo*)AcquireMemory( sizeof(AnnotateInfo) )),
-    _drawInfo((DrawInfo*)AcquireMemory( sizeof(DrawInfo) ))
+  : _imageInfo(static_cast<ImageInfo*>(AcquireMemory(sizeof(ImageInfo)))),
+    _quantizeInfo(static_cast<QuantizeInfo*>(AcquireMemory(sizeof(QuantizeInfo)))),
+    _annotateInfo(static_cast<AnnotateInfo*>(AcquireMemory(sizeof(AnnotateInfo)))),
+    _drawInfo(static_cast<DrawInfo*>(AcquireMemory( sizeof(DrawInfo))))
 {
   // Initialize image info with defaults
   GetImageInfo( _imageInfo );
@@ -107,7 +110,7 @@ Magick::Color Magick::Options::backgroundColor ( void ) const
 void Magick::Options::backgroundTexture ( const std::string &backgroundTexture_ )
 {
   if ( backgroundTexture_.length() == 0 )
-    LiberateMemory( (void**)&_imageInfo->texture );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->texture) );
   else
     Magick::CloneString( &_imageInfo->texture, backgroundTexture_ );
 }
@@ -122,6 +125,7 @@ std::string Magick::Options::backgroundTexture ( void ) const
 void Magick::Options::borderColor ( const Color &color_ )
 {
   _imageInfo->border_color = color_;
+  _drawInfo->border_color = color_;
 }
 Magick::Color Magick::Options::borderColor ( void ) const
 {
@@ -142,7 +146,7 @@ Magick::Color Magick::Options::boxColor ( void ) const
 void Magick::Options::density ( const Magick::Geometry &density_ )
 {
   if ( !density_.isValid() )
-    LiberateMemory( (void**)&_imageInfo->density );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->density) );
   else
     Magick::CloneString( &_imageInfo->density, density_ );
 
@@ -181,9 +185,15 @@ Magick::Color Magick::Options::fillColor ( void ) const
 void Magick::Options::font ( const std::string &font_ )
 {
   if ( font_.length() == 0 )
-    LiberateMemory( (void**)&_imageInfo->font );
+    {
+      LiberateMemory( reinterpret_cast<void**>(&_imageInfo->font) );
+      LiberateMemory( reinterpret_cast<void**>(&_drawInfo->font) );
+    }
   else
-    Magick::CloneString( &_imageInfo->font, font_ );
+    {
+      Magick::CloneString( &_imageInfo->font, font_ );
+      Magick::CloneString( &_drawInfo->font, font_ );
+    }
 
   updateAnnotateInfo();
 }
@@ -201,7 +211,7 @@ std::string Magick::Options::format ( void ) const
   if ( _imageInfo->magick && ( *_imageInfo->magick != '\0' ))
     magick_info = GetMagickInfo( _imageInfo->magick );
   
-  if (( magick_info != (MagickInfo *)0 ) && 
+  if (( magick_info != 0 ) && 
       ( *magick_info->description != '\0' ))
     return std::string( magick_info->description );
   
@@ -228,9 +238,9 @@ void Magick::Options::magick ( const std::string &magick_ )
   FormatString( _imageInfo->filename, "%.1024s:", magick_.c_str() );
   SetImageInfo( _imageInfo, 1 );
   if ( _imageInfo->magick == '\0' )
-    throwException( OptionWarning,
-		    "Unrecognized image format",
-		    magick_.c_str() );
+    throwExceptionExplicit( OptionWarning,
+			    "Unrecognized image format",
+			    magick_.c_str() );
 }
 std::string Magick::Options::magick ( void ) const
 {
@@ -252,7 +262,7 @@ Magick::Color Magick::Options::matteColor ( void ) const
 void Magick::Options::page ( const Magick::Geometry &pageSize_ )
 {
   if ( !pageSize_.isValid() )
-    LiberateMemory( (void**)&_imageInfo->page );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->page) );
   else
     Magick::CloneString( &_imageInfo->page, pageSize_ );
 }
@@ -269,7 +279,7 @@ void Magick::Options::penTexture ( const MagickLib::Image *penTexture_ )
   if ( _drawInfo->tile )
     {
       DestroyImage( _drawInfo->tile );
-      _drawInfo->tile = (MagickLib::Image*)NULL;
+      _drawInfo->tile = 0;
     }
 
   if ( penTexture_ )
@@ -278,9 +288,9 @@ void Magick::Options::penTexture ( const MagickLib::Image *penTexture_ )
       GetExceptionInfo( &exceptionInfo );
       _drawInfo->tile =
 	CloneImage( const_cast<MagickLib::Image*>(penTexture_),
-		    penTexture_->columns,
-		    penTexture_->rows,
-		    (int)true,
+		    0,
+		    0,
+		    static_cast<int>(true),
 		    &exceptionInfo );
       throwException( exceptionInfo );
     }
@@ -296,12 +306,12 @@ void Magick::Options::resolutionUnits ( Magick::ResolutionType resolutionUnits_
 }
 Magick::ResolutionType Magick::Options::resolutionUnits ( void ) const
 {
-  return (Magick::ResolutionType)_imageInfo->units;
+  return static_cast<Magick::ResolutionType>(_imageInfo->units);
 }
 
 void Magick::Options::size ( const Geometry &geometry_ )
 {
-  LiberateMemory( (void**)&_imageInfo->size );
+  LiberateMemory( reinterpret_cast<void**>(&_imageInfo->size) );
 
   if ( geometry_.isValid() )
     Magick::CloneString( &_imageInfo->size, geometry_ );
@@ -329,7 +339,7 @@ Magick::Color Magick::Options::strokeColor ( void ) const
 void Magick::Options::tileName ( const std::string &tileName_ )
 {
   if ( tileName_.length() == 0 )
-    LiberateMemory( (void**)&_imageInfo->tile );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->tile) );
   else
     Magick::CloneString( &_imageInfo->tile, tileName_ );
 }
@@ -340,10 +350,155 @@ std::string Magick::Options::tileName ( void ) const
   return std::string();
 }
 
+// Origin of coordinate system to use when annotating with text or drawing
+void Magick::Options::transformOrigin ( double tx_, double ty_ )
+{
+  AffineInfo current = _imageInfo->affine;
+  AffineInfo affine;
+  affine.sx=1.0;
+  affine.rx=0.0;
+  affine.ry=0.0;
+  affine.sy=1.0;
+  affine.tx=0.0;
+  affine.ty=0.0;
+
+  affine.tx = tx_;
+  affine.ty = ty_;
+
+  _imageInfo->affine.sx=current.sx*affine.sx+current.ry*affine.rx;
+  _imageInfo->affine.rx=current.rx*affine.sx+current.sy*affine.rx;
+  _imageInfo->affine.ry=current.sx*affine.ry+current.ry*affine.sy;
+  _imageInfo->affine.sy=current.rx*affine.ry+current.sy*affine.sy;
+  _imageInfo->affine.tx=current.sx*affine.tx+current.ry*affine.ty+current.tx;
+  _imageInfo->affine.ty=current.rx*affine.tx+current.sy*affine.ty+current.ty;
+
+  _annotateInfo->affine = _imageInfo->affine;
+  _drawInfo->affine     = _imageInfo->affine;
+}
+
+// Reset transformation parameters to default
+void Magick::Options::transformReset ( void )
+{
+  _imageInfo->affine.sx=1.0;
+  _imageInfo->affine.rx=0.0;
+  _imageInfo->affine.ry=0.0;
+  _imageInfo->affine.sy=1.0;
+  _imageInfo->affine.tx=0.0;
+  _imageInfo->affine.ty=0.0;
+}
+
+// Rotation to use when annotating with text or drawing
+void Magick::Options::transformRotation ( double angle_ )
+{
+  AffineInfo current = _imageInfo->affine;
+  AffineInfo affine;
+  affine.sx=1.0;
+  affine.rx=0.0;
+  affine.ry=0.0;
+  affine.sy=1.0;
+  affine.tx=0.0;
+  affine.ty=0.0;
+
+  affine.sx=cos(DegreesToRadians(fmod(angle_,360.0)));
+  affine.rx=(-sin(DegreesToRadians(fmod(angle_,360.0))));
+  affine.ry=sin(DegreesToRadians(fmod(angle_,360.0)));
+  affine.sy=cos(DegreesToRadians(fmod(angle_,360.0)));
+
+  _imageInfo->affine.sx=current.sx*affine.sx+current.ry*affine.rx;
+  _imageInfo->affine.rx=current.rx*affine.sx+current.sy*affine.rx;
+  _imageInfo->affine.ry=current.sx*affine.ry+current.ry*affine.sy;
+  _imageInfo->affine.sy=current.rx*affine.ry+current.sy*affine.sy;
+  _imageInfo->affine.tx=current.sx*affine.tx+current.ry*affine.ty+current.tx;
+  _imageInfo->affine.ty=current.rx*affine.tx+current.sy*affine.ty+current.ty;
+
+  _annotateInfo->affine = _imageInfo->affine;
+  _drawInfo->affine     = _imageInfo->affine;
+}
+
+// Scale to use when annotating with text or drawing
+void Magick::Options::transformScale ( double sx_, double sy_ )
+{
+  AffineInfo current = _imageInfo->affine;
+  AffineInfo affine;
+  affine.sx=1.0;
+  affine.rx=0.0;
+  affine.ry=0.0;
+  affine.sy=1.0;
+  affine.tx=0.0;
+  affine.ty=0.0;
+
+  affine.sx = sx_;
+  affine.sy = sy_;
+
+  _imageInfo->affine.sx=current.sx*affine.sx+current.ry*affine.rx;
+  _imageInfo->affine.rx=current.rx*affine.sx+current.sy*affine.rx;
+  _imageInfo->affine.ry=current.sx*affine.ry+current.ry*affine.sy;
+  _imageInfo->affine.sy=current.rx*affine.ry+current.sy*affine.sy;
+  _imageInfo->affine.tx=current.sx*affine.tx+current.ry*affine.ty+current.tx;
+  _imageInfo->affine.ty=current.rx*affine.tx+current.sy*affine.ty+current.ty;
+
+  _annotateInfo->affine = _imageInfo->affine;
+  _drawInfo->affine     = _imageInfo->affine;
+}
+
+// Skew to use in X axis when annotating with text or drawing
+void Magick::Options::transformSkewX ( double skewx_ )
+{
+  AffineInfo current = _imageInfo->affine;
+  AffineInfo affine;
+  affine.sx=1.0;
+  affine.rx=0.0;
+  affine.ry=0.0;
+  affine.sy=1.0;
+  affine.tx=0.0;
+  affine.ty=0.0;
+
+  affine.sx=1.0;
+  affine.ry=tan(DegreesToRadians(fmod(skewx_,360.0)));
+  affine.sy=1.0;
+
+  _imageInfo->affine.sx=current.sx*affine.sx+current.ry*affine.rx;
+  _imageInfo->affine.rx=current.rx*affine.sx+current.sy*affine.rx;
+  _imageInfo->affine.ry=current.sx*affine.ry+current.ry*affine.sy;
+  _imageInfo->affine.sy=current.rx*affine.ry+current.sy*affine.sy;
+  _imageInfo->affine.tx=current.sx*affine.tx+current.ry*affine.ty+current.tx;
+  _imageInfo->affine.ty=current.rx*affine.tx+current.sy*affine.ty+current.ty;
+
+  _annotateInfo->affine = _imageInfo->affine;
+  _drawInfo->affine = _imageInfo->affine;
+}
+
+// Skew to use in Y axis when annotating with text or drawing
+void Magick::Options::transformSkewY ( double skewy_ )
+{
+  AffineInfo current = _imageInfo->affine;
+  AffineInfo affine;
+  affine.sx=1.0;
+  affine.rx=0.0;
+  affine.ry=0.0;
+  affine.sy=1.0;
+  affine.tx=0.0;
+  affine.ty=0.0;
+
+  affine.sx=1.0;
+  affine.rx=tan(DegreesToRadians(fmod(skewy_,360.0)));
+  affine.sy=1.0;
+
+  _imageInfo->affine.sx=current.sx*affine.sx+current.ry*affine.rx;
+  _imageInfo->affine.rx=current.rx*affine.sx+current.sy*affine.rx;
+  _imageInfo->affine.ry=current.sx*affine.ry+current.ry*affine.sy;
+  _imageInfo->affine.sy=current.rx*affine.ry+current.sy*affine.sy;
+  _imageInfo->affine.tx=current.sx*affine.tx+current.ry*affine.ty+current.tx;
+  _imageInfo->affine.ty=current.rx*affine.tx+current.sy*affine.ty+current.ty;
+
+  _annotateInfo->affine = _imageInfo->affine;
+  _drawInfo->affine = _imageInfo->affine;
+}
+
 void Magick::Options::view ( const std::string &view_ )
 {
   if ( view_.length() == 0 )
-    LiberateMemory( (void**)&_imageInfo->view );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->view) );
   else
     Magick::CloneString( &_imageInfo->view, view_ );
 }
@@ -358,7 +513,7 @@ std::string Magick::Options::view ( void ) const
 void Magick::Options::x11Display ( const std::string &display_ )
 {
   if ( display_.length() == 0 )
-    LiberateMemory( (void**)&_imageInfo->server_name );
+    LiberateMemory( reinterpret_cast<void**>(&_imageInfo->server_name) );
   else
     Magick::CloneString( &_imageInfo->server_name, display_ );
 }
@@ -375,7 +530,7 @@ void Magick::Options::updateAnnotateInfo( void )
 {
   // Update _annotateInfo
   AnnotateInfo* annotate_info =
-    (AnnotateInfo*)AcquireMemory( sizeof(AnnotateInfo) );
+    static_cast<AnnotateInfo*>(AcquireMemory(sizeof(AnnotateInfo)));
   if ( annotate_info )
     {
       GetAnnotateInfo( _imageInfo, annotate_info );
