@@ -24,6 +24,10 @@ int main( int /*argc*/, char ** argv)
 
   int failures=0;
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
   try {
 
     //
@@ -31,15 +35,14 @@ int main( int /*argc*/, char ** argv)
     //
 
     list<Image> imageList;
-    readImages( &imageList, "test_image_anim.miff" );
+    readImages( &imageList, srcdir + "test_image_anim.miff" );
 
     Image appended;
 
     // Horizontal
     appendImages( &appended, imageList.begin(), imageList.end() );
     // appended.display();
-    if ( appended.signature() != "0e600860c5cb47cd5e2377c015753d3c" &&
-	 appended.signature() != "7c7c64a91c652c0eadbee38ac315539b" )
+    if ( appended.signature() != "586f22dd8ff100c760972af77b13437b" )
       {
 	++failures;
 	cout << "Line: " << __LINE__
@@ -50,8 +53,7 @@ int main( int /*argc*/, char ** argv)
 
     // Vertical
     appendImages( &appended, imageList.begin(), imageList.end(), true );
-    if ( appended.signature() != "b65606228af103f08d21d437725ba90d" &&
-	 appended.signature() != "39c8d58e479462844d8e38d9a0016bb6" )
+    if ( appended.signature() != "1b32743b917dc97c5ed354b3b64fe3c8" )
       {
 	++failures;
 	cout << "Line: " << __LINE__
