@@ -7,8 +7,6 @@
 
 #include <string>
 #include <iostream>
-#include <list>
-#include <vector>
 
 #include <Magick++.h>
 
@@ -693,11 +691,12 @@ int main( int /*argc*/, char ** argv)
     // font
     //
     // Test default
-    if ( image.font().length() != 0 )
+    if ( image.font().length() != 11 )
       {
 	++failures;
 	cout << "Line: " << __LINE__
-             << ", font does not have default length of zero as expected"
+             << ", font has default length " << image.font().length()
+             << " rather than 13 as expected"
              << endl;
       }
 
@@ -708,7 +707,7 @@ int main( int /*argc*/, char ** argv)
 	++failures;
 	cout << "Line: " << __LINE__ << ", font set/get failed" << endl;
       }
-    // Test set to default
+    // Test set to null font
     image.font( string() );
     if ( image.font().length() != 0 )
       {
@@ -720,11 +719,13 @@ int main( int /*argc*/, char ** argv)
     // fontPointsize
     //
     // Test default
-    if ( image.fontPointsize() != 12 )
+    if ( image.fontPointsize() != 13 )
       {
 	++failures;
 	cout << "Line: " << __LINE__
-             << ", fontPointsize does not report default of 12 as expected"
+             << ", fontPointsize ("
+             << image.fontPointsize()
+             << ") is not default of 13 as expected"
              << endl;
       }
 
