@@ -24,6 +24,10 @@ int main( int /*argc*/, char ** argv)
 
   int failures=0;
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
   try {
 
     //
@@ -31,13 +35,13 @@ int main( int /*argc*/, char ** argv)
     //
     
     list<Image> imageList;
-    readImages( &imageList, "test_image_anim.miff" );
+    readImages( &imageList, srcdir + "test_image_anim.miff" );
     
     Image averaged;
     averageImages( &averaged, imageList.begin(), imageList.end() );
     // averaged.display();
-    if ( averaged.signature() != "0ee231b0a02df53c6afae650dc05c04a" &&
-	 averaged.signature() != "b2dd960061090cf3e7f0864b6a9f044d")
+    if ( averaged.signature() != "25b9f5906dd262a740d9b5985f42902f" &&
+         averaged.signature() != "17ea2e483626c1b87c017c230a83c015")
       {
 	cout << "Line: " << __LINE__
 	     << "  Averaging image failed, signature = "
