@@ -24,6 +24,10 @@ int main( int /*argc*/, char **argv)
 
   int failures=0;
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
   try {
 
     //
@@ -31,7 +35,7 @@ int main( int /*argc*/, char **argv)
     //
 
     list<Image> imageList;
-    readImages( &imageList, "test_image_anim.miff" );
+    readImages( &imageList, srcdir + "test_image_anim.miff" );
 
     vector<Image> montage;
     MontageFramed montageOpts;
@@ -39,7 +43,7 @@ int main( int /*argc*/, char **argv)
     // Default montage
     montageImages( &montage, imageList.begin(), imageList.end(), montageOpts );
 
-    if ( montage[0].montageGeometry() != Geometry( 114, 112 ) )
+    if ( montage[0].montageGeometry() != Geometry( 128, 126 ) )
       {
 	++failures;
 	cout << "Line: " << __LINE__ 
@@ -49,7 +53,7 @@ int main( int /*argc*/, char **argv)
 	     << endl;
       }
 
-    if ( montage[0].columns() != 684 || montage[0].rows() != 114 )
+    if ( montage[0].columns() != 768 || montage[0].rows() != 128 )
       {
 	++failures;
 	cout << "Line: " << __LINE__ 
