@@ -24,6 +24,10 @@ int main( int /*argc*/, char ** argv)
 
   int failures=0;
 
+  string srcdir("");
+  if(getenv("srcdir") != 0)
+    srcdir = getenv("srcdir") + string("/");
+
   try {
 
     //
@@ -31,7 +35,7 @@ int main( int /*argc*/, char ** argv)
     //
       
     list<Image> first;
-    readImages( &first, "test_image_anim.miff" );
+    readImages( &first, srcdir + "test_image_anim.miff" );
       
     if ( first.size() != 6 )
       {
