@@ -263,7 +263,7 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
         }
       }
     if (QuantumTick(y,number_rows))
-      ProgressMonitor(LoadImageText,y,number_rows);
+      MagickMonitor(LoadImageText,y,number_rows);
   }
   (void) ReadByte(image);  /* end of line */
   (void) ReadByte(image);
@@ -305,7 +305,7 @@ static unsigned int IsAVI(const unsigned char *magick,
 {
   if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"RIFF",4) == 0)
+  if (memcmp(magick,"RIFF",4) == 0)
     return(True);
   return(False);
 }
@@ -482,7 +482,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+                  MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
             }
             break;
           }
@@ -519,7 +519,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+                  MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
             }
             break;
           }
@@ -547,15 +547,14 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+                  MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
             }
             break;
           }
           case 16:
           {
-            unsigned char
-              h,
-              l;
+            unsigned short
+              word;
 
             /*
               Convert PseudoColor scanline.
@@ -571,19 +570,18 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               for (x=0; x < (int) image->columns; x++)
               {
-                h=(*p++);
-                l=(*p++);
-                q->red=(MaxRGB*((int) (l & 0x7c) >> 2))/31;
-                q->green=
-                  (MaxRGB*(((int) (l & 0x03) << 3)+((int) (h & 0xe0) >> 5)))/31;
-                q->blue=(MaxRGB*((int) (h & 0x1f)))/31;
+                word=(*p++);
+                word|=(*p++ << 8);
+                q->red=UpScale(ScaleColor5to8((word >> 11) & 0x1f));
+                q->green=UpScale(ScaleColor6to8((word >> 5) & 0x3f));
+                q->blue=UpScale(ScaleColor5to8(word & 0x1f));
                 q++;
               }
               if (!SyncImagePixels(image))
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+                  MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
             }
             break;
           }
@@ -612,7 +610,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+                  MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
             }
             break;
           }
@@ -633,7 +631,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 return((Image *) NULL);
               }
             image=image->next;
-            ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+            MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
           }
         continue;
       }
@@ -787,7 +785,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           (void) ReadByte(image);
         continue;
       }
-    FormatString(message,"AVI support for chunk %s not yet available",id);
+    FormatString(message,"AVI support for chunk %.1024s not yet available",id);
     ThrowReaderException(CorruptImageWarning,message,image);
   }
   while (image->previous != (Image *) NULL)
