@@ -165,7 +165,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
       for (x=0; x < (int) image->columns; x++)
       {
-        q->opacity=UpScale(DownScale(MaxRGB)-(*p++));
+        q->opacity=MaxRGB-UpScale(*p++);
         q->red=UpScale(*p++);
         q->green=UpScale(*p++);
         q->blue=UpScale(*p++);
@@ -176,7 +176,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(LoadImageText,y,image->rows);
+          MagickMonitor(LoadImageText,y,image->rows);
     }
     LiberateMemory((void **) &pixels);
     /*
@@ -199,7 +199,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while ((width != (unsigned long) ~0) && (height != (unsigned long) ~0));
   while (image->previous != (Image *) NULL)
@@ -334,8 +334,7 @@ static unsigned int WriteAVSImage(const ImageInfo *image_info,Image *image)
     /*
       Allocate memory for pixels.
     */
-    pixels=(unsigned char *)
-      AcquireMemory(image->columns*sizeof(PixelPacket));
+    pixels=(unsigned char *) AcquireMemory(image->columns*sizeof(PixelPacket));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitWarning,"Memory allocation failed",
         image);
@@ -350,7 +349,7 @@ static unsigned int WriteAVSImage(const ImageInfo *image_info,Image *image)
       q=pixels;
       for (x=0; x < (int) image->columns; x++)
       {
-        *q++=DownScale(MaxRGB-(image->matte ? p->opacity : OpaqueOpacity));
+        *q++=MaxRGB-DownScale((image->matte ? p->opacity : OpaqueOpacity));
         *q++=DownScale(p->red);
         *q++=DownScale(p->green);
         *q++=DownScale(p->blue);
@@ -359,13 +358,13 @@ static unsigned int WriteAVSImage(const ImageInfo *image_info,Image *image)
       (void) WriteBlob(image,q-pixels,(char *) pixels);
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
     }
     LiberateMemory((void **) &pixels);
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
