@@ -1,4 +1,4 @@
-/*
+/* 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
@@ -61,12 +61,8 @@
 typedef struct _BMPInfo
 {
   unsigned long
-    file_size;
-
-  unsigned short
-    reserved[2];
-
-  unsigned long
+    file_size,
+    ba_offset,
     offset_bits,
     size;
 
@@ -125,7 +121,6 @@ static unsigned int
 %  The format of the DecodeImage method is:
 %
 %      unsigned int DecodeImage(Image *image,const unsigned int compression,
-%        const unsigned int number_columns,const unsigned int number_rows,
 %        unsigned char *pixels)
 %
 %  A description of each parameter follows:
@@ -138,19 +133,12 @@ static unsigned int
 %    o compression:  A value of 1 means the compressed pixels are runlength
 %      encoded for a 256-color bitmap.  A value of 2 means a 16-color bitmap.
 %
-%    o number_columns:  An integer value that is the number of columns or
-%      width in pixels of your source image.
-%
-%    o number_rows:  An integer value that is the number of rows or
-%      heigth in pixels of your source image.
-%
 %    o pixels:  The address of a byte (8 bits) array of pixel data created by
 %      the decoding process.
 %
 %
 */
 static unsigned int DecodeImage(Image *image,const unsigned int compression,
-  const unsigned int number_columns,const unsigned int number_rows,
   unsigned char *pixels)
 {
   int
@@ -167,12 +155,12 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
 
   assert(image != (Image *) NULL);
   assert(pixels != (unsigned char *) NULL);
-  for (i=0; i < (int) (number_columns*number_rows); i++)
+  for (i=0; i < (int) (image->columns*image->rows); i++)
     pixels[i]=0;
   byte=0;
   x=0;
   q=pixels;
-  for (y=0; y < (int) number_rows; )
+  for (y=0; y < (int) image->rows; )
   {
     count=ReadByte(image);
     if (count == EOF)
@@ -209,7 +197,7 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
             */
             x=0;
             y++;
-            q=pixels+y*number_columns;
+            q=pixels+y*image->columns;
             break;
           }
           case 0x02:
@@ -219,7 +207,7 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
             */
             x+=ReadByte(image);
             y+=ReadByte(image);
-            q=pixels+y*number_columns+x;
+            q=pixels+y*image->columns+x;
             break;
           }
           default:
@@ -254,8 +242,8 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
           }
         }
       }
-    if (QuantumTick(y,number_rows))
-      ProgressMonitor(LoadImageText,y,number_rows);
+    if (QuantumTick(y,image->rows))
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   (void) ReadByte(image);  /* end of line */
   (void) ReadByte(image);
@@ -277,8 +265,8 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
 %
 %  The format of the EncodeImage method is:
 %
-%    static unsigned int EncodeImage(const unsigned char *pixels,
-%      const unsigned int number_columns,const unsigned int number_rows,
+%    static unsigned int EncodeImage(Image *image,
+%      const unsigned int bytes_per_line,const unsigned char *pixels,
 %      unsigned char *compressed_pixels)
 %
 %  A description of each parameter follows:
@@ -286,23 +274,18 @@ static unsigned int DecodeImage(Image *image,const unsigned int compression,
 %    o status:  Method EncodeImage returns the number of bytes in the
 %      runlength encoded compress_pixels array.
 %
+%    o image:  A pointer to a Image structure.
+%
 %    o pixels:  The address of a byte (8 bits) array of pixel data created by
 %      the compression process.
 %
-%    o number_columns:  An integer value that is the number of columns or
-%      width in pixels of your source image.
-%
-%    o number_rows:  An integer value that is the number of rows or
-%      heigth in pixels of your source image.
-%
 %    o compressed_pixels:  The address of a byte (8 bits) array of compressed
 %      pixel data.
 %
 %
 */
-static unsigned int EncodeImage(const unsigned char *pixels,
-  const unsigned int number_columns,const unsigned int number_rows,
-  unsigned char *compressed_pixels)
+static unsigned int EncodeImage(Image *image,const unsigned int bytes_per_line,
+  const unsigned char *pixels,unsigned char *compressed_pixels)
 {
   int
     y;
@@ -317,21 +300,16 @@ static unsigned int EncodeImage(const unsigned char *pixels,
   register unsigned char
     *q;
 
-  unsigned int
-    bytes_per_line;
-
   /*
     Runlength encode pixels.
   */
-  assert(pixels != (unsigned char *) NULL);
+  assert(image != (Image *) NULL);
+  assert(pixels != (const unsigned char *) NULL);
   assert(compressed_pixels != (unsigned char *) NULL);
   p=pixels;
   q=compressed_pixels;
   i=0;
-  bytes_per_line=number_columns;
-  while ((bytes_per_line & 3) != 0)
-    bytes_per_line++;
-  for (y=0; y < (int) number_rows; y++)
+  for (y=0; y < (int) image->rows; y++)
   {
     for (x=0; x < (int) bytes_per_line; x+=i)
     {
@@ -350,8 +328,8 @@ static unsigned int EncodeImage(const unsigned char *pixels,
     */
     *q++=0x00;
     *q++=0x00;
-    if (QuantumTick(y,number_rows))
-      ProgressMonitor(SaveImageText,y,number_rows);
+    if (QuantumTick(y,image->rows))
+      MagickMonitor(SaveImageText,y,image->rows);
   }
   /*
     End of bitmap.
@@ -395,6 +373,8 @@ static unsigned int IsBMP(const unsigned char *magick,const unsigned int length)
 {
   if (length < 2)
     return(False);
+  if (LocaleNCompare((char *) magick,"BA",2) == 0)
+    return(True);
   if (LocaleNCompare((char *) magick,"BM",2) == 0)
     return(True);
   if (LocaleNCompare((char *) magick,"IC",2) == 0)
@@ -489,18 +469,30 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine if this is a BMP file.
   */
+  memset(&bmp_info,0,sizeof(BMPInfo));
+  bmp_info.ba_offset=0;
   status=ReadBlob(image,2,(char *) magick);
   do
   {
     /*
       Verify BMP identifier.
     */
-    start_position=TellBlob(image)-2;
-    if ((status == False) || (LocaleNCompare((char *) magick,"BM",2) != 0))
+    if (bmp_info.ba_offset == 0)
+      start_position=TellBlob(image)-2;
+    bmp_info.ba_offset=0;
+    while (LocaleNCompare((char *) magick,"BA",2) == 0)
+    {
+      bmp_info.file_size=LSBFirstReadLong(image);
+      bmp_info.ba_offset=LSBFirstReadLong(image);
+      bmp_info.offset_bits=LSBFirstReadLong(image);
+      status=ReadBlob(image,2,(char *) magick);
+    }
+    if ((status == False) || 
+        ((LocaleNCompare((char *) magick,"BM",2) != 0) &&
+         (LocaleNCompare((char *) magick,"CI",2) != 0)))
       ThrowReaderException(CorruptImageWarning,"Not a BMP image file",image);
     bmp_info.file_size=LSBFirstReadLong(image);
-    bmp_info.reserved[0]=LSBFirstReadShort(image);
-    bmp_info.reserved[1]=LSBFirstReadShort(image);
+    (void) LSBFirstReadLong(image);
     bmp_info.offset_bits=LSBFirstReadLong(image);
     bmp_info.size=LSBFirstReadLong(image);
     if (bmp_info.size == 12)
@@ -535,9 +527,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         bmp_info.colors_important=LSBFirstReadLong(image);
         for (i=0; i < ((int) bmp_info.size-40); i++)
           (void) ReadByte(image);
-        if ((bmp_info.compression == 3) &&
-            ((bmp_info.bits_per_pixel == 16) ||
-             (bmp_info.bits_per_pixel == 32)))
+        if ((bmp_info.compression == 3) && ((bmp_info.bits_per_pixel == 16) ||
+            (bmp_info.bits_per_pixel == 32)))
           {
             bmp_info.red_mask=LSBFirstReadShort(image);
             bmp_info.green_mask=LSBFirstReadShort(image);
@@ -633,8 +624,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert run-length encoded raster pixels.
         */
-        status=DecodeImage(image,(unsigned int) bmp_info.compression,
-          (unsigned int) bmp_info.width,image->rows,pixels);
+        status=DecodeImage(image,(unsigned int) bmp_info.compression,pixels);
         if (status == False)
           ThrowReaderException(CorruptImageWarning,"runlength decoding failed",
             image);
@@ -686,7 +676,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -723,7 +713,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -751,22 +741,21 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
       case 16:
       {
-        unsigned char
-          h,
-          l;
+        unsigned short
+          word;
 
         /*
           Convert PseudoColor scanline.
         */
         image->storage_class=DirectClass;
         if (bmp_info.compression == 1)
-          bytes_per_line=image->columns << 1;
+          bytes_per_line=2*image->columns;
         for (y=image->rows-1; y >= 0; y--)
         {
           p=pixels+(image->rows-y-1)*bytes_per_line;
@@ -775,19 +764,27 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (int) image->columns; x++)
           {
-            h=(*p++);
-            l=(*p++);
-            q->red=(MaxRGB*((int) (l & 0x7c) >> 2))/31;
-            q->green=
-              (MaxRGB*(((int) (l & 0x03) << 3)+((int) (h & 0xe0) >> 5)))/31;
-            q->blue=(MaxRGB*((int) (h & 0x1f)))/31;
+            word=(*p++);
+            word|=(*p++ << 8);
+            if (bmp_info.red_mask == 0)
+              {
+                q->red=UpScale(ScaleColor5to8((word >> 10) & 0x1f));
+                q->green=UpScale(ScaleColor5to8((word >> 5) & 0x1f));
+                q->blue=UpScale(ScaleColor5to8(word & 0x1f));
+              }
+            else
+              {
+                q->red=UpScale(ScaleColor5to8((word >> 11) & 0x1f));
+                q->green=UpScale(ScaleColor6to8((word >> 5) & 0x3f));
+                q->blue=UpScale(ScaleColor5to8(word & 0x1f));
+              }
             q++;
           }
           if (!SyncImagePixels(image))
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -816,7 +813,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -848,11 +845,13 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (image->scene >= (image_info->subimage+image_info->subrange-1))
         break;
     *magick='\0';
+    if (bmp_info.ba_offset > 0)
+      SeekBlob(image,bmp_info.ba_offset,SEEK_SET);
     (void) ReadBlob(image,2,(char *) magick);
-    if (LocaleNCompare((char *) magick,"BM",2) == 0)
+    if (IsBMP(magick,2))
       {
         /*
-          Allocate next image structure.
+          Acquire next image structure.
         */
         AllocateNextImage(image_info,image);
         if (image->next == (Image *) NULL)
@@ -861,9 +860,9 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
-  } while (LocaleNCompare((char *) magick,"BM",2) == 0);
+  } while (IsBMP(magick,2));
   while (image->previous != (Image *) NULL)
     image=image->previous;
   CloseBlob(image);
@@ -1042,11 +1041,8 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
         bmp_info.offset_bits+=4*(1 << bmp_info.bits_per_pixel);
         bmp_info.number_colors=1 << bmp_info.bits_per_pixel;
       }
-    bytes_per_line=image->columns;
-    while ((bytes_per_line & 3) != 0)
-      bytes_per_line++;
-    bmp_info.reserved[0]=0;
-    bmp_info.reserved[1]=0;
+    bytes_per_line=4*((image->columns*bmp_info.bits_per_pixel+31)/32);
+    bmp_info.ba_offset=0;
     bmp_info.size=40;
     bmp_info.width=image->columns;
     bmp_info.height=image->rows;
@@ -1086,19 +1082,10 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
         /*
           Convert PseudoClass image to a BMP monochrome image.
         */
-        polarity=Intensity(image->colormap[0]) > (0.5*MaxRGB);
+        polarity=Intensity(image->colormap[0]) > (MaxRGB >> 1);
         if (image->colors == 2)
-          {
-            PixelPacket temp;
-            polarity=
-              Intensity(image->colormap[1]) > Intensity(image->colormap[0]);
-            if (!polarity)
-              {
-                temp=image->colormap[1];
-                image->colormap[1]=image->colormap[0];
-                image->colormap[0]=temp;
-              }
-          }
+          polarity=
+            Intensity(image->colormap[1]) > Intensity(image->colormap[0]);
         for (y=0; y < (int) image->rows; y++)
         {
           p=GetImagePixels(image,0,y,image->columns,1);
@@ -1126,7 +1113,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
            *q++=byte << (8-bit);
          if (image->previous == (Image *) NULL)
            if (QuantumTick(y,image->rows))
-             ProgressMonitor(SaveImageText,y,image->rows);
+             MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -1149,7 +1136,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
           }
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -1176,7 +1163,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
           }
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -1190,7 +1177,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
           /*
             Convert run-length encoded raster pixels.
           */
-          packets=(unsigned int) ((bytes_per_line*(bmp_info.height+2)+1) << 1);
+          packets=(unsigned int) 2*bytes_per_line*(bmp_info.height+2)+1;
           bmp_data=(unsigned char *) AcquireMemory(packets);
           if (pixels == (unsigned char *) NULL)
             {
@@ -1199,8 +1186,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
                 "Memory allocation failed",image);
             }
           bmp_info.file_size-=bmp_info.image_size;
-          bmp_info.image_size=
-            EncodeImage(pixels,image->columns,image->rows,bmp_data);
+          bmp_info.image_size=EncodeImage(image,bytes_per_line,pixels,bmp_data);
           bmp_info.file_size+=bmp_info.image_size;
           LiberateMemory((void **) &pixels);
           pixels=bmp_data;
@@ -1211,8 +1197,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
     */
     (void) WriteBlob(image,2,"BM");
     (void) LSBFirstWriteLong(image,bmp_info.file_size);
-    (void) LSBFirstWriteShort(image,bmp_info.reserved[0]);
-    (void) LSBFirstWriteShort(image,bmp_info.reserved[1]);
+    (void) LSBFirstWriteLong(image,bmp_info.ba_offset);
     (void) LSBFirstWriteLong(image,bmp_info.offset_bits);
     (void) LSBFirstWriteLong(image,bmp_info.size);
     (void) LSBFirstWriteLong(image,bmp_info.width);
@@ -1262,7 +1247,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
