@@ -192,10 +192,7 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
       Decode image header;  header terminates one character beyond a ':'.
     */
     length=MaxTextExtent;
-    values=(char *) AcquireMemory(length);
-    if (values == (char *) NULL)
-      ThrowReaderException(ResourceLimitWarning,"Unable to allocate memory",
-        image);
+    values=AllocateString((char *) NULL);
     GetCacheInfo(&image->cache);
     cache_info=(CacheInfo *) image->cache;
     image->depth=8;
@@ -214,7 +211,7 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
             Read comment-- any text between { }.
           */
           length=MaxTextExtent;
-          comment=(char *) AcquireMemory(length);
+          comment=AllocateString((char *) NULL);
           p=comment;
           for ( ; comment != (char *) NULL; p++)
           {
@@ -303,7 +300,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     (void) QueryColorDatabase(values,&image->border_color);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'c':
@@ -358,7 +356,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     image->columns=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'd':
@@ -381,7 +380,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                       image->dispose=atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'g':
@@ -399,7 +399,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                       &image->chromaticity.green_primary.y);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'i':
@@ -416,7 +417,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                       image->iterations=atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'm':
@@ -438,7 +440,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     (void) CloneString(&image->montage,values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'p':
@@ -479,7 +482,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     image->generic_profiles++;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'r':
@@ -520,7 +524,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     image->rows=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 's':
@@ -531,7 +536,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                     image->scene=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'u':
@@ -549,7 +555,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                           image->units=PixelsPerCentimeterResolution;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'w':
@@ -562,7 +569,8 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
                       &image->chromaticity.white_point.y);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               default:
@@ -602,7 +610,7 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
         /*
           Image directory.
         */
-        image->directory=(char *) AcquireMemory(MaxTextExtent);
+        image->directory=AllocateString((char *) NULL);
         if (image->directory == (char *) NULL)
           ThrowReaderException(CorruptImageWarning,"Unable to read image data",
             image);
@@ -698,8 +706,7 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
               Read image colormap from file.
             */
             packet_size=image->colors > 256 ? 6 : 3;
-            colormap=(unsigned char *)
-              AcquireMemory(packet_size*image->colors);
+            colormap=(unsigned char *) AcquireMemory(packet_size*image->colors);
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitWarning,
                 "Memory allocation failed",image);
@@ -788,7 +795,7 @@ static Image *ReadCACHEImage(const ImageInfo *image_info,
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (c != EOF);
   while (image->previous != (Image *) NULL)
@@ -1098,7 +1105,7 @@ static unsigned int WriteCACHEImage(const ImageInfo *image_info,Image *image)
       }
     SignatureImage(image);
     attribute=GetImageAttribute(image,(char *) NULL);
-    while (attribute != (ImageAttribute *) NULL)
+    for ( ; attribute != (ImageAttribute *) NULL; attribute=attribute->next)
     {
       if (attribute->value != NULL)
         {
@@ -1114,7 +1121,6 @@ static unsigned int WriteCACHEImage(const ImageInfo *image_info,Image *image)
             (void) WriteByte(image,'}');
           (void) WriteByte(image,'\n');
         }
-      attribute=attribute->next;
     }
     (void) strcpy(buffer,"\f\n:\032");
     (void) WriteBlob(image,strlen(buffer),buffer);
@@ -1186,7 +1192,7 @@ static unsigned int WriteCACHEImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
