@@ -174,7 +174,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
@@ -206,7 +206,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
@@ -245,7 +245,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(i,span))
-              ProgressMonitor(LoadImageText,i,span);
+              MagickMonitor(LoadImageText,i,span);
           i++;
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
@@ -271,7 +271,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(i,span))
-              ProgressMonitor(LoadImageText,i,span);
+              MagickMonitor(LoadImageText,i,span);
           i++;
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
@@ -297,7 +297,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(i,span))
-              ProgressMonitor(LoadImageText,i,span);
+              MagickMonitor(LoadImageText,i,span);
           i++;
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
@@ -324,7 +324,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(i,span))
-              ProgressMonitor(LoadImageText,i,span);
+              MagickMonitor(LoadImageText,i,span);
           i++;
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
@@ -354,7 +354,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,ExceptionInfo *exception
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (count > 0);
   LiberateMemory((void **) &scanline);
@@ -510,7 +510,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlob(image,packet_size*image->columns,pixels);
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -532,7 +532,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
           (void) PopImagePixels(image,BlackQuantum,pixels);
           (void) WriteBlob(image,image->columns,pixels);
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(SaveImageText,y,image->rows);
+            MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -564,7 +564,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
             if (status == False)
               ThrowWriterException(FileOpenWarning,"Unable to open file",image);
           }
-        ProgressMonitor(SaveImageText,100,400);
+        MagickMonitor(SaveImageText,100,400);
         for (y=0; y < (int) image->rows; y++)
         {
           if (!GetImagePixels(image,0,y,image->columns,1))
@@ -580,7 +580,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
             if (status == False)
               ThrowWriterException(FileOpenWarning,"Unable to open file",image);
           }
-        ProgressMonitor(SaveImageText,200,400);
+        MagickMonitor(SaveImageText,200,400);
         for (y=0; y < (int) image->rows; y++)
         {
           if (!GetImagePixels(image,0,y,image->columns,1))
@@ -588,7 +588,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
           (void) PopImagePixels(image,MagentaQuantum,pixels);
           (void) WriteBlob(image,image->columns,pixels);
         }
-        ProgressMonitor(SaveImageText,300,400);
+        MagickMonitor(SaveImageText,300,400);
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -607,14 +607,14 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
         }
         if (image_info->interlace == PartitionInterlace)
           (void) strcpy(image->filename,image_info->filename);
-        ProgressMonitor(SaveImageText,400,400);
+        MagickMonitor(SaveImageText,400,400);
         break;
       }
     }
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   LiberateMemory((void **) &pixels);
   if (image_info->adjoin)
