@@ -164,7 +164,7 @@ static Image *ReadGRADIENTImage(const ImageInfo *image_info,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   return(image);
 }
@@ -204,13 +204,6 @@ ModuleExport void RegisterGRADIENTImage(void)
     AllocateString("Gradual passing from one shade to another");
   entry->module=AllocateString("GRADIENT");
   RegisterMagickInfo(entry);
-  entry=SetMagickInfo("GRADATION");
-  entry->decoder=ReadGRADIENTImage;
-  entry->adjoin=False;
-  entry->description=
-    AllocateString("Gradual passing from one shade to another");
-  entry->module=AllocateString("GRADIENT");
-  RegisterMagickInfo(entry);
 }
 
 /*
