@@ -301,7 +301,7 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
     if (!SyncImagePixels(histogram_image))
       break;
     if (QuantumTick(x,histogram_image->columns))
-      ProgressMonitor(SaveImageText,x,histogram_image->columns);
+      MagickMonitor(SaveImageText,x,histogram_image->columns);
   }
   /*
     Free memory resources.
@@ -329,7 +329,7 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
     Write Histogram image as MIFF.
   */
   (void) strcpy(filename,histogram_image->filename);
-  (void) FormatString(histogram_image->filename,"miff:%s",filename);
+  (void) FormatString(histogram_image->filename,"miff:%.1024s",filename);
   status=WriteImage(image_info,histogram_image);
   DestroyImage(histogram_image);
   return(status);
