@@ -100,7 +100,7 @@ static unsigned int IsJPEG(const unsigned char *magick,
 {
   if (length < 3)
     return(False);
-  if (LocaleNCompare((char *) magick,"\377\330\377",3) == 0)
+  if (memcmp(magick,"\377\330\377",3) == 0)
     return(True);
   return(False);
 }
@@ -195,7 +195,8 @@ static unsigned int EmitMessage(j_common_ptr jpeg_info,int level)
     {
       if ((jpeg_info->err->num_warnings == 0) ||
           (jpeg_info->err->trace_level >= 3))
-        ThrowBinaryException(DelegateWarning,(char *) message,image->filename);
+        ThrowBinaryException(CorruptImageWarning,(char *) message,
+          image->filename);
       jpeg_info->err->num_warnings++;
     }
   else
@@ -319,7 +320,7 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
   /*
     Determine length of generic profile.
   */
-  image->generic_profile[i].name=AllocateString("");
+  image->generic_profile[i].name=AllocateString((char *) NULL);
   FormatString(image->generic_profile[i].name,"APP%d",
     jpeg_info->unread_marker-JPEG_APP0);
   length=GetCharacter(jpeg_info) << 8;
@@ -675,52 +676,62 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   scanline[0]=(JSAMPROW) jpeg_pixels;
   for (y=0; y < (int) image->rows; y++)
   {
+    (void) jpeg_read_scanlines(&jpeg_info,scanline,1);
     p=jpeg_pixels;
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
     indexes=GetIndexes(image);
-    (void) jpeg_read_scanlines(&jpeg_info,scanline,1);
-    for (x=0; x < (int) image->columns; x++)
-    {
-      if (jpeg_info.data_precision > QuantumDepth)
-        {
-          if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+    if (jpeg_info.data_precision > QuantumDepth)
+      {
+        if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+          {
+            for (x=0; x < (int) image->columns; x++)
             {
               index=GETJSAMPLE(*p++)/16;
               indexes[x]=index;
-              *q=image->colormap[index];
+              *q++=image->colormap[index];
             }
-          else
+          }
+        else
+          {
+            for (x=0; x < (int) image->columns; x++)
             {
               q->red=(Quantum) (GETJSAMPLE(*p++)/16);
               q->green=(Quantum) (GETJSAMPLE(*p++)/16);
               q->blue=(Quantum) (GETJSAMPLE(*p++)/16);
               if (image->colorspace == CMYKColorspace)
                 q->opacity=(Quantum) (GETJSAMPLE(*p++)/16);
+              q++;
             }
-        }
-      else
-        if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+          }
+      }
+    else
+      if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+        {
+          for (x=0; x < (int) image->columns; x++)
           {
             index=GETJSAMPLE(*p++);
             indexes[x]=index;
-            *q=image->colormap[index];
+            *q++=image->colormap[index];
           }
-        else
+        }
+      else
+        {
+          for (x=0; x < (int) image->columns; x++)
           {
             q->red=(Quantum) UpScale(GETJSAMPLE(*p++));
             q->green=(Quantum) UpScale(GETJSAMPLE(*p++));
             q->blue=(Quantum) UpScale(GETJSAMPLE(*p++));
             if (image->colorspace == CMYKColorspace)
               q->opacity=(Quantum) UpScale(GETJSAMPLE(*p++));
+            q++;
           }
-      q++;
-    }
+        }
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   if (image->colorspace == CMYKColorspace)
     {
@@ -1095,17 +1106,30 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
   jpeg_info.input_components=3;
   jpeg_info.data_precision=image->depth <= 8 ? 8 : 12;
   jpeg_info.in_color_space=JCS_RGB;
-  if (((image_info->colorspace != UndefinedColorspace) ||
-       (image->colorspace != CMYKColorspace)) &&
-       (image_info->colorspace != CMYKColorspace))
-    TransformRGBImage(image,RGBColorspace);
-  else
+  switch (image_info->colorspace)
+  {
+    case CMYKColorspace:
     {
       jpeg_info.input_components=4;
       jpeg_info.in_color_space=JCS_CMYK;
       if (image->colorspace != CMYKColorspace)
         RGBTransformImage(image,CMYKColorspace);
+      break;
     }
+    case YCbCrColorspace:
+    {
+      jpeg_info.in_color_space=JCS_YCbCr;
+      if (image->colorspace != YCbCrColorspace)
+        RGBTransformImage(image,YCbCrColorspace);
+      break;
+    }
+    default:
+    {
+      if (image->colorspace != RGBColorspace)
+        TransformRGBImage(image,RGBColorspace);
+      break;
+    }
+  }
   if (LocaleCompare(image_info->magick,"JPEG24") != 0)
     if (IsGrayImage(image))
       {
@@ -1200,10 +1224,11 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(SaveImageText,y,image->rows);
+            MagickMonitor(SaveImageText,y,image->rows);
         }
       else
-        if (jpeg_info.in_color_space == JCS_RGB)
+        if ((jpeg_info.in_color_space == JCS_RGB) ||
+            (jpeg_info.in_color_space == JCS_YCbCr))
           for (y=0; y < (int) image->rows; y++)
           {
             p=GetImagePixels(image,0,y,image->columns,1);
@@ -1219,7 +1244,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
             }
             (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
           }
         else
           for (y=0; y < (int) image->rows; y++)
@@ -1241,7 +1266,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
             }
             (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
           }
     }
   else
@@ -1259,10 +1284,11 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
         }
         (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
       }
     else
-      if (jpeg_info.in_color_space == JCS_RGB)
+      if ((jpeg_info.in_color_space == JCS_RGB) ||
+          (jpeg_info.in_color_space == JCS_YCbCr))
         for (y=0; y < (int) image->rows; y++)
         {
           p=GetImagePixels(image,0,y,image->columns,1);
@@ -1278,7 +1304,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(SaveImageText,y,image->rows);
+            MagickMonitor(SaveImageText,y,image->rows);
         }
       else
         for (y=0; y < (int) image->rows; y++)
@@ -1292,15 +1318,15 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
             /*
               Convert DirectClass packets to contiguous CMYK scanlines.
             */
-            *q++=(JSAMPLE) DownScale(MaxRGB-p->red);
-            *q++=(JSAMPLE) DownScale(MaxRGB-p->green);
-            *q++=(JSAMPLE) DownScale(MaxRGB-p->blue);
-            *q++=(JSAMPLE) DownScale(MaxRGB-p->opacity);
+            *q++=(JSAMPLE) MaxRGB-DownScale(p->red);
+            *q++=(JSAMPLE) MaxRGB-DownScale(p->green);
+            *q++=(JSAMPLE) MaxRGB-DownScale(p->blue);
+            *q++=(JSAMPLE) MaxRGB-DownScale(p->opacity);
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(SaveImageText,y,image->rows);
+            MagickMonitor(SaveImageText,y,image->rows);
         }
   jpeg_finish_compress(&jpeg_info);
   /*
