@@ -58,7 +58,7 @@
 #include "xwindows.h"
 #endif
 #if defined(HasTTF)
-#if !defined(vms) && !defined(macintosh) && !defined(WIN32)
+#if defined(HAVE_FREETYPE_FREETYPE_H)
 #include "freetype/freetype.h"
 #else
 #include "freetype.h"
@@ -289,7 +289,6 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
     *image;
 
   int
-    id,
     length,
     y;
 
@@ -413,10 +412,10 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
   bounds.x2=(-32000);
   bounds.y1=32000;
   bounds.y2=(-32000);
-  affine.xx=(FT_Fixed) (65536.0*image_info->affine[0]);
-  affine.yx=(FT_Fixed) (-65536.0*image_info->affine[1]);
-  affine.xy=(FT_Fixed) (-65536.0*image_info->affine[2]);
-  affine.yy=(FT_Fixed) (65536.0*image_info->affine[3]);
+  affine.xx=(FT_Fixed) (65536.0*image_info->affine.sx);
+  affine.yx=(FT_Fixed) (-65536.0*image_info->affine.rx);
+  affine.xy=(FT_Fixed) (-65536.0*image_info->affine.ry);
+  affine.yy=(FT_Fixed) (65536.0*image_info->affine.sy);
   glyph=glyphs;
   for (i=0; i < length; i++)
   {
@@ -454,8 +453,8 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
   glyph->id=0;
   image->columns=(unsigned int) (bounds.x2-bounds.x1+1.0);
   image->rows=(unsigned int) (bounds.y2-bounds.y1+1.0);
-  if ((image_info->affine[0] != 0.0) && (image_info->affine[4] != 0.0) ||
-      (image_info->affine[1] != 0.0) && (image_info->affine[2] != 0.0))
+  if (((image_info->affine.sx != 0.0) && (image_info->affine.tx != 0.0)) ||
+      ((image_info->affine.rx != 0.0) && (image_info->affine.ry != 0.0)))
     {
       image->columns+=3;
       image->rows+=3;
@@ -481,30 +480,64 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
     bitmap=(FT_BitmapGlyph) glyph->image;
     if ((bitmap->bitmap.width == 0) || (bitmap->bitmap.rows == 0))
       continue;
-    x=(int) (bitmap->left-bounds.x1+0.5);
-    y=(int) (image->rows-bitmap->top+bounds.y1+0.5);
-    q=GetImagePixels(image,x,y,bitmap->bitmap.width,bitmap->bitmap.rows);
-    if (q == (PixelPacket *) NULL)
-      continue;
     p=bitmap->bitmap.buffer;
     for (y=0; y < bitmap->bitmap.rows; y++)
     {
-      for (x=0; x < bitmap->bitmap.width; x++)
-      {
-        if (*p != 0)
+      x=(int) (bitmap->left-bounds.x1+0.5);
+      i=(int) (bitmap->left-bounds.x1+0.5);
+      q=GetImagePixels(image,x,(int) (image->rows-bitmap->top+bounds.y1+y+0.5),
+        bitmap->bitmap.width,1);
+      if (q == (PixelPacket *) NULL)
+        continue;
+      if (image_info->antialias)
+        for (x=0; x < bitmap->bitmap.width; x++)
+        {
+          if (*p != 0)
+            {
+              *q=image_info->fill;
+              if (image_info->stroke.opacity != TransparentOpacity)
+                if (*p < 255)
+                  *q=image_info->stroke;
+              q->opacity=MaxRGB-(int) UpScale(*p);
+            }
+          p++;
+          q++;
+        }
+      else
+        {
+          int
+            bit;
+
+          for (x=0; x < ((int) bitmap->bitmap.width-7); x+=8)
           {
-            *q=image_info->fill;
-            if (image_info->stroke.opacity != TransparentOpacity)
-              if (*p < 255)
-                *q=image_info->stroke;
-            q->opacity=UpScale(DownScale(MaxRGB)-(*p));
+            for (bit=7; bit >= 0; bit--)
+            {
+              if ((*p) & (0x01 << bit))
+                {
+                  *q=image_info->fill;
+                  q->opacity=OpaqueOpacity;
+                }
+              q++;
+            }
+            p++;
           }
-        p++;
-        q++;
-      }
+          if ((bitmap->bitmap.width % 8) != 0)
+            {
+              for (bit=7; bit >= (int) (8-(bitmap->bitmap.width % 8)); bit--)
+              {
+                if ((*p) & (0x01 << bit))
+                  {
+                    *q=image_info->fill;
+                    q->opacity=OpaqueOpacity;
+                  }
+                q++;
+              }
+              p++;
+            }
+        }
+      if (!SyncImagePixels(image))
+        continue;
     }
-    if (!SyncImagePixels(image))
-      continue;
   }
   /*
     Free resources.
@@ -667,8 +700,8 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
   status|=TT_Set_Instance_Resolutions(instance,(unsigned short)
     image->x_resolution,(unsigned short) image->y_resolution);
   pointsize=image_info->pointsize;
-  if (image_info->affine[1] == 0.0)
-    pointsize*=image_info->affine[0];
+  if (image_info->affine.rx == 0.0)
+    pointsize*=image_info->affine.sx;
   status|=TT_Set_Instance_CharSize(instance,(int) (64.0*pointsize));
   if (status)
     ThrowReaderException(DelegateWarning,"Cannot initialize TTF instance",
@@ -794,9 +827,9 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
     if ((image->columns % 2) != 0)
       p++;
   }
-  if ((image_info->affine[1] == 0.0) && (image_info->affine[2] == 0.0))
+  if ((image_info->affine.rx == 0.0) && (image_info->affine.ry == 0.0))
     {
-      if ((image_info->affine[0] != 1.0) || (image_info->affine[0] != 1.0))
+      if ((image_info->affine.sx != 1.0) || (image_info->affine.sx != 1.0))
         {
           Image
             *scale_image;
@@ -805,8 +838,8 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
             height,
             width;
 
-          width=image_info->affine[0]*image->columns;
-          height=image_info->affine[3]*image->rows;
+          width=image_info->affine.sx*image->columns;
+          height=image_info->affine.sy*image->rows;
           scale_image=ZoomImage(image,width,height,exception);
           if (scale_image != (Image *) NULL)
             {
@@ -817,8 +850,8 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
     }
   else
     {
-      if (((image_info->affine[0]-image_info->affine[3]) == 0.0) &&
-          ((image_info->affine[1]+image_info->affine[2]) == 0.0))
+      if (((image_info->affine.sx-image_info->affine.sy) == 0.0) &&
+          ((image_info->affine.rx+image_info->affine.ry) == 0.0))
         {
           double
             theta;
@@ -826,7 +859,7 @@ static Image *RenderFreetype(const ImageInfo *image_info,const char *text,
           Image
             *rotate_image;
 
-          theta=(180.0/M_PI)*atan2(image_info->affine[1],image_info->affine[0]);
+          theta=(180.0/M_PI)*atan2(image_info->affine.rx,image_info->affine.sx);
           rotate_image=RotateImage(image,theta,exception);
           if (rotate_image != (Image *) NULL)
             {
@@ -911,20 +944,20 @@ static Image *RenderPostscript(const ImageInfo *image_info,const char *text,
   (void) fprintf(file,"} bind def\n");
   font=image_info->font;
   if (font == (char *) NULL)
-    font="Times-Roman";
+    font="Helvetica";
   /*
     Sample to compute bounding box.
   */
-  identity=(image_info->affine[0] == image_info->affine[3]) &&
-    (image_info->affine[1] == 0.0) && (image_info->affine[2] == 0.0);
+  identity=(image_info->affine.sx == image_info->affine.sy) &&
+    (image_info->affine.rx == 0.0) && (image_info->affine.ry == 0.0);
   extent.x=0;
   extent.y=0;
   for (x=0; x <= (Extent(text)+2); x++)
   {
-    point.x=fabs(image_info->affine[0]*x*image_info->pointsize+
-      image_info->affine[2]*2.0*image_info->pointsize);
-    point.y=fabs(image_info->affine[1]*x*image_info->pointsize+
-      image_info->affine[3]*2.0*image_info->pointsize);
+    point.x=fabs(image_info->affine.sx*x*image_info->pointsize+
+      image_info->affine.ry*2.0*image_info->pointsize);
+    point.y=fabs(image_info->affine.rx*x*image_info->pointsize+
+      image_info->affine.sy*2.0*image_info->pointsize);
     if (point.x > extent.x)
       extent.x=point.x;
     if (point.y > extent.y)
@@ -936,9 +969,9 @@ static Image *RenderPostscript(const ImageInfo *image_info,const char *text,
     image_info->pointsize);
   (void) fprintf(file,
     "/%.1024s-ISO dup /%.1024s ReencodeFont findfont setfont\n",font,font);
-  (void) fprintf(file,"[%g %g %g %g 0 0] concat\n",image_info->affine[0],
-    -image_info->affine[1],-image_info->affine[2],
-    image_info->affine[3]);
+  (void) fprintf(file,"[%g %g %g %g 0 0] concat\n",image_info->affine.sx,
+    -image_info->affine.rx,-image_info->affine.ry,
+    image_info->affine.sy);
   if (!identity)
     (void) fprintf(file,"(%.1024s) stringwidth pop -0.5 mul -0.5 rmoveto\n",
       EscapeParenthesis(text));
@@ -962,37 +995,14 @@ static Image *RenderPostscript(const ImageInfo *image_info,const char *text,
       char
         geometry[MaxTextExtent];
 
-      PixelPacket
-        target;
-
       RectangleInfo
         crop_info;
 
-      register PixelPacket
-        *p;
-
-      crop_info.width=0;
-      crop_info.height=(unsigned int) ceil(extent.y/2.0);
-      crop_info.x=0;
+      crop_info=GetImageBoundingBox(image);
+      crop_info.height=(unsigned int) ceil(extent.y/1.75);
       crop_info.y=(int) floor(extent.y/8.0);
-      if (image == (Image *) NULL)
-        return(image);
-      target=GetOnePixel(image,0,0);
-      for (y=0; y < (int) image->rows; y++)
-      {
-        p=GetImagePixels(image,0,y,image->columns,1);
-        if (p == (PixelPacket *) NULL)
-          break;
-        for (x=0; x < (int) image->columns; x++)
-        {
-          if (!ColorMatch(*p,target,0))
-            if (x > (int) crop_info.width)
-              crop_info.width=x;
-          p++;
-        }
-      }
-      (void) sprintf(geometry,"%ux%u%+d%+d",crop_info.width+1,crop_info.height,
-        crop_info.x,crop_info.y);
+      (void) FormatString(geometry,"%ux%u%+d%+d",crop_info.width,
+        crop_info.height,crop_info.x,crop_info.y);
       TransformImage(&image,geometry,(char *) NULL);
     }
   image->matte=True;
@@ -1173,7 +1183,7 @@ static Image *RenderX11(const ImageInfo *image_info,const char *text,
       break;
     for (x=0; x < (int) image->columns; x++)
     {
-      q->opacity=(Quantum) Intensity(*q);
+      q->opacity=(Quantum) (MaxRGB-Intensity(*q));
       q->red=image_info->fill.red;
       q->green=image_info->fill.green;
       q->blue=image_info->fill.blue;
@@ -1188,9 +1198,9 @@ static Image *RenderX11(const ImageInfo *image_info,const char *text,
     if (!SyncImagePixels(image))
       break;
   }
-  if ((image_info->affine[1] == 0.0) && (image_info->affine[2] == 0.0))
+  if ((image_info->affine.rx == 0.0) && (image_info->affine.ry == 0.0))
     {
-      if ((image_info->affine[0] != 1.0) || (image_info->affine[0] != 1.0))
+      if ((image_info->affine.sx != 1.0) || (image_info->affine.sx != 1.0))
         {
           Image
             *scale_image;
@@ -1199,8 +1209,8 @@ static Image *RenderX11(const ImageInfo *image_info,const char *text,
             height,
             width;
 
-          width=(unsigned int) (image_info->affine[0]*image->columns);
-          height=(unsigned int) (image_info->affine[3]*image->rows);
+          width=(unsigned int) (image_info->affine.sx*image->columns);
+          height=(unsigned int) (image_info->affine.sy*image->rows);
           scale_image=ZoomImage(image,width,height,exception);
           if (scale_image != (Image *) NULL)
             {
@@ -1211,8 +1221,8 @@ static Image *RenderX11(const ImageInfo *image_info,const char *text,
     }
   else
     {
-      if (((image_info->affine[0]-image_info->affine[3]) == 0.0) &&
-          ((image_info->affine[1]+image_info->affine[2]) == 0.0))
+      if (((image_info->affine.sx-image_info->affine.sy) == 0.0) &&
+          ((image_info->affine.rx+image_info->affine.ry) == 0.0))
         {
           double
             theta;
@@ -1220,7 +1230,7 @@ static Image *RenderX11(const ImageInfo *image_info,const char *text,
           Image
             *rotate_image;
 
-          theta=(180.0/M_PI)*atan2(image_info->affine[1],image_info->affine[0]);
+          theta=(180.0/M_PI)*atan2(image_info->affine.rx,image_info->affine.sx);
           rotate_image=RotateImage(image,theta,exception);
           if (rotate_image != (Image *) NULL)
             {
