@@ -175,8 +175,8 @@ static unsigned int WriteMATTEImage(const ImageInfo *image_info,Image *image)
   if (!image->matte)
     ThrowWriterException(ResourceLimitWarning,
       "Image does not have a matte channel",image);
-  matte_image=
-    CloneImage(image,image->columns,image->rows,True,&image->exception);
+  matte_image=CloneImage(image,image->columns,image->rows,True,
+    &image->exception);
   if (matte_image == (Image *) NULL)
     return(False);
   if (!AllocateImageColormap(matte_image,MaxRGB+1))
@@ -203,9 +203,9 @@ static unsigned int WriteMATTEImage(const ImageInfo *image_info,Image *image)
       break;
     if (image->previous == (Image *) NULL)
       if (QuantumTick(y,image->rows))
-        ProgressMonitor(SaveImageText,y,image->rows);
+        MagickMonitor(SaveImageText,y,image->rows);
   }
-  (void) FormatString(matte_image->filename,"MIFF:%s",image->filename);
+  (void) FormatString(matte_image->filename,"MIFF:%.1024s",image->filename);
   status=WriteImage(image_info,matte_image);
   DestroyImage(matte_image);
   return(status);
