@@ -324,7 +324,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     (void) QueryColorDatabase(values,&image->border_color);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'c':
@@ -374,7 +375,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     image->columns=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'd':
@@ -397,7 +399,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                       image->dispose=atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'g':
@@ -415,7 +418,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                       &image->chromaticity.green_primary.y);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'i':
@@ -432,7 +436,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                       image->iterations=atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'm':
@@ -454,7 +459,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     (void) CloneString(&image->montage,values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'p':
@@ -495,7 +501,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     image->generic_profiles++;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'r':
@@ -536,7 +543,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     image->rows=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 's':
@@ -547,7 +555,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                     image->scene=(unsigned int) atoi(values);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'u':
@@ -565,7 +574,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                           image->units=PixelsPerCentimeterResolution;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               case 'w':
@@ -578,7 +588,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                       &image->chromaticity.white_point.y);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,values);
+                (void) SetImageAttribute(image,keyword,
+                  *values == '{' ? values+1 : values);
                 break;
               }
               default:
@@ -713,7 +724,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
             /*
               Read image colormap from file.
             */
-            packet_size=image->colors > 256 ? 6 : 3;
+            packet_size=image->depth > 8 ? 6 : 3;
             colormap=(unsigned char *)
               AcquireMemory(packet_size*image->colors);
             if (colormap == (unsigned char *) NULL)
@@ -721,7 +732,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                 "Memory allocation failed",image);
             (void) ReadBlob(image,packet_size*image->colors,colormap);
             p=colormap;
-            if (image->colors <= 256)
+            if (image->depth <= 8)
               for (i=0; i < (int) image->colors; i++)
               {
                 image->colormap[i].red=UpScale(*p++);
@@ -747,7 +758,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
     if (image->storage_class == DirectClass)
       packet_size=image->depth > 8 ? 6 : 3;
     else
-      packet_size=image->colors > 256 ? 2 : 1;
+      packet_size=image->depth > 8 ? 2 : 1;
     if (image->matte || (image->colorspace == CMYKColorspace))
       packet_size+=image->depth > 8 ? 2 : 1;
     if (image->compression == RunlengthEncodedCompression)
@@ -867,7 +878,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                 if (image->storage_class != DirectClass)
                   {
                     index=ReadByte(image);
-                    if (image->colors > 256)
+                    if (image->depth > 8)
                       index=(index << 8)+ReadByte(image);
                     if (index >= image->colors)
                       ThrowReaderException(CorruptImageWarning,
@@ -883,7 +894,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
                         pixel.blue=UpScale(ReadByte(image));
                         if (image->matte ||
                             (image->colorspace == CMYKColorspace))
-                          pixel.opacity=UpScale(MaxRGB-ReadByte(image));
+                          pixel.opacity=MaxRGB-UpScale(ReadByte(image));
                       }
                     else
                       {
@@ -939,7 +950,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,ExceptionInfo *exception
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (c != EOF);
   while (image->previous != (Image *) NULL)
@@ -1119,7 +1130,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
     if (image->storage_class == DirectClass)
       packet_size=image->depth > 8 ? 6 : 3;
     else
-      packet_size=image->colors > 256 ? 2 : 1;
+      packet_size=image->depth > 8 ? 2 : 1;
     if (image->matte || (image->colorspace == CMYKColorspace))
       packet_size+=image->depth > 8 ? 2 : 1;
     if (compression == RunlengthEncodedCompression)
@@ -1294,8 +1305,10 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
       }
     SignatureImage(image);
     attribute=GetImageAttribute(image,(char *) NULL);
-    while (attribute != (ImageAttribute *) NULL)
+    for ( ; attribute != (ImageAttribute *) NULL; attribute=attribute->next)
     {
+      if (*attribute->key == '[')
+        continue;
       FormatString(buffer,"%.1024s=",attribute->key);
       (void) WriteBlob(image,strlen(buffer),buffer);
       for (i=0; i < strlen(attribute->value); i++)
@@ -1307,7 +1320,6 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
       if (i < strlen(attribute->value))
         (void) WriteByte(image,'}');
       (void) WriteByte(image,'\n');
-      attribute=attribute->next;
     }
     (void) strcpy(buffer,"\f\n:\032");
     (void) WriteBlob(image,strlen(buffer),buffer);
@@ -1353,7 +1365,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
         /*
           Allocate colormap.
         */
-        packet_size=image->colors > 256 ? 6 : 3;
+        packet_size=image->depth > 8 ? 6 : 3;
         colormap=(unsigned char *) AcquireMemory(packet_size*image->colors);
         if (colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitWarning,"Memory allocation failed",
@@ -1362,12 +1374,12 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
           Write colormap to file.
         */
         q=colormap;
-        if (image->colors <= 256)
+        if (image->depth <= 8)
           for (i=0; i < (int) image->colors; i++)
           {
-            *q++=image->colormap[i].red;
-            *q++=image->colormap[i].green;
-            *q++=image->colormap[i].blue;
+            *q++=DownScale(image->colormap[i].red);
+            *q++=DownScale(image->colormap[i].green);
+            *q++=DownScale(image->colormap[i].blue);
           }
         else
           for (i=0; i < (int) image->colors; i++)
@@ -1428,7 +1440,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
               {
                 if (image->storage_class != DirectClass)
                   {
-                    if (image->colors > 256)
+                    if (image->depth > 8)
                       *q++=index >> 8;
                     *q++=index;
                   }
@@ -1441,7 +1453,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
                         *q++=DownScale(pixel.blue);
                         if (image->matte ||
                             (image->colorspace == CMYKColorspace))
-                          *q++=DownScale(MaxRGB-pixel.opacity);
+                          *q++=MaxRGB-DownScale(pixel.opacity);
                       }
                     else
                       {
@@ -1564,14 +1576,14 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
             status=WriteBlob(image,packet_size*image->columns,pixels);
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
     }
     LiberateMemory((void **) &pixels);
     LiberateMemory((void **) &compressed_pixels);
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
