@@ -158,7 +158,7 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   SyncImage(image);
   CloseBlob(image);
@@ -326,7 +326,7 @@ static unsigned int WriteMONOImage(const ImageInfo *image_info,Image *image)
     if (bit != 0)
       (void) WriteByte(image,byte >> (8-bit));
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(SaveImageText,y,image->rows);
+      MagickMonitor(SaveImageText,y,image->rows);
   }
   CloseBlob(image);
   return(True);
