@@ -271,7 +271,7 @@ static unsigned int DecodeImage(Image *image,unsigned char *luma,
         }
         length=pcd_length[plane];
         if (QuantumTick(row,image->rows))
-          ProgressMonitor(DecodeImageText,row,image->rows);
+          MagickMonitor(DecodeImageText,row,image->rows);
         continue;
       }
     /*
@@ -626,7 +626,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             image=image->next;
           }
         (void) SetMonitorHandler(handler);
-        ProgressMonitor(LoadImageText,j-1,number_images);
+        MagickMonitor(LoadImageText,j-1,number_images);
       }
       LiberateMemory((void **) &chroma2);
       LiberateMemory((void **) &chroma1);
@@ -712,7 +712,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   LiberateMemory((void **) &chroma2);
   LiberateMemory((void **) &chroma1);
@@ -922,8 +922,8 @@ static unsigned int WritePCDTile(const ImageInfo *image_info,Image *image,
     }
   TransformImage(&tile_image,(char *) NULL,tile_geometry);
   RGBTransformImage(tile_image,YCCColorspace);
-  downsampled_image=ZoomImage(tile_image,tile_image->columns >> 1,
-    tile_image->rows >> 1,&image->exception);
+  downsampled_image=ZoomImage(tile_image,tile_image->columns/2,
+    tile_image->rows/2,&image->exception);
   if (downsampled_image == (Image *) NULL)
     return(False);
   /*
@@ -956,7 +956,7 @@ static unsigned int WritePCDTile(const ImageInfo *image_info,Image *image,
       q++;
     }
     if (QuantumTick(y,tile_image->rows))
-      ProgressMonitor(SaveImageText,y,tile_image->rows);
+      MagickMonitor(SaveImageText,y,tile_image->rows);
   }
   for (i=0; i < 0x800; i++)
     (void) WriteByte(image,'\0');
