@@ -95,9 +95,9 @@ static unsigned int IsPCL(const unsigned char *magick,const unsigned int length)
 {
   if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"\033E\033&",4) == 0)
+  if (memcmp(magick,"\033E\033&",4) == 0)
     return(False);
-  if (LocaleNCompare((char *) magick,"\033E\033",3) == 0)
+  if (memcmp(magick,"\033E\033",3) == 0)
     return(True);
   return(False);
 }
@@ -390,7 +390,7 @@ static unsigned int WritePCLImage(const ImageInfo *image_info,Image *image)
         FormatString(buffer,"\033*b%uW",3*image->columns);
         (void) WriteBlob(image,strlen(buffer),buffer);
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
       }
       (void) strcpy(buffer,"\033*rC");  /* end graphics */
       (void) WriteBlob(image,strlen(buffer),buffer);
@@ -474,7 +474,7 @@ static unsigned int WritePCLImage(const ImageInfo *image_info,Image *image)
             (void) WriteBlob(image,strlen(buffer),buffer);
           }
         if (QuantumTick(y,monochrome_image->rows))
-          ProgressMonitor(SaveImageText,y,monochrome_image->rows);
+          MagickMonitor(SaveImageText,y,monochrome_image->rows);
       }
       (void) strcpy(buffer,"\033*rB");  /* end graphics */
       (void) WriteBlob(image,strlen(buffer),buffer);
