@@ -126,7 +126,7 @@ static unsigned int IsDCX(const unsigned char *magick,const unsigned int length)
 {
   if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"\261\150\336\72",4) == 0)
+  if (memcmp(magick,"\261\150\336\72",4) == 0)
     return(True);
   return(False);
 }
@@ -165,9 +165,9 @@ static unsigned int IsPCX(const unsigned char *magick,const unsigned int length)
 {
   if (length < 2)
     return(False);
-  if (LocaleNCompare((char *) magick,"\12\2",2) == 0)
+  if (memcmp(magick,"\012\002",2) == 0)
     return(True);
-  if (LocaleNCompare((char *) magick,"\12\5",2) == 0)
+  if (memcmp(magick,"\012\005",2) == 0)
     return(True);
   return(False);
 }
@@ -318,7 +318,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     pcx_info.planes=ReadByte(image);
     if ((pcx_info.bits_per_pixel != 8) || (pcx_info.planes == 1))
       if ((pcx_info.version == 3) || (pcx_info.version == 5) ||
-	  ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
+          ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
         image->colors=1 << (pcx_info.bits_per_pixel*pcx_info.planes);
     if (!AllocateImageColormap(image,image->colors))
       ThrowReaderException(ResourceLimitWarning,"Memory allocation failed",
@@ -380,7 +380,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->matte=pcx_info.planes > 3;
     else
       if ((pcx_info.version == 5) ||
-	  ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
+          ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
         {
           /*
             Initialize image colormap.
@@ -556,7 +556,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             q->green=UpScale(*r++);
             q->blue=UpScale(*r++);
             if (image->matte)
-              q->opacity=UpScale(MaxRGB-*r++);
+              q->opacity=MaxRGB-UpScale(*r++);
           }
         q++;
       }
@@ -564,7 +564,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(LoadImageText,y,image->rows);
+          MagickMonitor(LoadImageText,y,image->rows);
     }
     if (image->storage_class == PseudoClass)
       SyncImage(image);
@@ -594,7 +594,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   }
   if (page_table != (unsigned long *) NULL)
@@ -881,7 +881,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
                 case 3:
                 default:
                 {
-                  *q++=DownScale(MaxRGB-p->opacity);
+                  *q++=MaxRGB-DownScale(p->opacity);
                   break;
                 }
               }
@@ -889,7 +889,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
             }
           }
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(SaveImageText,y,image->rows);
+            MagickMonitor(SaveImageText,y,image->rows);
         }
       }
     else
@@ -905,7 +905,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
             *q++=indexes[x];
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
       else
         {
@@ -948,7 +948,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
               *q++=byte << (8-bit);
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
         }
     /*
@@ -985,7 +985,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
           }
         (void) WriteByte(image,previous);
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
       }
     }
     (void) WriteByte(image,pcx_info.colormap_signature);
@@ -995,7 +995,7 @@ static unsigned int WritePCXImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
     if (scene >= 1023)
       break;
   } while (image_info->adjoin);
