@@ -304,9 +304,9 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   FormatString(command,delegate_info.commands,image_info->antialias ? 4 : 1,
     image_info->antialias ? 4 : 1,geometry,density,options,image_info->filename,
     postscript_filename);
-  ProgressMonitor(RenderPostscriptText,0,8);
+  MagickMonitor(RenderPostscriptText,0,8);
   status=SystemCommand(image_info->verbose,command);
-  ProgressMonitor(RenderPostscriptText,7,8);
+  MagickMonitor(RenderPostscriptText,7,8);
   if (status)
     {
       (void) remove(postscript_filename);
@@ -840,10 +840,13 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
         {
           switch (compression)
           {
-            case JPEGCompression: sprintf(buffer,CFormat,"DCTDecode"); break;
-            case LZWCompression: sprintf(buffer,CFormat,"LZWDecode"); break;
-            case ZipCompression: sprintf(buffer,CFormat,"FlateDecode"); break;
-            default: sprintf(buffer,CFormat,"RunLengthDecode"); break;
+            case JPEGCompression:
+              FormatString(buffer,CFormat,"DCTDecode"); break;
+            case LZWCompression:
+              FormatString(buffer,CFormat,"LZWDecode"); break;
+            case ZipCompression:
+              FormatString(buffer,CFormat,"FlateDecode"); break;
+            default: FormatString(buffer,CFormat,"RunLengthDecode"); break;
           }
           (void) WriteBlob(image,strlen(buffer),buffer);
         }
@@ -894,11 +897,10 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
             Write image to temporary file in JPEG format.
           */
           TemporaryFilename(filename);
-          jpeg_image=
-            CloneImage(image,image->columns,image->rows,True,&image->exception);
+          jpeg_image=CloneImage(image,0,0,True,&image->exception);
           if (jpeg_image == (Image *) NULL)
             ThrowWriterException(DelegateWarning,"Unable to clone image",image);
-          (void) FormatString(jpeg_image->filename,"jpeg:%s",filename);
+          (void) FormatString(jpeg_image->filename,"jpeg:%.1024s",filename);
           status=WriteImage(image_info,jpeg_image);
           DestroyImage(jpeg_image);
           if (status == False)
@@ -961,7 +963,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
             }
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
           if (compression == ZipCompression)
             status=
@@ -1016,7 +1018,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
             }
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
           Ascii85Flush(image);
           break;
@@ -1077,7 +1079,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
                   Ascii85Encode(image,byte << (8-bit));
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               Ascii85Flush(image);
               break;
@@ -1119,7 +1121,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               if (compression == ZipCompression)
                 status=ZLIBEncodeImage(image,number_packets,image_info->quality,
@@ -1156,7 +1158,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               Ascii85Flush(image);
               break;
@@ -1409,7 +1411,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
                   *q++=byte << (8-bit);
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,tile_image->rows))
-                    ProgressMonitor(SaveImageText,y,tile_image->rows);
+                    MagickMonitor(SaveImageText,y,tile_image->rows);
               }
               if (compression == ZipCompression)
                 status=ZLIBEncodeImage(image,number_packets,image_info->quality,
@@ -1459,7 +1461,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
                   Ascii85Encode(image,byte << (8-bit));
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,tile_image->rows))
-                    ProgressMonitor(SaveImageText,y,tile_image->rows);
+                    MagickMonitor(SaveImageText,y,tile_image->rows);
               }
               Ascii85Flush(image);
               break;
@@ -1609,7 +1611,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
