@@ -193,7 +193,7 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (!SyncImagePixels(image))
         break;
       if (image->previous == (Image *) NULL)
-        ProgressMonitor(LoadImageText,y,image->rows);
+        MagickMonitor(LoadImageText,y,image->rows);
     }
     if (image->storage_class == PseudoClass)
       SyncImage(image);
@@ -222,7 +222,7 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (status == True);
   while (image->previous != (Image *) NULL)
