@@ -93,12 +93,12 @@ static unsigned int
 */
 static unsigned int IsPS(const unsigned char *magick,const unsigned int length)
 {
-  if (length < 3)
+  if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"\004%!",3) == 0)
-    return(True);
   if (LocaleNCompare((char *) magick,"%!",2) == 0)
     return(True);
+  if (memcmp(magick,"\004%!",3) == 0)
+    return(True);
   return(False);
 }
 
@@ -254,9 +254,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   box.width=0;
   box.height=0;
-  /*
-    Copy Postscript to temporary file.
-  */
   level=0;
   eps_level=0;
   p=command;
@@ -342,7 +339,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   FormatString(command,delegate_info.commands,image_info->antialias ? 4 : 1,
     image_info->antialias ? 4 : 1,geometry,density,options,image_info->filename,
     postscript_filename);
-  ProgressMonitor(RenderPostscriptText,0,8);
+  MagickMonitor(RenderPostscriptText,0,8);
   status=SystemCommand(image_info->verbose,command);
   if (!IsAccessible(image_info->filename))
     {
@@ -357,13 +354,13 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       status=SystemCommand(image_info->verbose,command);
     }
   (void) remove(postscript_filename);
-  ProgressMonitor(RenderPostscriptText,7,8);
+  MagickMonitor(RenderPostscriptText,7,8);
   if (status)
     {
       /*
         Ghostscript has failed-- try the Display Postscript Extension.
       */
-      (void) FormatString((char *) image_info->filename,"dps:%s",filename);
+      (void) FormatString((char *) image_info->filename,"dps:%.1024s",filename);
       image=ReadImage((ImageInfo *) image_info,exception);
       if (image != (Image *) NULL)
         return(image);
@@ -861,7 +858,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     attribute=GetImageAttribute(image,"Label");
     if (attribute != (ImageAttribute *) NULL)
       text_size=(unsigned int)
-	(MultilineCensus(attribute->value)*image_info->pointsize+12);
+        (MultilineCensus(attribute->value)*image_info->pointsize+12);
     width=image->columns;
     height=image->rows;
     x=0;
@@ -940,17 +937,11 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
         (void) WriteBlob(image,strlen(buffer),buffer);
         if (LocaleCompare(image_info->magick,"PS") != 0)
           {
-            (void) strcpy(buffer,"%%Pages: 0\n");
+            (void) strcpy(buffer,"%%Pages: 1\n");
             (void) WriteBlob(image,strlen(buffer),buffer);
           }
         else
           {
-            Image
-              *next_image;
-
-            unsigned int
-              pages;
-
             /*
               Compute the number of pages.
             */
@@ -958,14 +949,8 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             (void) WriteBlob(image,strlen(buffer),buffer);
             (void) strcpy(buffer,"%%PageOrder: Ascend\n");
             (void) WriteBlob(image,strlen(buffer),buffer);
-            pages=1;
-            if (image_info->adjoin)
-              for (next_image=image->next; next_image != (Image *) NULL; )
-              {
-                next_image=next_image->next;
-                pages++;
-              }
-            FormatString(buffer,"%%%%Pages: %u\n",pages);
+            FormatString(buffer,"%%%%Pages: %u\n",
+              image_info->adjoin ? GetNumberScenes(image) : 1);
             (void) WriteBlob(image,strlen(buffer),buffer);
           }
         (void) strcpy(buffer,"%%EndComments\n");
@@ -992,8 +977,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Create preview image.
             */
-            preview_image=CloneImage(image,image->columns,image->rows,True,
-              &image->exception);
+            preview_image=CloneImage(image,0,0,True,&image->exception);
             if (preview_image == (Image *) NULL)
               ThrowWriterException(ResourceLimitWarning,
                 "Memory allocation failed",image);
@@ -1126,8 +1110,6 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
         (void) strcpy(buffer,"userdict begin\n");
         (void) WriteBlob(image,strlen(buffer),buffer);
       }
-    (void) strcpy(buffer,"%%BeginData:\n");
-    (void) WriteBlob(image,strlen(buffer),buffer);
     (void) strcpy(buffer,"DisplayImage\n");
     (void) WriteBlob(image,strlen(buffer),buffer);
     /*
@@ -1159,8 +1141,8 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
         /*
           Dump DirectClass image.
         */
-        FormatString(buffer,"%u %u\n%d\n%d\n",
-          image->columns,image->rows,(int) (image->storage_class == PseudoClass),
+        FormatString(buffer,"%u %u\n%d\n%d\n",image->columns,image->rows,
+          (int) (image->storage_class == PseudoClass),
           (int) (image_info->compression == NoCompression));
         (void) WriteBlob(image,strlen(buffer),buffer);
         switch (image_info->compression)
@@ -1208,7 +1190,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               }
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(SaveImageText,y,image->rows);
+                  MagickMonitor(SaveImageText,y,image->rows);
             }
             break;
           }
@@ -1241,7 +1223,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               }
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(SaveImageText,y,image->rows);
+                  MagickMonitor(SaveImageText,y,image->rows);
             }
             break;
           }
@@ -1279,7 +1261,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
             }
           else
@@ -1338,7 +1320,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                   };
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
             }
           if (count != 0)
@@ -1349,8 +1331,8 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
           /*
             Dump PseudoClass image.
           */
-          FormatString(buffer,"%u %u\n%d\n%d\n0\n",
-            image->columns,image->rows,(int) (image->storage_class == PseudoClass),
+          FormatString(buffer,"%u %u\n%d\n%d\n0\n",image->columns,image->rows,
+            (int) (image->storage_class == PseudoClass),
             (int) (image_info->compression == NoCompression));
           (void) WriteBlob(image,strlen(buffer),buffer);
           /*
@@ -1407,7 +1389,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               break;
             }
@@ -1437,15 +1419,13 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               break;
             }
           }
           (void) WriteByte(image,'\n');
         }
-    (void) strcpy(buffer,"%%EndData\n");
-    (void) WriteBlob(image,strlen(buffer),buffer);
     if (LocaleCompare(image_info->magick,"PS") != 0)
       {
         (void) strcpy(buffer,"end\n");
@@ -1456,14 +1436,14 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
   (void) strcpy(buffer,"%%Trailer\n");
   (void) WriteBlob(image,strlen(buffer),buffer);
-  if (page > 1)
+  if (page > 2)
     {
       FormatString(buffer,"%%%%BoundingBox: %g %g %g %g\n",
         bounds.x1,bounds.y1,bounds.x2,bounds.y2);
