@@ -501,10 +501,10 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
         {
           switch (compression)
           {
-            case JPEGCompression: sprintf(buffer,*q,"DCTDecode"); break;
-            case LZWCompression: sprintf(buffer,*q,"LZWDecode"); break;
-            case ZipCompression: sprintf(buffer,*q,"FlateDecode"); break;
-            default: sprintf(buffer,*q,"RunLengthDecode"); break;
+            case JPEGCompression: FormatString(buffer,*q,"DCTDecode"); break;
+            case LZWCompression: FormatString(buffer,*q,"LZWDecode"); break;
+            case ZipCompression: FormatString(buffer,*q,"FlateDecode"); break;
+            default: FormatString(buffer,*q,"RunLengthDecode"); break;
           }
           (void) WriteBlob(image,strlen(buffer),buffer);
           (void) WriteByte(image,'\n');
@@ -609,11 +609,10 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
             Write image to temporary file in JPEG format.
           */
           TemporaryFilename(filename);
-          jpeg_image=CloneImage(image,image->columns,image->rows,True,
-            &image->exception);
+          jpeg_image=CloneImage(image,0,0,True,&image->exception);
           if (jpeg_image == (Image *) NULL)
             ThrowWriterException(DelegateWarning,"Unable to clone image",image);
-          (void) FormatString(jpeg_image->filename,"jpeg:%s",filename);
+          (void) FormatString(jpeg_image->filename,"jpeg:%.1024s",filename);
           status=WriteImage(image_info,jpeg_image);
           DestroyImage(jpeg_image);
           if (status == False)
@@ -679,7 +678,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
             }
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
           if (compression == ZipCompression)
             status=
@@ -734,7 +733,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
             }
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
           Ascii85Flush(image);
           break;
@@ -797,7 +796,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
                   Ascii85Encode(image,byte << (8-bit));
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               Ascii85Flush(image);
               break;
@@ -852,7 +851,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
                 }
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               if (compression == ZipCompression)
                 status=ZLIBEncodeImage(image,number_packets,image_info->quality,
@@ -886,7 +885,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
                   Ascii85Encode(image,indexes[x]);
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
-                    ProgressMonitor(SaveImageText,y,image->rows);
+                    MagickMonitor(SaveImageText,y,image->rows);
               }
               Ascii85Flush(image);
               break;
@@ -906,7 +905,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
