@@ -159,7 +159,7 @@ ModuleExport void UnregisterPS3Image(void)
 */
 static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
 {
-#define CFormat  "/%s filter "
+#define CFormat  "/%.1024s filter "
 
   char
     buffer[MaxTextExtent],
@@ -338,10 +338,11 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
       {
         switch (compression)
         {
-          case JPEGCompression: sprintf(buffer,CFormat,"DCTDecode"); break;
-          case LZWCompression: sprintf(buffer,CFormat,"LZWDecode"); break;
-          case ZipCompression: sprintf(buffer,CFormat,"FlateDecode"); break;
-          default: sprintf(buffer,CFormat,"RunLengthDecode"); break;
+          case JPEGCompression: FormatString(buffer,CFormat,"DCTDecode"); break;
+          case LZWCompression: FormatString(buffer,CFormat,"LZWDecode"); break;
+          case ZipCompression:
+            FormatString(buffer,CFormat,"FlateDecode"); break;
+          default: FormatString(buffer,CFormat,"RunLengthDecode"); break;
         }
         (void) WriteBlob(image,strlen(buffer),buffer);
       }
@@ -367,8 +368,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
           Write image to temporary file in JPEG format.
         */
         TemporaryFilename(filename);
-        jpeg_image=CloneImage(image,image->columns,image->rows,True,
-          &image->exception);
+        jpeg_image=CloneImage(image,0,0,True,&image->exception);
         if (jpeg_image == (Image *) NULL)
           ThrowWriterException(DelegateWarning,"Unable to clone image",image);
         (void) FormatString(jpeg_image->filename,"jpeg:%s",filename);
@@ -412,7 +412,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (int) image->columns; x++)
           {
-            *q++=DownScale(MaxRGB-p->opacity);
+            *q++=MaxRGB-DownScale(p->opacity);
             *q++=DownScale(p->red);
             *q++=DownScale(p->green);
             *q++=DownScale(p->blue);
@@ -420,7 +420,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
           }
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         if (compression == ZipCompression)
           status=
@@ -451,7 +451,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (int) image->columns; x++)
           {
-            Ascii85Encode(image,DownScale(MaxRGB-p->opacity));
+            Ascii85Encode(image,MaxRGB-DownScale(p->opacity));
             Ascii85Encode(image,DownScale(p->red));
             Ascii85Encode(image,DownScale(p->green));
             Ascii85Encode(image,DownScale(p->blue));
@@ -459,7 +459,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
           }
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         Ascii85Flush(image);
         break;
@@ -552,7 +552,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
