@@ -134,28 +134,31 @@ static unsigned int DecodeImage(Image *image,const int channel)
           {
             case 0:
             {
-              q->red=pixel;
+              q->red=UpScale(pixel);
               if (image->storage_class == PseudoClass)
                 {
-                  *indexes=pixel;
+                  *indexes=UpScale(pixel);
                   *q=image->colormap[pixel];
                 }
               break;
             }
             case 1:
             {
-              q->green=pixel;
+              q->green=UpScale(pixel);
               break;
             }
             case 2:
             {
-              q->blue=pixel;
+              q->blue=UpScale(pixel);
               break;
             }
             case 3:
             default:
             {
-              q->opacity=MaxRGB-pixel;
+              if (image->colorspace == CMYKColorspace)
+                q->opacity=UpScale(pixel);
+              else
+                q->opacity=MaxRGB-UpScale(pixel);
               break;
             }
           }
@@ -178,28 +181,31 @@ static unsigned int DecodeImage(Image *image,const int channel)
       {
         case 0:
         {
-          q->red=pixel;
+          q->red=UpScale(pixel);
           if (image->storage_class == PseudoClass)
             {
-              *indexes=pixel;
+              *indexes=UpScale(pixel);
               *q=image->colormap[pixel];
             }
           break;
         }
         case 1:
         {
-          q->green=pixel;
+          q->green=UpScale(pixel);
           break;
         }
         case 2:
         {
-          q->blue=pixel;
+          q->blue=UpScale(pixel);
           break;
         }
         case 3:
         default:
         {
-          q->opacity=MaxRGB-pixel;
+          if (image->colorspace == CMYKColorspace)
+            q->opacity=UpScale(pixel);
+          else
+            q->opacity=MaxRGB-UpScale(pixel);
           break;
         }
       }
@@ -327,8 +333,10 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     char
       blendkey[4];
 
+    Quantum
+      opacity;
+
     unsigned char
-      opacity,
       clipping,
       flags;
 
@@ -508,7 +516,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           ThrowReaderException(CorruptImageWarning,"Not a PSD image file",
             image);
         (void) ReadBlob(image,4,(char *) layer_info[i].blendkey);
-        layer_info[i].opacity=MaxRGB-ReadByte(image);
+        layer_info[i].opacity=MaxRGB-UpScale(ReadByte(image));
         layer_info[i].clipping=ReadByte(image);
         layer_info[i].flags=ReadByte(image);
         (void) ReadByte(image);  /* filler */
@@ -603,8 +611,12 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   case 3:
                   default:
                   {
-                    (void) PushImagePixels(layer_info[i].image,OpacityQuantum,
-                      scanline);
+                    if (layer_info[i].image->colorspace == CMYKColorspace)
+                      (void) PushImagePixels(layer_info[i].image,BlackQuantum,
+                        scanline);
+                    else
+                      (void) PushImagePixels(layer_info[i].image,OpacityQuantum,
+                        scanline);
                     break;
                   }
                 }
@@ -653,7 +665,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 for (x=0; x < (int) layer_info[i].image->columns; x++)
                 {
-                  q->opacity=MaxRGB-(unsigned long)
+                  q->opacity=(unsigned long)
                     (q->opacity*layer_info[i].opacity)/MaxRGB;
                   q++;
                 }
@@ -666,9 +678,6 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       for (i=0; i < 4; i++)
         (void) ReadByte(image);
     }
-  /*
-    Convert pixels to Runlength encoded.
-  */
   compression=MSBFirstReadShort(image);
   SetImage(image,OpaqueOpacity);
   if (compression != 0)
@@ -679,13 +688,10 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       for (i=0; i < (int) (image->rows*psd_info.channels); i++)
         (void) MSBFirstReadShort(image);
       for (i=0; i < (int) psd_info.channels; i++)
-        (void) DecodeImage(image,i);
+        (void) DecodeImage(image,image->matte ? i-1 : i);
     }
   else
     {
-      int
-        channel_map[24];
-
       /*
         Read uncompressed pixel data as separate planes.
       */
@@ -698,8 +704,6 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         if (image->depth > 8)
           packet_size++;
-      for (i=0; i < psd_info.channels; i++)
-        channel_map[i]=!image->matte ? i : i-1;
       scanline=(unsigned char *) AcquireMemory(packet_size*image->columns);
       if (scanline == (unsigned char *) NULL)
         ThrowReaderException(ResourceLimitWarning,"Memory allocation failed",
@@ -712,7 +716,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           status=ReadBlob(image,packet_size*image->columns,(char *) scanline);
           if ((status == False) || (q == (PixelPacket *) NULL))
             break;
-          switch (channel_map[i])
+          switch (i)
           {
             case 0:
             {
@@ -735,7 +739,10 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 3:
             default:
             {
-              (void) PushImagePixels(image,OpacityQuantum,scanline);
+              if (image->colorspace == CMYKColorspace)
+                (void) PushImagePixels(image,BlackQuantum,scanline);
+              else
+                (void) PushImagePixels(image,OpacityQuantum,scanline);
               break;
             }
           }
@@ -769,6 +776,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       }
     }
+  (void) IsMatteImage(image);
   for (i=0; i < number_layers; i++)
   {
     /*
@@ -915,7 +923,8 @@ static unsigned int WritePSDImage(const ImageInfo *image_info,Image *image)
     MSBFirstWriteShort(image,image->matte ? 4 : 3);
   MSBFirstWriteLong(image,image->rows);
   MSBFirstWriteLong(image,image->columns);
-  MSBFirstWriteShort(image,image->storage_class == PseudoClass ? 8 : image->depth);
+  MSBFirstWriteShort(image,
+    image->storage_class == PseudoClass ? 8 : image->depth);
   if (((image_info->colorspace != UndefinedColorspace) ||
        (image->colorspace != CMYKColorspace)) &&
        (image_info->colorspace != CMYKColorspace))
