@@ -308,7 +308,7 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 case 3:
                 default:
                 {
-                  q->opacity=UpScale(MaxRGB-byte);
+                  q->opacity=MaxRGB-UpScale(byte);
                   break;
                 }
               }
@@ -348,7 +348,7 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 3:
             default:
             {
-              q->opacity=UpScale(MaxRGB-byte);
+              q->opacity=MaxRGB-UpScale(byte);
               break;
             }
           }
@@ -361,7 +361,7 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     }
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   CloseBlob(image);
   return(image);
