@@ -89,7 +89,7 @@ static unsigned int IsRLE(const unsigned char *magick,const unsigned int length)
 {
   if (length < 2)
     return(False);
-  if (LocaleNCompare((char *) magick,"\122\314",2) == 0)
+  if (memcmp(magick,"\122\314",2) == 0)
     return(True);
   return(False);
 }
@@ -184,7 +184,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Determine if this is a RLE file.
   */
   status=ReadBlob(image,2,(char *) magick);
-  if ((status == False) || (LocaleNCompare(magick,"\122\314",2) != 0))
+  if ((status == False) || (memcmp(magick,"\122\314",2) != 0))
     ThrowReaderException(CorruptImageWarning,"Not a RLE image file",image);
   do
   {
@@ -423,14 +423,14 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
             q->green=UpScale(*p++);
             q->blue=UpScale(*p++);
             if (image->matte)
-              q->opacity=UpScale(MaxRGB-*p++);
+              q->opacity=MaxRGB-UpScale(*p++);
             q++;
           }
           if (!SyncImagePixels(image))
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
       }
     else
@@ -481,7 +481,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,y,image->rows);
+                  MagickMonitor(LoadImageText,y,image->rows);
             }
             SyncImage(image);
           }
@@ -500,14 +500,14 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 q->red=image->colormap[*p++].red;
                 q->green=image->colormap[*p++].green;
                 q->blue=image->colormap[*p++].blue;
-                q->opacity=UpScale(MaxRGB-*p++);
+                q->opacity=MaxRGB-UpScale(*p++);
                 q++;
               }
               if (!SyncImagePixels(image))
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,y,image->rows);
+                  MagickMonitor(LoadImageText,y,image->rows);
             }
             LiberateMemory((void **) &image->colormap);
             image->colormap=(PixelPacket *) NULL;
@@ -526,7 +526,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     (void) ReadByte(image);
     status=ReadBlob(image,2,(char *) magick);
-    if ((status == True) && (LocaleNCompare(magick,"\122\314",2) == 0))
+    if ((status == True) && (memcmp(magick,"\122\314",2) == 0))
       {
         /*
           Allocate next image structure.
@@ -538,9 +538,9 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
-  } while ((status == True) && (LocaleNCompare(magick,"\122\314",2) == 0));
+  } while ((status == True) && (memcmp(magick,"\122\314",2) == 0));
   while (image->previous != (Image *) NULL)
     image=image->previous;
   CloseBlob(image);
