@@ -120,7 +120,7 @@ static unsigned int IsSGI(const unsigned char *magick,const unsigned int length)
 {
   if (length < 2)
     return(False);
-  if (LocaleNCompare((char *) magick,"\001\332",2) == 0)
+  if (memcmp(magick,"\001\332",2) == 0)
     return(True);
   return(False);
 }
@@ -467,7 +467,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,y,image->rows);
+                  MagickMonitor(LoadImageText,y,image->rows);
             }
           }
         else
@@ -482,7 +482,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               q->red=UpScale(*p);
               q->green=UpScale(*(p+1));
               q->blue=UpScale(*(p+2));
-              q->opacity=UpScale(MaxRGB-*(p+3));
+              q->opacity=MaxRGB-UpScale(*(p+3));
               p+=4;
               q++;
             }
@@ -490,7 +490,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(LoadImageText,y,image->rows);
+                MagickMonitor(LoadImageText,y,image->rows);
           }
       }
     else
@@ -524,7 +524,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(LoadImageText,y,image->rows);
+                  MagickMonitor(LoadImageText,y,image->rows);
             }
           }
         else
@@ -545,7 +545,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(LoadImageText,y,image->rows);
+                MagickMonitor(LoadImageText,y,image->rows);
           }
         SyncImage(image);
       }
@@ -569,7 +569,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (iris_info.magic == 0x01DA);
   while (image->previous != (Image *) NULL)
@@ -816,12 +816,12 @@ static unsigned int WriteSGIImage(const ImageInfo *image_info,Image *image)
         *q++=DownScale(p->red);
         *q++=DownScale(p->green);
         *q++=DownScale(p->blue);
-        *q++=DownScale(MaxRGB-p->opacity);
+        *q++=MaxRGB-DownScale(p->opacity);
         p++;
       }
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
     }
     if (image_info->compression == NoCompression)
       {
@@ -908,7 +908,7 @@ static unsigned int WriteSGIImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
