@@ -147,8 +147,8 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
   DestroyImageInfo(clone_info);
   if (stegano_image == (Image *) NULL)
     return((Image *) NULL);
-  clone_image=
-    CloneImage(stegano_image,image->columns,image->rows,True,exception);
+  clone_image=CloneImage(stegano_image,image->columns,image->rows,True,
+    exception);
   DestroyImage(image);
   if (clone_image == (Image *) NULL)
     return((Image *) NULL);
@@ -186,7 +186,7 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
     if (shift < 0)
       break;
     if (QuantumTick(y,stegano_image->rows))
-      ProgressMonitor(LoadImageText,y,stegano_image->rows);
+      MagickMonitor(LoadImageText,y,stegano_image->rows);
   }
   SyncImage(image);
   DestroyImage(stegano_image);
