@@ -95,7 +95,7 @@ static unsigned int IsSUN(const unsigned char *magick,const unsigned int length)
 {
   if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"\131\246\152\225",4) == 0)
+  if (memcmp(magick,"\131\246\152\225",4) == 0)
     return(True);
   return(False);
 }
@@ -434,7 +434,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,y,image->rows);
+            MagickMonitor(LoadImageText,y,image->rows);
       }
     else
       if (image->storage_class == PseudoClass)
@@ -452,7 +452,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
       else
         for (y=0; y < (int) image->rows; y++)
@@ -463,7 +463,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (x=0; x < (int) image->columns; x++)
           {
             if (image->matte)
-              q->opacity=UpScale(MaxRGB-*p++);
+              q->opacity=MaxRGB-UpScale(*p++);
             if (sun_info.type == RT_STANDARD)
               {
                 q->blue=UpScale(*p++);
@@ -490,7 +490,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
     if (image->storage_class == PseudoClass)
       SyncImage(image);
@@ -514,7 +514,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (sun_info.magic == 0x59a66a95);
   while (image->previous != (Image *) NULL)
@@ -755,7 +755,7 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (int) image->columns; x++)
           {
             if (image->matte)
-              *q++=DownScale(MaxRGB-p->opacity);
+              *q++=MaxRGB-DownScale(p->opacity);
             *q++=DownScale(p->red);
             *q++=DownScale(p->green);
             *q++=DownScale(p->blue);
@@ -766,7 +766,7 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlob(image,q-pixels,(char *) pixels);
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         LiberateMemory((void **) &pixels);
       }
@@ -814,7 +814,7 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
               (void) WriteByte(image,0);  /* pad scanline */
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
         }
       else
@@ -846,13 +846,13 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
               (void) WriteByte(image,0);  /* pad scanline */
             if (image->previous == (Image *) NULL)
               if (QuantumTick(y,image->rows))
-                ProgressMonitor(SaveImageText,y,image->rows);
+                MagickMonitor(SaveImageText,y,image->rows);
           }
         }
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
