@@ -102,10 +102,9 @@ static unsigned int IsTIFF(const unsigned char *magick,
 {
   if (length < 4)
     return(False);
-  if ((magick[0] == 0x4D) && (magick[1] == 0x4D))
-    if ((magick[2] == 0x00) && (magick[3] == 0x2A))
-      return(True);
-  if (LocaleNCompare((char *) magick,"\111\111\052\000",4) == 0)
+  if (memcmp(magick,"\115\115\000\052",4) == 0)
+    return(True);
+  if (memcmp(magick,"\111\111\052\000",4) == 0)
     return(True);
   return(False);
 }
@@ -273,6 +272,7 @@ static unsigned int TIFFWarningHandler(const char *module,const char *format,
   (void) strcat(p,".");
   if (image != (Image *) NULL)
     ThrowBinaryException(DelegateWarning,message,image->filename);
+  return(True);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
@@ -493,6 +493,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       {
         TIFFClose(tiff);
         CloseBlob(image);
+        LiberateSemaphore(tiff_semaphore);
         return(image);
       }
     if (units == RESUNIT_INCH)
@@ -530,7 +531,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     if (samples_per_pixel > 1)
       {
         method=2;
-        if ((samples_per_pixel == 3) && (photometric == PHOTOMETRIC_RGB) &&
+        if ((samples_per_pixel > 2) && (photometric == PHOTOMETRIC_RGB) &&
             (interlace == PLANARCONFIG_CONTIG))
           method=1;
         if (image->colorspace == CMYKColorspace)
@@ -741,7 +742,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
         LiberateMemory((void **) &scanline);
         LiberateMemory((void **) &quantum_scanline);
@@ -809,7 +810,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
         LiberateMemory((void **) &scanline);
         break;
@@ -830,8 +831,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           &sample_info);
         image->matte=
           ((extra_samples == 1) && (sample_info[0] == EXTRASAMPLE_ASSOCALPHA));
-        pixels=(uint32 *) AcquireMemory((image->columns*image->rows+
-          image->columns)*sizeof(uint32));
+        pixels=(uint32 *) AcquireMemory((4*image->columns*image->rows+
+          2*image->columns)*sizeof(uint32));
         if (pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -839,7 +840,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             ThrowReaderException(ResourceLimitWarning,
               "Memory allocation failed",image);
           }
-        status=TIFFReadRGBAImage(tiff,image->columns,image->rows,pixels,0);
+        status=TIFFReadRGBAImage(tiff,image->columns,image->rows,
+          pixels+image->columns*sizeof(uint32),0);
         if (status == False)
           {
             LiberateMemory((void **) &pixels);
@@ -851,7 +853,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         /*
           Convert image to DirectClass pixel packets.
         */
-        p=pixels+image->columns*image->rows-1;
+        p=pixels+image->columns*image->rows+image->columns*sizeof(uint32)-1;
         for (y=0; y < (int) image->rows; y++)
         {
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -864,7 +866,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             q->green=UpScale(TIFFGetG(*p));
             q->blue=UpScale(TIFFGetB(*p));
             if (image->matte)
-              q->opacity=UpScale(MaxRGB-TIFFGetA(*p));
+              q->opacity=MaxRGB-UpScale(TIFFGetA(*p));
             p--;
             q--;
           }
@@ -872,7 +874,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,y,image->rows);
+              MagickMonitor(LoadImageText,y,image->rows);
         }
         LiberateMemory((void **) &pixels);
         break;
@@ -894,10 +896,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         if (image->next == (Image *) NULL)
           {
             DestroyImages(image);
+            LiberateSemaphore(tiff_semaphore);
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImageText,image->scene-1,image->scene);
+        MagickMonitor(LoadImageText,image->scene-1,image->scene);
       }
   } while (status == True);
   TIFFClose(tiff);
@@ -1443,7 +1446,8 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
     if (compress_tag == COMPRESSION_JPEG)
       TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size+(8-(strip_size % 8)));
     else
-      if (compress_tag == COMPRESSION_CCITTFAX4)
+      if ((compress_tag == COMPRESSION_CCITTFAX4) ||
+          (compress_tag == COMPRESSION_ADOBE_DEFLATE))
         TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,image->rows);
       else
         TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size);
@@ -1563,7 +1567,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(SaveImageText,y,image->rows);
+                  MagickMonitor(SaveImageText,y,image->rows);
             }
             break;
           }
@@ -1581,7 +1585,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
               if (TIFFWritePixels(tiff,(char *) scanline,y,0,image) < 0)
                 break;
             }
-            ProgressMonitor(SaveImageText,100,400);
+            MagickMonitor(SaveImageText,100,400);
             for (y=0; y < (int) image->rows; y++)
             {
               if (!GetImagePixels(image,0,y,image->columns,1))
@@ -1590,7 +1594,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
               if (TIFFWritePixels(tiff,(char *) scanline,y,1,image) < 0)
                 break;
             }
-            ProgressMonitor(SaveImageText,200,400);
+            MagickMonitor(SaveImageText,200,400);
             for (y=0; y < (int) image->rows; y++)
             {
               if (!GetImagePixels(image,0,y,image->columns,1))
@@ -1599,7 +1603,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
               if (TIFFWritePixels(tiff,(char *) scanline,y,2,image) < 0)
                 break;
             }
-            ProgressMonitor(SaveImageText,300,400);
+            MagickMonitor(SaveImageText,300,400);
             if (image->matte)
               for (y=0; y < (int) image->rows; y++)
               {
@@ -1609,7 +1613,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
                 if (TIFFWritePixels(tiff,(char *) scanline,y,3,image) < 0)
                   break;
               }
-            ProgressMonitor(SaveImageText,400,400);
+            MagickMonitor(SaveImageText,400,400);
             break;
           }
         }
@@ -1631,7 +1635,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -1700,7 +1704,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
                 break;
               if (image->previous == (Image *) NULL)
                 if (QuantumTick(y,image->rows))
-                  ProgressMonitor(SaveImageText,y,image->rows);
+                  MagickMonitor(SaveImageText,y,image->rows);
             }
             break;
           }
@@ -1746,7 +1750,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(SaveImageText,y,image->rows);
+              MagickMonitor(SaveImageText,y,image->rows);
         }
         break;
       }
@@ -1758,7 +1762,7 @@ static unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   while (image->previous != (Image *) NULL)
     image=image->previous;
