@@ -90,8 +90,6 @@
 */
 static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-#define ScaleColor5to8(x)  ((x) << 3)
-
   typedef struct _TIMInfo
   {
     unsigned long
@@ -192,7 +190,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (i=0; i < (int) image->colors; i++)
         {
           word=(*p++);
-          word=word | (*p++ << 8);
+          word|=(*p++ << 8);
           image->colormap[i].blue=UpScale(ScaleColor5to8((word >> 10) & 0x1f));
           image->colormap[i].green=UpScale(ScaleColor5to8((word >> 5) & 0x1f));
           image->colormap[i].red=UpScale(ScaleColor5to8(word & 0x1f));
@@ -251,7 +249,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+            MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -272,7 +270,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+            MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -290,7 +288,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (x=0; x < (int) image->columns; x++)
           {
             word=(*p++);
-            word=word | (*p++ << 8);
+            word|=(*p++ << 8);
             q->blue=UpScale(ScaleColor5to8((word >> 10) & 0x1f));
             q->green=UpScale(ScaleColor5to8((word >> 5) & 0x1f));
             q->red=UpScale(ScaleColor5to8(word & 0x1f));
@@ -299,7 +297,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+            MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -324,7 +322,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);
+            MagickMonitor(LoadImageText,image->rows-y-1,image->rows);
         }
         break;
       }
@@ -350,7 +348,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (tim_info.id == 0x00000010);
   while (image->previous != (Image *) NULL)
