@@ -54,6 +54,11 @@
 */
 #include "magick.h"
 #include "defines.h"
+/*
+  Forward declarations.
+*/
+static unsigned int
+  WriteVIDImage(const ImageInfo *,Image *);
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -139,9 +144,6 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   image=(Image *) NULL;
   clone_info=CloneImageInfo(image_info);
-  if (clone_info == (ImageInfo *) NULL)
-    return((Image *) NULL);
-  (void) CloneString(&clone_info->size,DefaultTileGeometry);
   for (i=0; i < number_files; i++)
   {
     handler=SetMonitorHandler((MonitorHandler) NULL);
@@ -151,7 +153,9 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (next_image != (Image *) NULL)
       {
         (void) SetImageAttribute(next_image,"Label",DefaultTileLabel);
-        TransformImage(&next_image,(char *) NULL,DefaultTileGeometry);
+        TransformImage(&next_image,(char *) NULL,
+          clone_info->size == (char *) NULL ? DefaultTileGeometry :
+          clone_info->size);
         if (image == (Image *) NULL)
           image=next_image;
         else
@@ -162,7 +166,7 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
     (void) SetMonitorHandler(handler);
-    ProgressMonitor(LoadImageText,i,number_files);
+    MagickMonitor(LoadImageText,i,number_files);
   }
   DestroyImageInfo(clone_info);
   LiberateMemory((void **) &filelist);
@@ -214,6 +218,7 @@ ModuleExport void RegisterVIDImage(void)
 
   entry=SetMagickInfo("VID");
   entry->decoder=ReadVIDImage;
+  entry->encoder=WriteVIDImage;
   entry->description=AllocateString("Visual Image Directory");
   entry->module=AllocateString("VID");
   RegisterMagickInfo(entry);
@@ -242,3 +247,61 @@ ModuleExport void UnregisterVIDImage(void)
 {
   UnregisterMagickInfo("VID");
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   W r i t e V I D I m a g e                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method WriteVIDImage writes an image to a file in VID X image format.
+%
+%  The format of the WriteVIDImage method is:
+%
+%      unsigned int WriteVIDImage(const ImageInfo *image_info,Image *image)
+%
+%  A description of each parameter follows.
+%
+%    o status: Method WriteVIDImage return True if the image is written.
+%      False is returned is there is a memory shortage or if the image file
+%      fails to write.
+%
+%    o image_info: Specifies a pointer to an ImageInfo structure.
+%
+%    o image:  A pointer to a Image structure.
+%
+%
+*/
+static unsigned int WriteVIDImage(const ImageInfo *image_info,Image *image)
+{
+  Image
+    *montage_image;
+
+  MontageInfo
+    *montage_info;
+
+  register Image
+    *p;
+
+  unsigned int
+    status;
+
+  /*
+    Create the visual image directory.
+  */
+  for (p=image; p != (Image *) NULL; p=p->next)
+    (void) SetImageAttribute(p,"Label",DefaultTileLabel);
+  montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
+  montage_image=MontageImages(image,montage_info,&image->exception);
+  if (montage_image == (Image *) NULL)
+    ThrowWriterException(CorruptImageWarning,"unable to write VID image",image);
+  FormatString(montage_image->filename,"miff:%.1024s",image->filename);
+  status=WriteImage(image_info,montage_image);
+  DestroyImages(montage_image);
+  return(status);
+}
