@@ -85,7 +85,7 @@ static unsigned int IsWPG(const unsigned char *magick,const unsigned int length)
 {
   if (length < 4)
     return(False);
-  if (LocaleNCompare((char *) magick,"\377WPC",4) == 0)
+  if (memcmp(magick,"\377WPC",4) == 0)
     return(True);
   return(False);
 }
@@ -154,7 +154,7 @@ register IndexPacket *indexes;
                  break;
 /*            if (image->previous == (Image *) NULL)
                  if (QuantumTick(y,image->rows))
-                   ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);*/
+                   MagickMonitor(LoadImageText,image->rows-y-1,image->rows);*/
             break;
             }
       case 2:  /* Convert PseudoColor scanline. */
@@ -204,7 +204,7 @@ register IndexPacket *indexes;
                  break;
 /*         if (image->previous == (Image *) NULL)
                  if (QuantumTick(y,image->rows))
-                   ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);*/
+                   MagickMonitor(LoadImageText,image->rows-y-1,image->rows);*/
            break;
            }
 	    
@@ -235,7 +235,7 @@ register IndexPacket *indexes;
                  break;
 /*         if (image->previous == (Image *) NULL)
                  if (QuantumTick(y,image->rows))
-                   ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);*/
+                   MagickMonitor(LoadImageText,image->rows-y-1,image->rows);*/
            break;
            }
       case 8: /* Convert PseudoColor scanline. */
@@ -254,7 +254,7 @@ register IndexPacket *indexes;
                  break;
 /*           if (image->previous == (Image *) NULL)
                  if (QuantumTick(y,image->rows))
-                   ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);*/
+                   MagickMonitor(LoadImageText,image->rows-y-1,image->rows);*/
            }
            break;
 	   
@@ -273,7 +273,7 @@ register IndexPacket *indexes;
             break;
 /*          if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              ProgressMonitor(LoadImageText,image->rows-y-1,image->rows);*/
+              MagickMonitor(LoadImageText,image->rows-y-1,image->rows);*/
           break;	   
        }
 }
@@ -352,7 +352,7 @@ long ldblk;
 }
 
 #define InsertRByte(b) {BImgBuff[x]=b;x++;if(x>=ldblk) {InsertRow(BImgBuff,image->rows-y-1,image);x=0;y++;}}
-int UnpackWPG2Raster(Image *image)
+static int UnpackWPG2Raster(Image *image)
 {
 unsigned x,y,i;
 unsigned char bbuf,RunCount;
@@ -421,7 +421,8 @@ long ldblk;
  return(0);
 }
 
-Image *ExtractPostscript(Image *image,const ImageInfo *image_info,long PS_Offset,long PS_Size)
+static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
+  long PS_Offset,long PS_Size)
 {
 /*char Filename[MaxTextExtent];*/
 FILE *f;
@@ -429,10 +430,10 @@ ImageInfo *clone_info;
 ExceptionInfo exception;
 Image *image2;
 
-if((clone_info=CloneImageInfo(image_info))==NULL) return(image);
+if ((clone_info=CloneImageInfo(image_info)) == NULL) return(image);
 TemporaryFilename((char *) clone_info->filename);
 
-/*printf("PS part %ld %ld %s\n",PS_Offset,PS_Size,clone_info->filename);/**/
+/*printf("PS part %ld %ld %s\n",PS_Offset,PS_Size,clone_info->filename);*/
 
 if( (f=fopen(clone_info->filename,"wb"))==NULL) goto FINISH;
 SeekBlob(image,PS_Offset,SEEK_SET);
@@ -824,7 +825,7 @@ DecompressionFailed: ThrowReaderException(ResourceLimitWarning,"Cannot decompres
 			       Rec2.RecordLength-0x12);
 	     break;
 	     
-/*	 default:printf("Record type %d; size %ld; offset %lX\n",Rec2.RecType,Rec2.RecordLength,Header.DataOffset-Rec2.RecordLength);/* */     
+/*	 default:printf("Record type %d; size %ld; offset %lX\n",Rec2.RecType,Rec2.RecordLength,Header.DataOffset-Rec2.RecordLength); */     
 	 }
        }
 
