@@ -95,10 +95,13 @@ static unsigned int IsXWD(const unsigned char *magick,const unsigned int length)
 {
   if (length < 8)
     return(False);
-  if ((magick[1] == 0x00) && (magick[2] == 0x00))
-    if ((magick[5] == 0x00) && (magick[6] == 0x00))
-      if ((magick[4] == 0x07) || (magick[7] == 0x07))
+  if (memcmp(magick+1,"\000\000",2) == 0)
+    {
+      if (memcmp(magick+4,"\007\000\000",3) == 0)
         return(True);
+      if (memcmp(magick+5,"\000\000\007",3) == 0)
+        return(True);
+    }
   return(False);
 }
 
@@ -375,7 +378,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,y,image->rows);
+            MagickMonitor(LoadImageText,y,image->rows);
         }
       else
         for (y=0; y < (int) image->rows; y++)
@@ -397,7 +400,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (!SyncImagePixels(image))
             break;
           if (QuantumTick(y,image->rows))
-            ProgressMonitor(LoadImageText,y,image->rows);
+            MagickMonitor(LoadImageText,y,image->rows);
         }
       break;
     }
@@ -433,7 +436,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(LoadImageText,y,image->rows);
+          MagickMonitor(LoadImageText,y,image->rows);
       }
       break;
     }
@@ -712,7 +715,7 @@ static unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlob(image,q-pixels,(char *) pixels);
     if (image->previous == (Image *) NULL)
       if (QuantumTick(y,image->rows))
-        ProgressMonitor(SaveImageText,y,image->rows);
+        MagickMonitor(SaveImageText,y,image->rows);
   }
   LiberateMemory((void **) &pixels);
   CloseBlob(image);
