@@ -97,7 +97,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image
     *chroma_image,
     *image,
-    *zoom_image;
+    *resize_image;
 
   int
     count,
@@ -174,7 +174,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (!SyncImagePixels(image))
         break;
       if (image->previous == (Image *) NULL)
-        ProgressMonitor(LoadImageText,y,image->rows);
+        MagickMonitor(LoadImageText,y,image->rows);
     }
     if (image_info->interlace == PartitionInterlace)
       {
@@ -184,8 +184,8 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (status == False)
           ThrowReaderException(FileOpenWarning,"Unable to open file",image);
       }
-    chroma_image=
-      CloneImage(image,image->columns/2,image->rows/2,True,exception);
+    chroma_image=CloneImage(image,image->columns/2,image->rows/2,True,
+      exception);
     if (chroma_image == (Image *) NULL)
       return((Image *) NULL);
     for (y=0; y < (int) chroma_image->rows; y++)
@@ -232,15 +232,16 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       Scale image.
     */
     chroma_image->orphan=True;
-    zoom_image=SampleImage(chroma_image,image->columns,image->rows,exception);
+    resize_image=ResizeImage(chroma_image,image->columns,image->rows,
+      TriangleFilter,1.0,exception);
     DestroyImage(chroma_image);
-    if (zoom_image == (Image *) NULL)
+    if (resize_image == (Image *) NULL)
       ThrowReaderException(ResourceLimitWarning,"Memory allocation failed",
         image);
     for (y=0; y < (int) image->rows; y++)
     {
       q=GetImagePixels(image,0,y,image->columns,1);
-      r=GetImagePixels(zoom_image,0,y,zoom_image->columns,1);
+      r=GetImagePixels(resize_image,0,y,resize_image->columns,1);
       if ((q == (PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
         break;
       for (x=0; x < (int) image->columns; x++)
@@ -253,7 +254,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (!SyncImagePixels(image))
         break;
     }
-    DestroyImage(zoom_image);
+    DestroyImage(resize_image);
     TransformRGBImage(image,YCbCrColorspace);
     if (image_info->interlace == PartitionInterlace)
       (void) strcpy(image->filename,image_info->filename);
@@ -276,7 +277,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,TellBlob(image),image->filesize);
+        MagickMonitor(LoadImagesText,TellBlob(image),image->filesize);
       }
   } while (count > 0);
   LiberateMemory((void **) &scanline);
@@ -425,9 +426,10 @@ static unsigned int WriteYUVImage(const ImageInfo *image_info,Image *image)
     width=image->columns+(image->columns & 0x01);
     height=image->rows+(image->rows & 0x01);
     image->orphan=True;
-    yuv_image=SampleImage(image,width,height,&image->exception);
+    yuv_image=ResizeImage(image,width,height,TriangleFilter,1.0,
+      &image->exception);
     if (yuv_image == (Image *) NULL)
-      ThrowWriterException(ResourceLimitWarning,"Unable to zoom image",image);
+      ThrowWriterException(ResourceLimitWarning,"Unable to resize image",image);
     RGBTransformImage(yuv_image,YCbCrColorspace);
     /*
       Initialize Y channel.
@@ -444,16 +446,17 @@ static unsigned int WriteYUVImage(const ImageInfo *image_info,Image *image)
       }
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(SaveImageText,y,image->rows);
+          MagickMonitor(SaveImageText,y,image->rows);
     }
     DestroyImage(yuv_image);
     /*
       Downsample image.
     */
     image->orphan=True;
-    chroma_image=SampleImage(image,width/2,height/2,&image->exception);
+    chroma_image=ResizeImage(image,width/2,height/2,TriangleFilter,1.0,
+      &image->exception);
     if (chroma_image == (Image *) NULL)
-      ThrowWriterException(ResourceLimitWarning,"Unable to zoom image",image);
+      ThrowWriterException(ResourceLimitWarning,"Unable to resize image",image);
     RGBTransformImage(chroma_image,YCbCrColorspace);
     /*
       Initialize U channel.
@@ -505,7 +508,7 @@ static unsigned int WriteYUVImage(const ImageInfo *image_info,Image *image)
     if (image->next == (Image *) NULL)
       break;
     image=GetNextImage(image);
-    ProgressMonitor(SaveImagesText,scene++,GetNumberScenes(image));
+    MagickMonitor(SaveImagesText,scene++,GetNumberScenes(image));
   } while (image_info->adjoin);
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
