@@ -1,5 +1,5 @@
 /* ltdl.c -- system independent dlopen wrapper
-   Copyright (C) 1998-2000 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000 Free Software Foundation, Inc.
    Originally by Thomas Tanner <tanner@ffii.org>
    This file is part of GNU Libtool.
 
@@ -1165,10 +1165,10 @@ load_deplibs(handle, deplibs)
 		ret = 0;
 		goto cleanup;
 	}
-	names = lt_dlmalloc(depcount * sizeof(char*));
+	names = (char**)lt_dlmalloc(depcount * sizeof(char*));
 	if (!names)
 		goto cleanup;
-	handles = lt_dlmalloc(depcount * sizeof(lt_dlhandle*));
+	handles = (lt_dlhandle*)lt_dlmalloc(depcount * sizeof(lt_dlhandle*));
 	if (!handles)
 		goto cleanup;
 	depcount = 0;
@@ -1185,9 +1185,9 @@ load_deplibs(handle, deplibs)
 				*end = 0; /* set a temporary string terminator */
 				if (strncmp(p, "-l", 2) == 0) {
 					name = lt_dlmalloc(3+ /* "lib" */
-					 strlen(p+2)+strlen(shlib_ext)+1);
+							   strlen(p+2)+1);
 					if (name)
-						sprintf(name, "lib%s%s", p+2, shlib_ext);
+						sprintf (name, "lib%s", p+2);
 				} else
 					name = strdup(p);
 				if (name)
@@ -1202,7 +1202,7 @@ load_deplibs(handle, deplibs)
 	}
 	/* load the deplibs (in reverse order) */
 	for (i = 0; i < depcount; i++) {
-		lt_dlhandle handle = lt_dlopen(names[depcount-1-i]);
+		lt_dlhandle handle = lt_dlopenext(names[depcount-1-i]);
 		if (!handle) {
 			int j;
 			for (j = 0; j < i; j++)
@@ -1440,6 +1440,22 @@ lt_dlopen (filename)
 			else
 			if (strcmp(line, "installed=no\n") == 0)
 				installed = 0;
+			else
+#			undef  STR_LIBRARY_NAMES
+#			define STR_LIBRARY_NAMES "library_names="
+			if (! dlname &&
+			    strncmp(line, STR_LIBRARY_NAMES,
+				sizeof(STR_LIBRARY_NAMES) - 1) == 0) {
+			  char *last_libname;
+			  error = trim(&dlname,
+				       &line[sizeof(STR_LIBRARY_NAMES) - 1]);
+			  if (! error && dlname &&
+			      (last_libname = strrchr(dlname, ' ')) != NULL) {
+			    last_libname = strdup(last_libname + 1);
+			    free(dlname);
+			    dlname = last_libname;
+			  }
+			}
 			if (error)
 				break;
 		}
