@@ -205,7 +205,7 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
         if (number_files <= 5)
           continue;
         (void) SetMonitorHandler(handler);
-        ProgressMonitor(LoadImageText,i,number_files);
+        MagickMonitor(LoadImageText,i,number_files);
       }
       DestroyImageInfo(clone_info);
       if (image == (Image *) NULL)
@@ -446,6 +446,7 @@ MagickExport void XAnimateBackgroundImage(Display *display,
     window_info;
 
   Image
+    *coalesce_image,
     *display_image,
     **images;
 
@@ -545,16 +546,35 @@ MagickExport void XAnimateBackgroundImage(Display *display,
   */
   if (window_info.id == root_window)
     XDestroyWindowColors(display,root_window);
+  coalesce_image=image;
   if (image->next != (Image *)NULL)
     {
       Image
-        *coalesce_image;
+        *next_image;
 
-      coalesce_image=CoalesceImages(image,&image->exception);
-      if (coalesce_image == (Image *) NULL)
-        MagickError(image->exception.severity,image->exception.message,
-          image->exception.qualifier);
-      image=coalesce_image;
+      /*
+        Determine if the sequence of images have identical page info.
+      */
+      for (next_image=image; next_image != (Image *) NULL; )
+      {
+        if ((image->columns != next_image->columns) ||
+            (image->rows != next_image->rows))
+          break;
+        if ((image->page.x != next_image->page.x) ||
+            (image->page.y != next_image->page.y))
+          break;
+        next_image=next_image->next;
+      }
+      if (next_image != (Image *) NULL)
+        {
+          coalesce_image=CoalesceImages(image,&image->exception);
+          if (coalesce_image == (Image *) NULL)
+            MagickError(image->exception.severity,image->exception.reason,
+              image->exception.description);
+          if (!resource_info->immutable)
+            DestroyImages(image);
+          image=coalesce_image;
+        }
     }
   if (resources.map_type == (char *) NULL)
     if ((visual_info->storage_class != TrueColor) &&
@@ -563,32 +583,24 @@ MagickExport void XAnimateBackgroundImage(Display *display,
         Image
           *next_image;
 
-        unsigned int
-          global_colormap;
-
         /*
           Determine if the sequence of images has the identical colormap.
         */
-        global_colormap=True;
-        next_image=image;
-        for ( ; next_image != (Image *) NULL; next_image=next_image->next)
+        for (next_image=image; next_image != (Image *) NULL; )
         {
           next_image->matte=False;
           if ((next_image->storage_class == DirectClass) ||
               (next_image->colors != image->colors) ||
               ((int) next_image->colors > visual_info->colormap_size))
-            {
-              global_colormap=False;
-              break;
-            }
+            break;
           for (i=0; i < (int) image->colors; i++)
             if (!ColorMatch(next_image->colormap[i],image->colormap[i],0))
-              {
-                global_colormap=False;
-                break;
-              }
+              break;
+          if (i < (int) image->colors)
+            break;
+          next_image=next_image->next;
         }
-        if (!global_colormap)
+        if (next_image != (Image *) NULL)
           (void) MapImages(image,(Image *) NULL,
             resources.quantize_info->dither);
       }
@@ -829,6 +841,8 @@ MagickExport void XAnimateBackgroundImage(Display *display,
     }
   } while (event.type != DestroyNotify);
   XSync(display,False);
+  if (coalesce_image != image)
+    DestroyImages(image);
 }
 
 /*
@@ -974,6 +988,7 @@ MagickExport Image *XAnimateImages(Display *display,
     command_type;
 
   Image
+    *coalesce_image,
     *display_image,
     **images,
     *nexus;
@@ -1063,7 +1078,7 @@ MagickExport Image *XAnimateImages(Display *display,
   if (windows != (XWindows *) NULL)
     {
       (void) chdir(working_directory);
-      monitor_handler=SetMonitorHandler(XProgressMonitor);
+      monitor_handler=SetMonitorHandler(XMagickMonitor);
       warning_handler=resource_info->display_warnings ?
         SetWarningHandler(XWarning) : SetWarningHandler((WarningHandler) NULL);
       (void) signal(SIGINT,XSignalHandler);
@@ -1127,16 +1142,35 @@ MagickExport Image *XAnimateImages(Display *display,
   class_hints=windows->class_hints;
   manager_hints=windows->manager_hints;
   root_window=XRootWindow(display,visual_info->screen);
+  coalesce_image=image;
   if (image->next != (Image *)NULL)
     {
       Image
-        *coalesce_image;
+        *next_image;
 
-      coalesce_image=CoalesceImages(image,&image->exception);
-      if (coalesce_image == (Image *) NULL)
-        MagickError(image->exception.severity,image->exception.message,
-          image->exception.qualifier);
-      image=coalesce_image;
+      /*
+        Determine if the sequence of images have identical page info.
+      */
+      for (next_image=image; next_image != (Image *) NULL; )
+      {
+        if ((image->columns != next_image->columns) ||
+            (image->rows != next_image->rows))
+          break;
+        if ((image->page.x != next_image->page.x) ||
+            (image->page.y != next_image->page.y))
+          break;
+        next_image=next_image->next;
+      }
+      if (next_image != (Image *) NULL)
+        {
+          coalesce_image=CoalesceImages(image,&image->exception);
+          if (coalesce_image == (Image *) NULL)
+            MagickError(image->exception.severity,image->exception.reason,
+              image->exception.description);
+          if (!resource_info->immutable)
+            DestroyImages(image);
+          image=coalesce_image;
+        }
     }
   if (resource_info->map_type == (char *) NULL)
     if ((visual_info->storage_class != TrueColor) &&
@@ -1145,33 +1179,24 @@ MagickExport Image *XAnimateImages(Display *display,
         Image
           *next_image;
 
-        unsigned int
-          global_colormap;
-
         /*
           Determine if the sequence of images has the identical colormap.
         */
-        global_colormap=True;
-        next_image=image;
-        for ( ; next_image != (Image *) NULL; next_image=next_image->next)
+        for (next_image=image; next_image != (Image *) NULL; )
         {
-          TransformRGBImage(next_image,RGBColorspace);
           next_image->matte=False;
           if ((next_image->storage_class == DirectClass) ||
               (next_image->colors != image->colors) ||
               ((int) next_image->colors > visual_info->colormap_size))
-            {
-              global_colormap=False;
-              break;
-            }
+            break;
           for (i=0; i < (int) image->colors; i++)
             if (!ColorMatch(next_image->colormap[i],image->colormap[i],0))
-              {
-                global_colormap=False;
-                break;
-              }
+              break;
+          if (i < (int) image->colors)
+            break;
+          next_image=next_image->next;
         }
-        if (!global_colormap)
+        if (next_image != (Image *) NULL)
           (void) MapImages(image,(Image *) NULL,
             resource_info->quantize_info->dither);
       }
@@ -1313,11 +1338,8 @@ MagickExport Image *XAnimateImages(Display *display,
       /*
         Window name is the base of the filename.
       */
-      windows->image.name=(char *) AcquireMemory(MaxTextExtent);
-      windows->image.icon_name=(char *) AcquireMemory(MaxTextExtent);
-      if ((windows->image.name == NULL) || (windows->image.icon_name == NULL))
-        MagickError(ResourceLimitError,"Unable to create Image window",
-          "Memory allocation failed");
+      windows->image.name=AllocateString((char *) NULL);
+      windows->image.icon_name=AllocateString((char *) NULL);
       p=display_image->filename+Extent(display_image->filename)-1;
       while ((p > display_image->filename) && !IsBasenameSeparator(*(p-1)))
         p--;
@@ -1484,10 +1506,7 @@ MagickExport Image *XAnimateImages(Display *display,
   FormatString(resource_name,"%.1024s.widget",resource_info->client_name);
   windows->widget.geometry=XGetResourceClass(resource_info->resource_database,
     resource_name,"geometry",(char *) NULL);
-  windows->widget.name=(char *) AcquireMemory(MaxTextExtent);
-  if (windows->widget.name == NULL)
-    MagickError(ResourceLimitError,"Unable to create Image window",
-      "Memory allocation failed");
+  windows->widget.name=AllocateString((char *) NULL);
   *windows->widget.name='\0';
   windows->widget.border_width=0;
   windows->widget.flags|=PPosition;
@@ -1516,10 +1535,7 @@ MagickExport Image *XAnimateImages(Display *display,
     LiberateMemory((void **) &windows->popup.name);
   XGetWindowInfo(display,visual_info,map_info,pixel,font_info,
     resource_info,&windows->popup);
-  windows->popup.name=(char *) AcquireMemory(MaxTextExtent);
-  if (windows->popup.name == NULL)
-    MagickError(ResourceLimitError,"Unable to create Image window",
-      "Memory allocation failed");
+  windows->popup.name=AllocateString((char *) NULL);
   *windows->popup.name='\0';
   windows->popup.border_width=0;
   windows->popup.flags|=PPosition;
@@ -1546,7 +1562,7 @@ MagickExport Image *XAnimateImages(Display *display,
     Set out progress and warning handlers.
   */
   if (monitor_handler == (MonitorHandler) NULL)
-    monitor_handler=SetMonitorHandler(XProgressMonitor);
+    monitor_handler=SetMonitorHandler(XMagickMonitor);
   if (warning_handler == (WarningHandler) NULL)
     warning_handler=resource_info->display_warnings ?
       SetWarningHandler(XWarning) : SetWarningHandler((WarningHandler) NULL);
@@ -1567,8 +1583,7 @@ MagickExport Image *XAnimateImages(Display *display,
     Initialize image pixmaps structure.
   */
   XMapWindow(display,windows->image.id);
-  windows->image.pixmaps=(Pixmap *)
-    AcquireMemory(number_scenes*sizeof(Pixmap));
+  windows->image.pixmaps=(Pixmap *) AcquireMemory(number_scenes*sizeof(Pixmap));
   windows->image.matte_pixmaps=(Pixmap *)
     AcquireMemory(number_scenes*sizeof(Pixmap));
   if ((windows->image.pixmaps == (Pixmap *) NULL) ||
@@ -2443,6 +2458,8 @@ MagickExport Image *XAnimateImages(Display *display,
       (void) XSetWindows((XWindows *) NULL);
     }
   XSync(display,False);
+  if (coalesce_image != image)
+    DestroyImages(image);
   /*
     Restore our progress monitor and warning handlers.
   */
