@@ -95,6 +95,9 @@ MagickExport unsigned int AnnotateImage(Image *image,
     *text,
     **textlist;
 
+  double
+    font_height;
+
   Image
     *annotate_image;
 
@@ -102,7 +105,6 @@ MagickExport unsigned int AnnotateImage(Image *image,
     *image_info;
 
   int
-    font_height,
     x,
     y;
 
@@ -191,8 +193,7 @@ MagickExport unsigned int AnnotateImage(Image *image,
   image_info->font=AllocateString(annotate_info->font);
   image_info->density=AllocateString(annotate_info->density);
   image_info->pointsize=annotate_info->pointsize;
-  for (i=0; i < 6; i++)
-    image_info->affine[i]=annotate_info->affine[i];
+  image_info->affine=annotate_info->affine;
   image_info->antialias=annotate_info->antialias;
   image_info->fill=annotate_info->fill;
   image_info->stroke=annotate_info->stroke;
@@ -224,11 +225,11 @@ MagickExport unsigned int AnnotateImage(Image *image,
           q=GetImagePixels(annotate_image,0,0,annotate_image->columns,1);
         else
           if (annotate_info->decorate == UnderlineDecoration)
-            q=GetImagePixels(annotate_image,0,(int) annotate_image->rows-1,
-              annotate_image->columns,1);
+            q=GetImagePixels(annotate_image,0,(int)
+              (2.0*annotate_image->rows/3.0),annotate_image->columns,1);
           else
-            q=GetImagePixels(annotate_image,0,(int) (0.5*annotate_image->rows),
-              annotate_image->columns,1);
+            q=GetImagePixels(annotate_image,0,(int)
+              (annotate_image->rows/3.0),annotate_image->columns,1);
         if (q != (PixelPacket *) NULL)
           {
             register int
@@ -258,10 +259,9 @@ MagickExport unsigned int AnnotateImage(Image *image,
     /*
       Composite text onto the image.
     */
-    font_height=(int) (clone_info->affine[0]*annotate_info->pointsize+
-      clone_info->affine[2]*annotate_info->pointsize);
-    point.x=clone_info->affine[2]*annotate_info->pointsize;
-    point.y=clone_info->affine[3]*annotate_info->pointsize;
+    font_height=clone_info->affine.sx*annotate_info->pointsize;
+    point.x=clone_info->affine.sx*annotate_info->pointsize;
+    point.y=clone_info->affine.sy*annotate_info->pointsize;
     switch (clone_info->gravity)
     {
       case NorthWestGravity:
@@ -333,7 +333,8 @@ MagickExport unsigned int AnnotateImage(Image *image,
         /*
           Surround text with a border.
         */
-        box_image=CloneImage(annotate_image,annotate_image->columns,font_height,          True,&image->exception);
+        box_image=CloneImage(annotate_image,annotate_image->columns,
+          (int) font_height,True,&image->exception);
         if (box_image != (Image *) NULL)
           {
             box_image->background_color=annotate_info->box;
@@ -483,25 +484,19 @@ MagickExport void DestroyAnnotateInfo(AnnotateInfo *annotate_info)
 MagickExport void GetAnnotateInfo(const ImageInfo *image_info,
   AnnotateInfo *annotate_info)
 {
-  register int
-    i;
-
   /*
     Initialize annotate attributes;
   */
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   assert(annotate_info != (AnnotateInfo *) NULL);
-  annotate_info->geometry=(char *) NULL;
-  annotate_info->text=(char *) NULL;
+  memset(annotate_info,0,sizeof(AnnotateInfo));
   annotate_info->font=AllocateString(image_info->font);
   annotate_info->density=AllocateString(image_info->density);
   annotate_info->antialias=image_info->antialias;
   annotate_info->gravity=NorthWestGravity;
   annotate_info->pointsize=image_info->pointsize;
-  annotate_info->degrees=0.0;
-  for (i=0; i < 6; i++)
-    annotate_info->affine[i]=image_info->affine[i];
+  annotate_info->affine=image_info->affine;
   annotate_info->fill=image_info->fill;
   annotate_info->stroke=image_info->stroke;
   (void) QueryColorDatabase("none",&annotate_info->box);
