@@ -5,7 +5,7 @@
 
       #include <stdio.h>
       #include <time.h>
-      #include <sys/type.h>
+      #include <sys/types.h>
       #include <magick/api.h>
 
 */
@@ -51,6 +51,7 @@
 #pragma warning(disable : 4018)
 #pragma warning(disable : 4244)
 #pragma warning(disable : 4142)
+#pragma warning(disable : 4800)
 
 #else
 # define MagickExport __declspec(dllexport)
@@ -71,6 +72,7 @@
 #endif
 #include "magick/classify.h"
 #include "magick/image.h"
+#include "magick/draw.h"
 #include "magick/gems.h"
 #include "magick/quantize.h"
 #include "magick/compress.h"
@@ -88,6 +90,7 @@
 #else
 #include "classify.h"
 #include "image.h"
+#include "draw.h"
 #include "gems.h"
 #include "quantize.h"
 #include "compress.h"
