@@ -335,11 +335,7 @@ MagickExport int EOFBlob(const Image *image)
 MagickExport void GetBlobInfo(BlobInfo *blob)
 {
   assert(blob != (BlobInfo *) NULL);
-  blob->mapped=False;
-  blob->data=(char *) NULL;
-  blob->offset=0;
-  blob->length=0;
-  blob->extent=0;
+  memset(blob,0,sizeof(BlobInfo));
   blob->quantum=BlobQuantum;
   blob->signature=MagickSignature;
 }
@@ -1222,7 +1218,7 @@ MagickExport unsigned int OpenBlob(const ImageInfo *image_info,Image *image,
   if (LocaleCompare(filename,"-") == 0)
     {
       image->file=(*type == 'r') ? stdin : stdout;
-#if defined(_VISUALC_)
+#if defined(_VISUALC_) || defined(__BORLANDC__)
       if (strchr(type,'b') != (char *) NULL)
         _setmode(_fileno(image->file),_O_BINARY);
 #endif
