@@ -406,16 +406,10 @@ MagickExport void GetCacheInfo(Cache *cache)
   if (cache_info == (CacheInfo *) NULL)
     MagickError(ResourceLimitError,"Memory allocation failed",
       "unable to allocate cache info");
+  memset(cache_info,0,sizeof(CacheInfo));
   cache_info->storage_class=UndefinedClass;
   cache_info->type=UndefinedCache;
-  cache_info->rows=0;
-  cache_info->columns=0;
-  cache_info->pixels=(PixelPacket *) NULL;
-  cache_info->indexes=(IndexPacket *) NULL;
-  cache_info->persist=False;
-  *cache_info->filename='\0';
   cache_info->file=(-1);
-  cache_info->nexus=(NexusInfo *) NULL;
   cache_info->signature=MagickSignature;
   *cache=cache_info;
 }
@@ -887,8 +881,8 @@ MagickExport unsigned int OpenCache(Cache cache,const ClassType storage_class,
         Set cache memory threshold.
       */
       threshold=PixelCacheThreshold;
-      if (getenv("MAGIGK_CACHE_THRESHOLD") != (char *) NULL)
-        threshold=atoi(getenv("MAGIGK_CACHE_THRESHOLD"));
+      if (getenv("MAGICK_CACHE_THRESHOLD") != (char *) NULL)
+        threshold=atoi(getenv("MAGICK_CACHE_THRESHOLD"));
 #if defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
       if (threshold > (sysconf(_SC_PAGESIZE)*sysconf(_SC_PHYS_PAGES/1048576)))
         threshold=sysconf(_SC_PAGESIZE)*sysconf(_SC_PHYS_PAGES)/1048576;
@@ -983,12 +977,14 @@ MagickExport unsigned int OpenCache(Cache cache,const ClassType storage_class,
       if (cache_info->file == -1)
         return(False);
     }
+#if !defined(vms) && !defined(macintosh) && !defined(WIN32)
+  if (ftruncate(cache_info->file,length) == -1)
+    return(False);
+else
   if (lseek(cache_info->file,length,SEEK_SET) == -1)
     return(False);
   if (write(cache_info->file,&null,sizeof(null)) == -1)
     return(False);
-#if !defined(vms) && !defined(macintosh) && !defined(WIN32)
-  (void) ftruncate(cache_info->file,length);
 #endif
   cache_info->storage_class=storage_class;
   if (cache_info->type != DiskCache)
@@ -1008,6 +1004,7 @@ MagickExport unsigned int OpenCache(Cache cache,const ClassType storage_class,
           if (cache_info->storage_class == PseudoClass)
             cache_info->indexes=(IndexPacket *)
               (cache_info->pixels+number_pixels);
+          CloseCache(cache);
         }
     }
   return(True);
