@@ -1,5 +1,5 @@
 /*
-  ImageMagick image and error classifications.
+  ImageMagick image and error storage_classs.
 */
 #ifndef _CLASSIFY_H
 #define _CLASSIFY_H
@@ -65,7 +65,8 @@ typedef enum
   BlendCompositeOp,
   DisplaceCompositeOp,
   AnnotateCompositeOp,
-  ModulateCompositeOp
+  ModulateCompositeOp,
+  ThresholdCompositeOp
 } CompositeOperator;
 
 typedef enum
@@ -115,6 +116,13 @@ typedef enum
   StreamError = 445
 } ExceptionType;
 
+typedef enum
+{
+  UndefinedRule,
+  EvenOddRule,
+  NonZeroRule
+} FillRule;
+
 typedef enum
 {
   UndefinedFilter,
@@ -133,7 +141,7 @@ typedef enum
   LanczosFilter,
   BesselFilter,
   SincFilter
-} FilterType;
+} FilterTypes;
 
 /* Eliminate possible conflict from <X11/Xutil.h> */
 #undef NoValue
@@ -205,6 +213,22 @@ typedef enum
   MatteLayer
 } LayerType;
 
+typedef enum
+{
+  UndefinedCap,
+  ButtCap,
+  RoundCap,
+  SquareCap
+} LineCap;
+
+typedef enum
+{
+  UndefinedJoin,
+  MiterJoin,
+  RoundJoin,
+  BevelJoin
+} LineJoin;
+
 typedef enum
 {
   ReadMode,
@@ -239,6 +263,13 @@ typedef enum
   ResetMethod
 } PaintMethod;
 
+typedef enum
+{
+  UndefinedProfile,
+  ICMProfile,
+  IPTCProfile
+} ProfileType;
+
 typedef enum
 {
   UndefinedPreview = 0,
@@ -310,7 +341,7 @@ typedef enum
   RGBQuantum,
   RGBAQuantum,
   CMYKQuantum
-} QuantumTypes;
+} QuantumType;
 
 typedef enum
 {
@@ -344,6 +375,15 @@ typedef enum
   RunningTimerState
 } TimerState;
 
+typedef enum
+{
+  UndefinedTransmitType,
+  FileTransmitType,
+  BlobTransmitType,
+  StreamTransmitType,
+  ImageTransmitType
+} TransmitType;
+
 typedef enum
 {
   ControlState = 0x0001,
