@@ -1261,7 +1261,7 @@ static void DestroyList(const NodeInfo *node_info)
 */
 MagickExport unsigned long GetNumberColors(Image *image,FILE *file)
 {
-#define NumberColorsImageText  "  Computing image colors...  "
+#define NumberColorsImageText  "  Compute image colors...  "
 
   CubeInfo
     color_cube;
@@ -1366,7 +1366,7 @@ MagickExport unsigned long GetNumberColors(Image *image,FILE *file)
       p++;
     }
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(NumberColorsImageText,y,image->rows);
+      MagickMonitor(NumberColorsImageText,y,image->rows);
   }
   if (file != (FILE *) NULL)
     {
@@ -1418,7 +1418,7 @@ MagickExport unsigned long GetNumberColors(Image *image,FILE *file)
 */
 static void Histogram(CubeInfo *color_cube,const NodeInfo *node_info,FILE *file)
 {
-#define HistogramImageText  "  Computing image histogram...  "
+#define HistogramImageText  "  Compute image histogram...  "
 
   register unsigned int
     id;
@@ -1458,7 +1458,7 @@ static void Histogram(CubeInfo *color_cube,const NodeInfo *node_info,FILE *file)
         (void) fprintf(file,"\n");
       }
       if (QuantumTick(color_cube->progress,color_cube->colors))
-        ProgressMonitor(HistogramImageText,color_cube->progress,
+        MagickMonitor(HistogramImageText,color_cube->progress,
           color_cube->colors);
       color_cube->progress++;
     }
@@ -1672,12 +1672,12 @@ MagickExport unsigned int IsMonochromeImage(Image *image)
     return(False);
   if (image->colors > 2)
     return(False);
-  if ((Intensity(image->colormap[0]) != 0) &&
-      (Intensity(image->colormap[0]) != MaxRGB))
+  if (((int) Intensity(image->colormap[0]) != 0) &&
+      ((int) Intensity(image->colormap[0]) != MaxRGB))
     return(False);
   if (image->colors == 2)
-    if ((Intensity(image->colormap[1]) != 0) &&
-        (Intensity(image->colormap[1]) != MaxRGB))
+    if (((int) Intensity(image->colormap[1]) != 0) &&
+        ((int) Intensity(image->colormap[1]) != MaxRGB))
       return(False);
   return(True);
 }
@@ -1913,8 +1913,14 @@ MagickExport unsigned int IsPseudoClass(Image *image)
 MagickExport unsigned int QueryColorDatabase(const char *target,
   PixelPacket *color)
 {
+  char
+    colorname[MaxTextExtent],
+    *path,
+    text[MaxTextExtent];
+
   int
     blue,
+    count,
     green,
     left,
     mid,
@@ -1925,6 +1931,9 @@ MagickExport unsigned int QueryColorDatabase(const char *target,
   register int
     i;
 
+  FILE
+    *file;
+
   /*
     Initialize color return value.
   */
@@ -2013,7 +2022,7 @@ MagickExport unsigned int QueryColorDatabase(const char *target,
       color->blue=((unsigned long) (MaxRGB*blue)/((1 << n)-1));
       color->opacity=OpaqueOpacity;
       if (opacity >= 0)
-        color->opacity=MaxRGB-((unsigned long) (MaxRGB*opacity)/((1 << n)-1));
+        color->opacity=((unsigned long) (MaxRGB*opacity)/((1 << n)-1));
       return(True);
     }
   if (LocaleCompare(target,"none") == 0)
@@ -2024,7 +2033,7 @@ MagickExport unsigned int QueryColorDatabase(const char *target,
       color->opacity=TransparentOpacity;
       return(True);
     }
-  if (LocaleNCompare(target,"rgb",3) == 0)
+  if (LocaleNCompare(target,"rgb(",4) == 0)
     {
       (void) sscanf(target,"%*[^(](%d%*[ ,]%d%*[ ,]%d",&red,&green,&blue);
       color->red=UpScale(red);
@@ -2034,7 +2043,7 @@ MagickExport unsigned int QueryColorDatabase(const char *target,
       return(True);
     }
   /*
-    Search our internal X color database.
+    Search our internal color database.
   */
   left=0;
   right=NumberXColors-2;
@@ -2107,44 +2116,32 @@ MagickExport unsigned int QueryColorDatabase(const char *target,
     color->opacity=OpaqueOpacity;
     return(status);
   }
-#else
-  {
-    char
-      colorname[MaxTextExtent],
-      text[MaxTextExtent];
-
-    int
-      count;
-
-    static FILE
-      *database = (FILE *) NULL;
-
-    /*
-      Match color against the X color database.
-    */
-    if (database == (FILE *) NULL)
-      database=fopen(RGBColorDatabase,"r");
-    if (database != (FILE *) NULL)
-      {
-        (void) rewind(database);
-        while (fgets(text,MaxTextExtent,database) != (char *) NULL)
-        {
-          count=sscanf(text,"%d %d %d %[^\n]\n",&red,&green,&blue,colorname);
-          if (count != 4)
-            continue;
-          if (LocaleCompare(colorname,target) == 0)
-            {
-              color->red=UpScale(red);
-              color->green=UpScale(green);
-              color->blue=UpScale(blue);
-              color->opacity=OpaqueOpacity;
-              return(True);
-            }
-        }
-      }
-    return(False);
-  }
 #endif
+  /*
+    Match color against the X color database.
+  */
+  path=GetMagickConfigurePath("rgb.txt");
+  if (path == (char *) NULL)
+    return(False);
+  file=fopen(path,"r");
+  LiberateMemory((void **) &path);  
+  if (file == (FILE *) NULL)
+    return(False);
+  while (fgets(text,MaxTextExtent,file) != (char *) NULL)
+  {
+    count=sscanf(text,"%d %d %d %[^\n]\n",&red,&green,&blue,colorname);
+    if (count != 4)
+      continue;
+    if (LocaleCompare(colorname,target) != 0)
+      continue;
+    color->red=UpScale(red);
+    color->green=UpScale(green);
+    color->blue=UpScale(blue);
+    color->opacity=OpaqueOpacity;
+    return(True);
+  }
+  (void) fclose(file);
+  return(False);
 }
 
 /*
