@@ -62,8 +62,8 @@
 /*
   Define declarations.
 */
-#define LoadImageText  "  Loading image...  "
-#define SaveImageText  "  Saving image...  "
+#define LoadImageText  "  Load image...  "
+#define SaveImageText  "  Save image...  "
 
 /*
   Typedef declarations.
@@ -591,7 +591,7 @@ MagickExport unsigned int HuffmanDecodeImage(Image *image)
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
     y++;
   }
   image->rows=Max(y-3,1);
@@ -719,8 +719,7 @@ MagickExport unsigned int HuffmanEncodeImage(const ImageInfo *image_info,
       /*
         Convert image to monochrome.
       */
-      huffman_image=
-        CloneImage(image,image->columns,image->rows,True,&image->exception);
+      huffman_image=CloneImage(image,0,0,True,&image->exception);
       if (huffman_image == (Image *) NULL)
         return(False);
       GetQuantizeInfo(&quantize_info);
@@ -819,7 +818,7 @@ MagickExport unsigned int HuffmanEncodeImage(const ImageInfo *image_info,
     q=scanline;
     if (huffman_image->previous == (Image *) NULL)
       if (QuantumTick(y,huffman_image->rows))
-        ProgressMonitor(SaveImageText,y,huffman_image->rows);
+        MagickMonitor(SaveImageText,y,huffman_image->rows);
   }
   /*
     End of page.
@@ -921,8 +920,7 @@ MagickExport unsigned int Huffman2DEncodeImage(ImageInfo *image_info,
   assert(image_info->signature == MagickSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  huffman_image=CloneImage(image,image->columns,image->rows,True,
-    &image->exception);
+  huffman_image=CloneImage(image,0,0,True,&image->exception);
   if (huffman_image == (Image *) NULL)
     return(False);
   if (!IsMonochromeImage(huffman_image))
