@@ -142,7 +142,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
       "impossible image size");
   image->columns=width;
   image->rows=height;
-  for (i=0; i < strlen(map); i++)
+  for (i=0; i < Extent(map); i++)
     switch (map[i])
     {
       case 'a':
@@ -184,7 +184,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
           break;
         for (x=0; x < (int) image->columns; x++)
         {
-          for (i=0; i < strlen(map); i++)
+          for (i=0; i < Extent(map); i++)
           {
             switch (map[i])
             {
@@ -247,7 +247,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
           break;
         for (x=0; x < (int) image->columns; x++)
         {
-          for (i=0; i < strlen(map); i++)
+          for (i=0; i < Extent(map); i++)
           {
             switch (map[i])
             {
@@ -310,7 +310,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
           break;
         for (x=0; x < (int) image->columns; x++)
         {
-          for (i=0; i < strlen(map); i++)
+          for (i=0; i < Extent(map); i++)
           {
             switch (map[i])
             {
@@ -373,7 +373,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
           break;
         for (x=0; x < (int) image->columns; x++)
         {
-          for (i=0; i < strlen(map); i++)
+          for (i=0; i < Extent(map); i++)
           {
             switch (map[i])
             {
@@ -436,7 +436,7 @@ MagickExport Image *ConstituteImage(const unsigned int width,
           break;
         for (x=0; x < (int) image->columns; x++)
         {
-          for (i=0; i < strlen(map); i++)
+          for (i=0; i < Extent(map); i++)
           {
             switch (map[i])
             {
@@ -557,7 +557,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  for (i=0; i < strlen(map); i++)
+  for (i=0; i < Extent(map); i++)
     switch (map[i])
     {
       case 'c':
@@ -589,7 +589,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
       q=(unsigned char *) pixels;
       for (i=0; i < (columns*rows); i++)
       {
-        for (j=0; j < strlen(map); j++)
+        for (j=0; j < Extent(map); j++)
         {
           switch (map[j])
           {
@@ -651,7 +651,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
       q=(unsigned short *) pixels;
       for (i=0; i < (columns*rows); i++)
       {
-        for (j=0; j < strlen(map); j++)
+        for (j=0; j < Extent(map); j++)
         {
           switch (map[j])
           {
@@ -706,7 +706,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
       q=(unsigned int *) pixels;
       for (i=0; i < (columns*rows); i++)
       {
-        for (j=0; j < strlen(map); j++)
+        for (j=0; j < Extent(map); j++)
         {
           switch (map[j])
           {
@@ -761,7 +761,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
       q=(float *) pixels;
       for (i=0; i < (columns*rows); i++)
       {
-        for (j=0; j < strlen(map); j++)
+        for (j=0; j < Extent(map); j++)
         {
           switch (map[j])
           {
@@ -770,7 +770,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
             case 'c':
             case 'C':
             {
-              *q++=p->red/MaxRGB;
+              *q++=(float) p->red/MaxRGB;
               break;
             }
             case 'g':
@@ -778,7 +778,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
             case 'y':
             case 'Y':
             {
-              *q++=p->green/MaxRGB;
+              *q++=(float) p->green/MaxRGB;
               break;
             }
             case 'b':
@@ -786,7 +786,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
             case 'm':
             case 'M':
             {
-              *q++=p->blue/MaxRGB;
+              *q++=(float) p->blue/MaxRGB;
               break;
             }
             case 'a':
@@ -794,7 +794,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
             case 'k':
             case 'K':
             {
-              *q++=p->opacity/MaxRGB;
+              *q++=(float) p->opacity/MaxRGB;
               break;
             }
             default:
@@ -816,7 +816,7 @@ MagickExport unsigned int DispatchImage(Image *image,const int x,const int y,
       q=(double *) pixels;
       for (i=0; i < (columns*rows); i++)
       {
-        for (j=0; j < strlen(map); j++)
+        for (j=0; j < Extent(map); j++)
         {
           switch (map[j])
           {
@@ -1124,7 +1124,7 @@ MagickExport unsigned int PopImagePixels(const Image *image,
         {
           for (x=0; x < (int) image->columns; x++)
           {
-            *q++=DownScale(MaxRGB-p->opacity);
+            *q++=MaxRGB-DownScale(p->opacity);
             p++;
           }
           break;
@@ -1191,7 +1191,7 @@ MagickExport unsigned int PopImagePixels(const Image *image,
             *q++=DownScale(p->red);
             *q++=DownScale(p->green);
             *q++=DownScale(p->blue);
-            *q++=DownScale(MaxRGB-p->opacity);
+            *q++=MaxRGB-DownScale(p->opacity);
             p++;
           }
           break;
@@ -1331,7 +1331,7 @@ MagickExport unsigned int PushImagePixels(const Image *image,
             index=(*p++);
             indexes[x]=index;
             *q=image->colormap[index];
-            q->opacity=UpScale(MaxRGB-*p++);
+            q->opacity=MaxRGB-UpScale(*p++);
             q++;
           }
           break;
@@ -1461,7 +1461,7 @@ MagickExport unsigned int PushImagePixels(const Image *image,
         {
           for (x=0; x < (int) image->columns; x++)
           {
-            q->opacity=UpScale(MaxRGB-*p++);
+            q->opacity=MaxRGB-UpScale(*p++);
             q++;
           }
           break;
@@ -1528,7 +1528,7 @@ MagickExport unsigned int PushImagePixels(const Image *image,
             q->red=UpScale(*p++);
             q->green=UpScale(*p++);
             q->blue=UpScale(*p++);
-            q->opacity=UpScale(MaxRGB-*p++);
+            q->opacity=MaxRGB-UpScale(*p++);
             q++;
           }
           break;
@@ -1661,7 +1661,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     if (!GetDelegateInfo(clone_info->magick,(char *) NULL,&delegate_info))
       {
         ThrowException(exception,MissingDelegateWarning,
-          "no delegate for this image format",clone_info->filename)
+          "no delegate for this image format",clone_info->filename);
         DestroyImageInfo(clone_info);
         return((Image *) NULL);
       }
@@ -1680,7 +1680,8 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         TemporaryFilename(clone_info->filename);
         status=
           InvokeDelegate(clone_info,image,clone_info->magick,(char *) NULL);
-        *exception=image->exception;
+        ThrowException(exception,image->exception.severity,
+           image->exception.reason,image->exception.description);
         DestroyImages(image);
         image=(Image *) NULL;
         if (status != False)
@@ -1749,8 +1750,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
             /*
               Clone this subimage.
             */
-            clone_image=
-              CloneImage(next,next->columns,next->rows,True,exception);
+            clone_image=CloneImage(next,0,0,True,exception);
             if (clone_image == (Image *) NULL)
               break;
             if (subimages == (Image *) NULL)
@@ -1913,7 +1913,7 @@ MagickExport Image *ReadImages(const ImageInfo *image_info,
       return((Image *) NULL);
     }
   length=MaxTextExtent;
-  command=(char *) AcquireMemory(length);
+  command=AllocateString((char *) NULL);
   for (p=command; command != (char *) NULL; p++)
   {
     c=fgetc(file);
