@@ -156,7 +156,7 @@ MagickExport Image *BorderImage(Image *image,const RectangleInfo *border_info,
 MagickExport Image *FrameImage(Image *image,const FrameInfo *frame_info,
   ExceptionInfo *exception)
 {
-#define FrameImageText  "  Adding frame to image...  "
+#define FrameImageText  "  Add frame to image...  "
 
   Image
     *frame_image;
@@ -201,8 +201,8 @@ MagickExport Image *FrameImage(Image *image,const FrameInfo *frame_info,
   /*
     Initialize framed image attributes.
   */
-  frame_image=
-    CloneImage(image,frame_info->width,frame_info->height,False,exception);
+  frame_image=CloneImage(image,frame_info->width,frame_info->height,False,
+    exception);
   if (frame_image == (Image *) NULL)
     return(False);
   frame_image->storage_class=DirectClass;
@@ -321,7 +321,7 @@ MagickExport Image *FrameImage(Image *image,const FrameInfo *frame_info,
     if (!SyncImagePixels(frame_image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(FrameImageText,y,image->rows);
+      MagickMonitor(FrameImageText,y,image->rows);
   }
   /*
     Draw bottom of ornamental border.
@@ -419,7 +419,7 @@ MagickExport unsigned int RaiseImage(Image *image,
 #define AccentuateFactor  UpScale(135)
 #define HighlightFactor  UpScale(190)
 #define ShadowFactor  UpScale(190)
-#define RaiseImageText  "  Raising image...  "
+#define RaiseImageText  "  Raise image...  "
 #define TroughFactor  UpScale(135)
 
   int
@@ -493,7 +493,7 @@ MagickExport unsigned int RaiseImage(Image *image,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(i,image->rows))
-      ProgressMonitor(RaiseImageText,i,image->rows);
+      MagickMonitor(RaiseImageText,i,image->rows);
   }
   height=image->rows-(raise_info->height << 1);
   for (y=0; y < (int) height; y++)
@@ -526,7 +526,7 @@ MagickExport unsigned int RaiseImage(Image *image,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(i,image->rows))
-      ProgressMonitor(RaiseImageText,i,image->rows);
+      MagickMonitor(RaiseImageText,i,image->rows);
   }
   for (y=0; y < (int) raise_info->height; y++)
   {
@@ -566,7 +566,7 @@ MagickExport unsigned int RaiseImage(Image *image,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(i,image->rows))
-      ProgressMonitor(RaiseImageText,i,image->rows);
+      MagickMonitor(RaiseImageText,i,image->rows);
   }
   return(True);
 }
