@@ -11,22 +11,10 @@ extern "C" {
 /*
   Review these platform specific definitions.
 */
-#if defined(sgi)
-#if !defined(RGBColorDatabase)
-#define RGBColorDatabase  "/usr/lib/X11/rgb.txt"
-#endif
-#if !defined(ApplicationDefaults)
-#define ApplicationDefaults  "/usr/lib/X11/app-defaults/"
-#endif
-#endif
-
 #if !defined(vms) && !defined(macintosh) && !defined(WIN32)
 #if !defined(ApplicationDefaults)
 #define ApplicationDefaults  "/usr/X11R6/lib/X11/app-defaults/"
 #endif
-#if !defined(DelegatePath)
-#define DelegatePath  "/usr/local/share/ImageMagick/"
-#endif
 #define DirectorySeparator  "/"
 #define DirectoryListSeparator  ':'
 #define EditorOptions  " -title \"Edit Image Comment\" -e vi"
@@ -39,11 +27,17 @@ extern "C" {
    (strchr(text,'}') != (char *) NULL) || \
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
+#if !defined(MagickConfigurePath)
+#define MagickConfigurePath  "/usr/local/share/ImageMagick/"
+#endif
+#if !defined(MagickModulesPath)
+#define MagickModulesPath  "/usr/local/lib/ImageMagick/modules/"
+#endif
 #define PreferencesDefaults  "~/."
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
-#if !defined(RGBColorDatabase)
-#define RGBColorDatabase  "/usr/X11R6/lib/X11/rgb.txt"
+#if !defined(X11ConfigurePath)
+#define X11ConfigurePath  "/usr/X11R6/lib/X11/"
 #endif
 #define SetNotifyHandlers
 #define TemporaryTemplate  "magick"
@@ -51,30 +45,30 @@ extern "C" {
 
 #if defined(vms)
 #define ApplicationDefaults  "decw$system_defaults:"
-#define DelegatePath  "sys$login:"
 #define DirectorySeparator  ""
 #define DirectoryListSeparator  ';'
 #define EditorOptions  ""
 #define Exit  exit
-#define IsBasenameSeparator(c)  ((c) == ']')
+#define IsBasenameSeparator(c)  (((c) == ']') || ((c) == ':') || ((c) == '/'))
 #define IsGlob(text) \
   ((strchr(text,'*') != (char *) NULL) || \
    (strchr(text,'?') != (char *) NULL) || \
    (strchr(text,'{') != (char *) NULL) || \
    (strchr(text,'}') != (char *) NULL))
 #define j1(x)  x
+#define MagickConfigurePath  "sys$login:"
+#define MagickModulesPath  "sys$login:"
 #define PreferencesDefaults  "decw$user_defaults:"
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
-#if !defined(RGBColorDatabase)
-#define RGBColorDatabase  "sys$common:[sysmgr]decw$rgb.dat"
+#if !defined(X11ConfigurePath)
+#define X11ConfigurePath  "sys$common:[sysmgr]rgb.dat"
 #endif
 #define SetNotifyHandlers
 #endif
 
 #if defined(macintosh)
 #define ApplicationDefaults  "/usr/lib/X11/app-defaults/"
-#define DelegatePath  ""
 #define DirectorySeparator  ":"
 #define DirectoryListSeparator  ';'
 #define EditorOptions ""
@@ -87,10 +81,12 @@ extern "C" {
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
 #define j1(x)  x
+#define MagickConfigurePath  ""
+#define MagickModulesPath  ""
 #define PreferencesDefaults  "~/."
 #define ReadCommandlLine(argc,argv)  argc=ccommand(argv); puts(MagickVersion);
-#if !defined(RGBColorDatabase)
-#define RGBColorDatabase  "../xlib/lib/X11/rgb.txt"
+#if !defined(X11ConfigurePath)
+#define X11ConfigurePath  "../xlib/lib/X11/"
 #endif
 #define SetNotifyHandlers \
   SetErrorHandler(MACErrorHandler); \
@@ -99,7 +95,6 @@ extern "C" {
 
 #if defined(WIN32)
 #define ApplicationDefaults  "c:\\ImageMagick\\"
-#define DelegatePath  "c:\\ImageMagick\\"
 #define DirectorySeparator  "\\"
 #define DirectoryListSeparator  ';'
 #define EditorOptions ""
@@ -114,11 +109,13 @@ extern "C" {
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
 #define j1(x)  x
+#define MagickConfigurePath  "c:\\ImageMagick\\"
+#define MagickModulesPath  "c:\\ImageMagick\\"
 #define PreferencesDefaults  "~/."
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
-#if !defined(RGBColorDatabase)
-#define RGBColorDatabase  "c:\\ImageMagick\\rgb.txt"
+#if !defined(X11ConfigurePath)
+#define X11ConfigurePath  "c:\\ImageMagick\\"
 #endif
 #define SetNotifyHandlers \
   SetErrorHandler(NTErrorHandler); \
@@ -145,7 +142,8 @@ extern "C" {
      (((double) (color).green-(double) (target).green)* \
       ((double) (color).green-(double) (target).green))+ \
      (((double) (color).blue-(double) (target).blue)* \
-      ((double) (color).blue-(double) (target).blue))) <= (distance*distance))
+      ((double) (color).blue-(double) (target).blue))) <= \
+      (double) (distance*distance))
 #define Extent(string)  ((int) strlen(string))
 #define False  0
 #define DegreesToRadians(x) (M_PI*(x)/180.0)
@@ -155,7 +153,7 @@ extern "C" {
   (IsMonochromeImage(image) && ((image)->columns <= 2560))
 #define IsGray(color)  \
   (((color).red == (color).green) && ((color).green == (color).blue))
-#define MagickEpsilon  0.00000000001
+#define MagickEpsilon  1.0e-12
 #define Max(x,y)  (((x) > (y)) ? (x) : (y))
 #define MaxApplicationProfiles  16
 #define Min(x,y)  (((x) < (y)) ? (x) : (y))
@@ -167,6 +165,8 @@ extern "C" {
   (((~((span)-i-1) & ((span)-i-2))+1) == ((span)-i-1))
 #define RadiansToDegrees(x) (180.0*(x)/M_PI)
 #define RenderPostscriptText  "  Rendering postscript...  "
+#define ScaleColor5to8(x)  ((x) << 3)
+#define ScaleColor6to8(x)  ((x) << 2)
 #define Swap(x,y) ((x)^=(y), (y)^=(x), (x)^=(y))
 #define True  1
 
