@@ -908,7 +908,8 @@ const char
     "",
     "  Alt-F     Press to add an ornamental border to the image.",
     "",
-    "  Shft-!    Press to add an image comment.",
+    "  Alt-Shft-!",
+    "            Press to add an image comment.",
     "",
     "  Ctl-A     Press to apply image processing techniques to a region",
     "            of interest.",
@@ -1345,7 +1346,7 @@ typedef enum
   ImplodeCommand,
   WaveCommand,
   OilPaintCommand,
-  CharcoalDrawingCommand,
+  CharcoalDrawCommand,
   AnnotateCommand,
   DrawCommand,
   ColorCommand,
