@@ -125,33 +125,21 @@ MagickExport unsigned int ContrastImage(Image *image,const unsigned int sharpen)
         if (QuantumTick(y,image->rows))
           {
             if (sharpen)
-              ProgressMonitor(SharpenContrastImageText,y,image->rows);
+              MagickMonitor(SharpenContrastImageText,y,image->rows);
             else
-              ProgressMonitor(DullContrastImageText,y,image->rows);
+              MagickMonitor(DullContrastImageText,y,image->rows);
           }
       }
       break;
     }
     case PseudoClass:
     {
-      Quantum
-        blue,
-        green,
-        red;
-
       /*
         Contrast enhance PseudoClass image.
       */
       for (i=0; i < (int) image->colors; i++)
-      {
-        red=image->colormap[i].red;
-        green=image->colormap[i].green;
-        blue=image->colormap[i].blue;
-        Contrast(sign,&red,&green,&blue);
-        image->colormap[i].red=red;
-        image->colormap[i].green=green;
-        image->colormap[i].blue=blue;
-      }
+        Contrast(sign,&image->colormap[i].red,&image->colormap[i].green,
+          &image->colormap[i].blue);
       SyncImage(image);
       break;
     }
@@ -258,7 +246,7 @@ MagickExport unsigned int EqualizeImage(Image *image)
   low=map[0];
   high=map[MaxRGB];
   for (i=0; i <= MaxRGB; i++)
-    equalize_map[i]=(unsigned char)
+    equalize_map[i]=(Quantum)
       ((((double) (map[i]-low))*MaxRGB)/Max(high-low,1));
   LiberateMemory((void **) &map);
   /*
@@ -287,7 +275,7 @@ MagickExport unsigned int EqualizeImage(Image *image)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(EqualizeImageText,y,image->rows);
+          MagickMonitor(EqualizeImageText,y,image->rows);
       }
       break;
     }
@@ -434,7 +422,7 @@ MagickExport unsigned int GammaImage(Image *image,const char *gamma)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(GammaImageText,y,image->rows);
+          MagickMonitor(GammaImageText,y,image->rows);
       }
       break;
     }
@@ -542,31 +530,19 @@ MagickExport unsigned int ModulateImage(Image *image,const char *modulate)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(ModulateImageText,y,image->rows);
+          MagickMonitor(ModulateImageText,y,image->rows);
       }
       break;
     }
     case PseudoClass:
     {
-      Quantum
-        blue,
-        green,
-        red;
-
       /*
         Modulate the color for a PseudoClass image.
       */
       for (i=0; i < (int) image->colors; i++)
-      {
-        red=image->colormap[i].red;
-        green=image->colormap[i].green;
-        blue=image->colormap[i].blue;
         Modulate(percent_hue,percent_saturation,percent_brightness,
-          &red,&green,&blue);
-        image->colormap[i].red=red;
-        image->colormap[i].green=green;
-        image->colormap[i].blue=blue;
-      }
+          &image->colormap[i].red,&image->colormap[i].green,
+          &image->colormap[i].blue);
       SyncImage(image);
       break;
     }
@@ -645,7 +621,7 @@ MagickExport unsigned int NegateImage(Image *image,const unsigned int grayscale)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(NegateImageText,y,image->rows);
+          MagickMonitor(NegateImageText,y,image->rows);
       }
       break;
     }
@@ -826,7 +802,7 @@ MagickExport unsigned int NormalizeImage(Image *image)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          ProgressMonitor(NormalizeImageText,y,image->rows);
+          MagickMonitor(NormalizeImageText,y,image->rows);
       }
       break;
     }
