@@ -241,6 +241,103 @@ MagickExport Quantum GenerateNoise(const Quantum pixel,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t O p t i m a l K e r n e l W i d t h                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method GetOptimalKernelWidth computes the optimal kernel radius for a
+%  convolution filter.  Start with the minimum value of 3 pixels and walk out
+%  until we drop below the threshold of one pixel numerical accuracy,
+%
+%  The format of the GetOptimalKernelWidth method is:
+%
+%      int GetOptimalKernelWidth(const double radius,const double sigma)
+%
+%  A description of each parameter follows:
+%
+%    o width: Method GetOptimalKernelWidth returns the optimal width of
+%      a convolution kernel.
+%
+%    o radius: The radius of the Gaussian, in pixels, not counting the center
+%      pixel.
+%
+%    o sigma: The standard deviation of the Gaussian, in pixels.
+%
+%
+*/
+
+MagickExport int GetOptimalKernelWidth1D(const double radius,const double sigma)
+{
+  double
+    normalize,
+    value;
+
+  int
+    width;
+
+  register int
+    u;
+
+  if (radius > 0.0)
+    return((int) (2.0*ceil(radius)+1.0));
+  for (width=5; ;)
+  {
+    normalize=0.0;
+    for (u=(-width/2); u <= (width/2); u++)
+      normalize+=exp((double) -(u*u)/(2.0*sigma*sigma));
+    u=width/2;
+    value=exp((double) -(u*u)/(2.0*sigma*sigma))/normalize;
+    if ((int) (value*MaxRGB) <= 0)
+      break;
+    width+=2;
+  }
+  return(width-2);
+}
+
+MagickExport int GetOptimalKernelWidth2D(const double radius,const double sigma)
+{
+  double
+    normalize,
+    value;
+
+  int
+    width;
+
+  register int
+    u,
+    v;
+
+  if (radius > 0.0)
+    return((int) (2.0*ceil(radius)+1.0));
+  for (width=5; ;)
+  {
+    normalize=0.0;
+    for (v=(-width/2); v <= (width/2); v++)
+    {
+      for (u=(-width/2); u <= (width/2); u++)
+        normalize+=exp((double) -(u*u+v*v)/(sigma*sigma));
+    }
+    v=width/2;
+    value=exp((double) -(v*v)/(sigma*sigma))/normalize;
+    if ((int) (value*MaxRGB) <= 0)
+      break;
+    width+=2;
+  }
+  return(width-2);
+}
+
+MagickExport int GetOptimalKernelWidth(const double radius,const double sigma)
+{
+  return GetOptimalKernelWidth1D(radius,sigma);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   H S L T r a n s f o r m                                                   %
 %                                                                             %
 %                                                                             %
@@ -286,9 +383,9 @@ MagickExport void HSLTransform(const double hue,const double saturation,
     (luminosity+saturation-luminosity*saturation);
   if ((saturation == 0.0) || (hue == -1.0))
     {
-      *red=(unsigned char) (MaxRGB*luminosity+0.5);
-      *green=(unsigned char) (MaxRGB*luminosity+0.5);
-      *blue=(unsigned char) (MaxRGB*luminosity+0.5);
+      *red=(Quantum) (MaxRGB*luminosity+0.5);
+      *green=(Quantum) (MaxRGB*luminosity+0.5);
+      *blue=(Quantum) (MaxRGB*luminosity+0.5);
       return;
     }
   y=2.0*luminosity-v;
@@ -304,9 +401,9 @@ MagickExport void HSLTransform(const double hue,const double saturation,
     case 5: r=v; g=y; b=z; break;
     default: r=v; g=x; b=y; break;
   }
-  *red=(unsigned char) (MaxRGB*r+0.5);
-  *green=(unsigned char) (MaxRGB*g+0.5);
-  *blue=(unsigned char) (MaxRGB*b+0.5);
+  *red=(Quantum) (MaxRGB*r+0.5);
+  *green=(Quantum) (MaxRGB*g+0.5);
+  *blue=(Quantum) (MaxRGB*b+0.5);
 }
 
 /*
