@@ -119,7 +119,7 @@ static pascal void
 %
 %  The format of the BottleneckTest method is:
 %
-%      int ImageFormatConflict(const char *magick)
+%      int BottleneckTest(const char *magick)
 %
 %  A description of each parameter follows:
 %
@@ -1082,7 +1082,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
     }
   GetGWorld(&port,&device);
   theErr=NewGWorld(&graphic_world,0,&(**picture_handle).picFrame,nil,nil,
-    useTempMem|keepLocal);
+    useTempMem | keepLocal);
   if (theErr != noErr && graphic_world == nil)
     {
       DisposeHandle((Handle) picture_handle);
@@ -1131,14 +1131,14 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
   image->rows=picture_info.sourceRect.bottom-picture_info.sourceRect.top;
   if ((depth <= 8) && ((*(picture_info.theColorTable))->ctSize != 0))
     {
+      unsigned int
+        number_colors;
+
       /*
         Colormapped PICT image.
       */
-      image->storage_class=PseudoClass;
-      image->colors=(*(picture_info.theColorTable))->ctSize;
-      image->colormap=(PixelPacket *)
-        AcquireMemory(image->colors*sizeof(PixelPacket));
-      if (image->colormap == (PixelPacket *) NULL)
+      number_colors=(*(picture_info.theColorTable))->ctSize;
+      if (!AllocateImageColormap(image,number_colors))
         {
           if (picture_info.theColorTable != nil)
             DisposeHandle((Handle) picture_info.theColorTable);
@@ -1191,7 +1191,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(LoadImageText,y,image->rows);
+      MagickMonitor(LoadImageText,y,image->rows);
   }
   UnlockPixels(graphic_world->portPixMap);
   SetGWorld(port,device);
