@@ -12,6 +12,7 @@ extern "C" {
 #include <stat.h>
 #include <errno.h>
 #include <Errors.h>
+#include <Files.h>
 
 /*
   Define declarations.
@@ -46,24 +47,27 @@ struct dirent
 /*
   Macintosh utilities routines.
 */
-extern DIR
+extern MagickExport DIR
   *opendir(char *);
 
-extern int
+MagickExport Image
+  *ReadPICTImage(const ImageInfo *,ExceptionInfo *);
+ 
+extern MagickExport int
   Exit(int),
   ImageFormatConflict(const char *),
   MACSystemCommand(const char *);
 
-extern long
+extern MagickExport long
   telldir(DIR *);
 
-extern struct dirent
+extern MagickExport struct dirent
   *readdir(DIR *);
- 
-extern void
+
+extern MagickExport void
   closedir(DIR *),
-  MACErrorHandler(const ErrorType,const char *,const char *),
-  MACWarningHandler(const WarningType,const char *,const char *),
+  MACErrorHandler(const ExceptionType,const char *,const char *),
+  MACWarningHandler(const ExceptionType,const char *,const char *),
   ProcessPendingEvents(const char *),
   seekdir(DIR *,long),
   SetApplicationType(const char *,const char *,OSType);
