@@ -160,6 +160,80 @@ MagickExport char *GetImageMagick(const unsigned char *magick)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t M a g i c k C o n f i g u r e P a t h                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method GetMagickConfigurePath searches a number of pre-defined locations
+%  for the specified ImageMagick configuration file and returns the path.
+%  The search order follows:
+%
+%             MagickConfigurePath
+%             $HOME/.magick/
+%             $MAGICK_HOME/
+%             <program directory>/
+%             MagickModulesPath
+%             X11ConfigurePath
+%
+%  The format of the GetMagickConfigurePath method is:
+%
+%      char *GetMagickConfigurePath(const char *filename)
+%
+%  A description of each parameter follows:
+%
+%    o path:  Method GetMagickConfigurePath returns the path if the
+%      configuration file is found, otherwise NULL is returned.
+%
+%    o filename: A character string representing the desired configuration
+%      file.
+%
+%
+*/
+MagickExport char *GetMagickConfigurePath(const char *filename)
+{
+  char
+    *path;
+
+  path=AllocateString(filename);
+  FormatString(path,"%.1024s%.1024s",MagickModulesPath,filename);
+  if (IsAccessible(path))
+    return(path);
+  if (getenv("HOME") != (char *) NULL)
+    {
+      FormatString(path,"%.1024s%.1024s%.1024s%.1024s%.1024s",getenv("HOME"),
+        *getenv("HOME") == '/' ? ".magick" : "",DirectorySeparator,
+        DirectorySeparator,filename);
+      if (IsAccessible(path))
+        return(path);
+    }
+  if (getenv("MAGICK_HOME") != (char *) NULL)
+    {
+      FormatString(path,"%.1024s%.1024s%.1024s",getenv("MAGICK_HOME"),
+        DirectorySeparator,filename);
+      if (IsAccessible(path))
+        return(path);
+    }
+  FormatString(path,"%.1024s%.1024s%.1024s",SetClientPath((char *) NULL),
+    DirectorySeparator,filename);
+  if (IsAccessible(path))
+    return(path);
+  FormatString(path,"%.1024s%.1024s",MagickConfigurePath,filename);
+  if (IsAccessible(path))
+    return(path);
+  FormatString(path,"%.1024s%.1024s",X11ConfigurePath,filename);
+  if (IsAccessible(path))
+    return(path);
+  LiberateMemory((void **) &path);
+  return((char *) NULL);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t M a g i c k I n f o                                                 %
 %                                                                             %
 %                                                                             %
@@ -402,33 +476,26 @@ MagickExport void MagickIncarnate(const char *path)
       /*
         Set client path.
       */
-      filename=AllocateString(path);
-      p=filename+(Extent(filename)-1);
-      while (p > filename)
-      {
-        if (!IsBasenameSeparator(*p))
+      filename=GetExecutionPath(path);
+      for (p=filename+(Extent(filename)-1); p > filename; p--)
+        if (IsBasenameSeparator(*p))
           {
-            p--;
-            continue;
+            p++;
+            (void) strncpy(directory,filename,p-filename);
+            directory[p-filename]='\0';
+            SetClientPath(directory);
+            (void) strcpy(filename,p);
+            break;
           }
-        *p='\0';
-        SetClientPath(filename);
-        (void) strcpy(filename,p+1);
-        break;
-      }
       /*
         Set client name.
       */
-      p=filename+(Extent(filename)-1);
-      while (p > filename)
-      {
+      for (p=filename+(Extent(filename)-1); p > filename; p--)
         if (*p == '.')
           {
             *p='\0';
             break;
           }
-        p--;
-      }
       SetClientName(filename);
       LiberateMemory((void **) &filename);
     }
@@ -487,9 +554,7 @@ MagickExport MagickInfo *RegisterMagickInfo(MagickInfo *entry)
       if (LocaleCompare(p->tag,entry->tag) == 0)
         {
           p=p->previous;
-          LiberateSemaphore(magick_semaphore);
           UnregisterMagickInfo(entry->tag);
-          AcquireSemaphore(magick_semaphore);
         }
     }
   if (magick_list == (MagickInfo *) NULL)
@@ -601,8 +666,8 @@ MagickExport unsigned int UnregisterMagickInfo(const char *tag)
     status;
 
   assert(tag != (const char *) NULL);
-  status=False;
   AcquireSemaphore(magick_semaphore);
+  status=False;
   for (p=magick_list; p != (MagickInfo *) NULL; p=p->next)
   {
     if (LocaleCompare(p->tag,tag) != 0)
