@@ -10,26 +10,20 @@
 #define __EXTENSIONS__  1
 #define _POSIX_C_SOURCE  199506L
 #define _XOPEN_SOURCE  500
+#ifndef __NetBSD__
 #define _XOPEN_SOURCE_EXTENDED  1
-
-#include <stdio.h>
-#include <stdlib.h>
-
-#if defined(_VISUALC_)
-#  include <direct.h>
-#  define HAVE_STRERROR
-#else
-#  include <unistd.h>
 #endif
 
 #include <stdarg.h>
-#include <string.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
 #define fseek  fseeko
 #define ftell  ftello
 #endif
 
+#include <string.h>
 #include <ctype.h>
 #include <locale.h>
 #include <errno.h>
@@ -39,6 +33,9 @@
 #include <assert.h>
 
 #if !defined(vms) && !defined(macintosh) && !defined(WIN32)
+#if defined(HAVE_VARARGS_H)
+#  include "varargs.h"
+#endif
 #  include <sys/types.h>
 #  include <sys/stat.h>
 #  include <sys/time.h>
@@ -72,6 +69,12 @@
 #  include "api.h"
 #endif
 #include <fcntl.h>
+#if defined(_VISUALC_)
+#  include <direct.h>
+#  define HAVE_STRERROR
+#else
+#  include <unistd.h>
+#endif
 
 /*
   ImageMagick API headers
@@ -86,6 +89,7 @@
 #endif
 
 #if defined(VMS)
+#define inline __inline
 #define HasJPEG
 #define HasPNG
 #define HasTIFF
@@ -95,6 +99,7 @@
 #endif
 
 #if defined(WIN32)
+#define inline __inline
 #define HasJBIG
 #define HasJPEG
 #define HasPNG
@@ -105,15 +110,15 @@
 #define HasBZLIB
 #define HasHDF
 #define HasFPX
-#define HasLZW
 #define HAVE_MMAP
 #define HasXML
-#define HasLZW
+#define HAVE_LIBXML_XML_ERROR_H
 #define HasLCMS
 #endif
 
-#define MagickSignature  0xcafe
+#define MagickSignature  0xabacadab
 
 #undef index
+#undef pipe
 
 #endif
