@@ -58,12 +58,12 @@ typedef struct _ModuleInfo
   time_t
     load_time;
 
-  unsigned int
-    signature;
-
   struct _ModuleInfo
     *previous,
     *next;
+
+  unsigned long
+    signature;
 } ModuleInfo;
 
 /*
