@@ -77,7 +77,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o cloned_info: Method CloneMontageInfo returns a duplicate of the given
+%    o clone_info: Method CloneMontageInfo returns a duplicate of the given
 %      annotate info, or if annotate info is NULL a new one.
 %
 %    o image_info: a structure of type ImageInfo.
@@ -90,29 +90,29 @@ MagickExport MontageInfo *CloneMontageInfo(const ImageInfo *image_info,
   const MontageInfo *montage_info)
 {
   MontageInfo
-    *cloned_info;
+    *clone_info;
 
-  cloned_info=(MontageInfo *) AcquireMemory(sizeof(MontageInfo));
-  if (cloned_info == (MontageInfo *) NULL)
+  clone_info=(MontageInfo *) AcquireMemory(sizeof(MontageInfo));
+  if (clone_info == (MontageInfo *) NULL)
     MagickError(ResourceLimitError,"Unable to clone montage info",
       "Memory allocation failed");
   if (montage_info == (MontageInfo *) NULL)
     {
-      GetMontageInfo(image_info,cloned_info);
-      return(cloned_info);
+      GetMontageInfo(image_info,clone_info);
+      return(clone_info);
     }
-  *cloned_info=(*montage_info);
+  *clone_info=(*montage_info);
   if (montage_info->geometry != (char *) NULL)
-    cloned_info->geometry=AllocateString(montage_info->geometry);
+    clone_info->geometry=AllocateString(montage_info->geometry);
   if (montage_info->tile != (char *) NULL)
-    cloned_info->tile=AllocateString(montage_info->tile);
+    clone_info->tile=AllocateString(montage_info->tile);
   if (montage_info->frame != (char *) NULL)
-    cloned_info->frame=AllocateString(montage_info->frame);
+    clone_info->frame=AllocateString(montage_info->frame);
   if (montage_info->texture != (char *) NULL)
-    cloned_info->texture=AllocateString(montage_info->texture);
+    clone_info->texture=AllocateString(montage_info->texture);
   if (montage_info->font != (char *) NULL)
-    cloned_info->font=AllocateString(montage_info->font);
-  return(cloned_info);
+    clone_info->font=AllocateString(montage_info->font);
+  return(clone_info);
 }
 
 /*
@@ -190,17 +190,13 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   assert(montage_info != (MontageInfo *) NULL);
+  memset(montage_info,0,sizeof(MontageInfo));
   (void) strcpy(montage_info->filename,image_info->filename);
   montage_info->geometry=AllocateString(DefaultTileGeometry);
   montage_info->tile=AllocateString("6x4");
-  montage_info->title=(char *) NULL;
-  montage_info->frame=(char *) NULL;
-  montage_info->texture=(char *) NULL;
   montage_info->font=AllocateString(image_info->font);
   montage_info->pointsize=image_info->pointsize;
-  montage_info->border_width=0;
   montage_info->gravity=CenterGravity;
-  montage_info->shadow=False;
   montage_info->compose=ReplaceCompositeOp;
   montage_info->fill=image_info->fill;
   montage_info->stroke=image_info->stroke;
@@ -304,8 +300,8 @@ static int SceneCompare(const void *x,const void *y)
 MagickExport Image *MontageImages(Image *image,const MontageInfo *montage_info,
   ExceptionInfo *exception)
 {
-#define MontageImageText  "  Creating visual next directory...  "
-#define TileImageText  "  Creating next tiles...  "
+#define MontageImageText  "  Create visual next directory...  "
+#define TileImageText  "  Create image tiles...  "
 
   AnnotateInfo
     *annotate_info;
@@ -402,7 +398,7 @@ MagickExport Image *MontageImages(Image *image,const MontageInfo *montage_info,
       }
     next_list[tile]=tiled_next;
     (void) SetMonitorHandler(handler);
-    ProgressMonitor(TileImageText,tile,number_images);
+    MagickMonitor(TileImageText,tile,number_images);
   }
   /*
     Sort next_list by increasing tile number.
@@ -515,10 +511,10 @@ MagickExport Image *MontageImages(Image *image,const MontageInfo *montage_info,
   /*
     Initialize font info.
   */
-  font_height=(unsigned int) (clone_info->affine[0]*annotate_info->pointsize+
-    clone_info->affine[2]*annotate_info->pointsize);
+  font_height=(unsigned int) (clone_info->affine.sx*annotate_info->pointsize+
+    clone_info->affine.ry*annotate_info->pointsize);
   title=TranslateText(clone_info,image,montage_info->title);
-  FormatLabel(clone_info,title,0.5*tile_info.width+2*border_width*
+  FormatLabel(clone_info,title,tile_info.width/2+2*border_width*
     Min(number_images,tiles_per_column),&font_height);
   for (tile=0; tile < number_images; tile++)
   {
@@ -591,7 +587,7 @@ MagickExport Image *MontageImages(Image *image,const MontageInfo *montage_info,
     /*
       Set montage geometry.
     */
-    montage_next->montage=(char *) AcquireMemory(MaxTextExtent);
+    montage_next->montage=AllocateString((char *) NULL);
     count=1;
     for (tile=0; tile < tiles_per_page; tile++)
       count+=Extent(next_list[tile]->filename)+1;
@@ -838,9 +834,10 @@ MagickExport Image *MontageImages(Image *image,const MontageInfo *montage_info,
             number_lines+(montage_info->shadow ? 4 : 0);
           max_height=0;
         }
-      DestroyImage(next);
+      if (next != next_list[tile])
+        DestroyImage(next);
       (void) SetMonitorHandler(handler);
-      ProgressMonitor(MontageImageText,tiles,total_tiles);
+      MagickMonitor(MontageImageText,tiles,total_tiles);
       tiles++;
     }
     if ((i+1) < (int) image_per_page)
