@@ -271,39 +271,13 @@ int lt_dlinit(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   l t _ d l e r r o r                                                       %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%   Method lt_dlerror returns the last error that occurred in the dynamic
-%   module loading subsystem.
-%
-%  The format of the lt_dlerror method is:
-%
-%      char *lt_dlerror(void)
-%
-%  A description of each parameter follows:
-%
-*/
-char *lt_dlerror(void)
-{
-  return(ntgetlasterror());
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   l t _ d l o p e n                                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%   Method lt_dlopen loads a dynamic module into memory and returs a handle
+%   Method lt_dlopen loads a dynamic module into memory and returns a handle
 %   that can be used to access the various procedures in the module.
 %
 %  The format of the lt_dlopen method is:
@@ -637,22 +611,51 @@ MagickExport void NTErrorHandler(const ExceptionType error,const char *message,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   n t g e t l a s t e r r o r                                               %
+%   N T G e t E x e c u t i o n P a t h                                       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method NTGetLastError converts the last error generated by a Win32 API call
-%  into a human readable string. It is similar to the UNIX perror function.
+%  Method NTGetExecutionPath returns the execution path of a program.
 %
-%  The format of the NTGetLastError method is:
+%  The format of the GetExecutionPath method is:
 %
-%      char *NTGetLastError()
+%      char *NTGetExecutionPath(void)
 %
 %
 */
-MagickExport char *ntgetlasterror(void)
+MagickExport char *NTGetExecutionPath(void)
+{
+  char
+    *path;
+
+  path=AllocateString((char *) NULL);
+  GetModuleFileName(0,path,MaxTextExtent);
+  return(path);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   N T G e t L a s t E r r o r                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%   Method NTGetLastError returns the last error that occurred.
+%
+%  The format of the lt_dlerror method is:
+%
+%      char *NTGetLastError(void)
+%
+%  A description of each parameter follows:
+%
+*/
+char *NTGetLastError(void)
 {
   char
     *message;
@@ -779,7 +782,7 @@ MagickExport int NTSystemCommand(const char *command)
 MagickExport int NTTemporaryFilename(char *filename)
 {
   char
-    path[1024];
+    path[MaxTextExtent];
 
   int
     status;
@@ -889,7 +892,7 @@ MagickExport void NTWarningHandler(const ExceptionType warning,
   const char *message,const char *qualifier)
 {
   char
-    buffer[2048];
+    buffer[2*MaxTextExtent];
 
   if (message == (char *) NULL)
     return;
