@@ -293,6 +293,9 @@ typedef struct _CubeInfo
 /*
   Method prototypes.
 */
+static void
+  ClosestColor(CubeInfo *,const NodeInfo *);
+
 static NodeInfo
   *GetNodeInfo(CubeInfo *,const unsigned int,const unsigned int,NodeInfo *);
 
@@ -300,7 +303,6 @@ static unsigned int
   DitherImage(CubeInfo *,Image *);
 
 static void
-  ClosestColor(CubeInfo *,const NodeInfo *),
   DefineColormap(CubeInfo *,NodeInfo *),
   HilbertCurve(CubeInfo *,Image *,const int,const unsigned int),
   PruneLevel(CubeInfo *,const NodeInfo *),
@@ -442,7 +444,7 @@ static unsigned int Assignment(CubeInfo *cube_info,Image *image)
       if (!SyncImagePixels(image))
         break;
       if (QuantumTick(y,image->rows))
-        ProgressMonitor(AssignImageText,y,image->rows);
+        MagickMonitor(AssignImageText,y,image->rows);
     }
   if ((cube_info->quantize_info->number_colors == 2) &&
       (cube_info->quantize_info->colorspace == GRAYColorspace))
@@ -637,7 +639,7 @@ static unsigned int Classification(CubeInfo *cube_info,Image *image)
       p++;
     }
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(ClassifyImageText,y,image->rows);
+      MagickMonitor(ClassifyImageText,y,image->rows);
   }
   return(True);
 }
@@ -1162,8 +1164,7 @@ static unsigned int GetCubeInfo(CubeInfo *cube_info,
     Initialize root node.
   */
   cube_info->root=GetNodeInfo(cube_info,0,0,(NodeInfo *) NULL);
-  cube_info->squares=(double *)
-    AcquireMemory((MaxRGB+MaxRGB+1)*sizeof(double));
+  cube_info->squares=(double *) AcquireMemory((MaxRGB+MaxRGB+1)*sizeof(double));
   if ((cube_info->root == (NodeInfo *) NULL) ||
       (cube_info->squares == (double *) NULL))
     return(False);
@@ -1307,11 +1308,8 @@ static NodeInfo *GetNodeInfo(CubeInfo *cube_info,const unsigned int id,
 MagickExport void GetQuantizeInfo(QuantizeInfo *quantize_info)
 {
   assert(quantize_info != (QuantizeInfo *) NULL);
-  quantize_info->number_colors=0;
-  quantize_info->tree_depth=0;
-  quantize_info->dither=False;
+  memset(quantize_info,0,sizeof(QuantizeInfo));
   quantize_info->colorspace=RGBColorspace;
-  quantize_info->measure_error=False;
   quantize_info->signature=MagickSignature;
 }
 
@@ -1715,7 +1713,7 @@ static unsigned int OrderedDitherImage(Image *image)
     if (!SyncImagePixels(image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(DitherImageText,y,image->rows);
+      MagickMonitor(DitherImageText,y,image->rows);
   }
   return(True);
 }
@@ -2158,7 +2156,7 @@ MagickExport unsigned int QuantizeImages(const QuantizeInfo *quantize_info,
       break;
     image=image->next;
     (void) SetMonitorHandler(handler);
-    ProgressMonitor(ClassifyImageText,i,number_images);
+    MagickMonitor(ClassifyImageText,i,number_images);
   }
   if (status != False)
     {
@@ -2177,7 +2175,7 @@ MagickExport unsigned int QuantizeImages(const QuantizeInfo *quantize_info,
           TransformRGBImage(image,quantize_info->colorspace);
         image=image->next;
         (void) SetMonitorHandler(handler);
-        ProgressMonitor(AssignImageText,i,number_images);
+        MagickMonitor(AssignImageText,i,number_images);
       }
     }
   DestroyCubeInfo(&cube_info);
@@ -2309,7 +2307,7 @@ static void Reduction(CubeInfo *cube_info,const unsigned int number_colors)
     cube_info->next_pruning_threshold=cube_info->root->quantization_error;
     cube_info->colors=0;
     Reduce(cube_info,cube_info->root);
-    ProgressMonitor(ReduceImageText,span-cube_info->colors,
+    MagickMonitor(ReduceImageText,span-cube_info->colors,
       span-number_colors+1);
   }
 }
