@@ -29,6 +29,9 @@ typedef struct _QuantizeInfo
 
   unsigned int
     measure_error;
+
+  unsigned long
+    signature;
 } QuantizeInfo;
 
 /*
