@@ -97,7 +97,7 @@
 MagickExport Image *ChopImage(Image *image,const RectangleInfo *chop_info,
   ExceptionInfo *exception)
 {
-#define ChopImageText  "  Chopping image...  "
+#define ChopImageText  "  Chop image...  "
 
   Image
     *chop_image;
@@ -184,7 +184,7 @@ MagickExport Image *ChopImage(Image *image,const RectangleInfo *chop_info,
     if (!SyncImagePixels(chop_image))
       break;
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(ChopImageText,y,image->rows);
+      MagickMonitor(ChopImageText,y,image->rows);
   }
   /*
     Extract chop image.
@@ -212,7 +212,7 @@ MagickExport Image *ChopImage(Image *image,const RectangleInfo *chop_info,
     if (!SyncImagePixels(chop_image))
       break;
     if (QuantumTick(i,image->rows))
-      ProgressMonitor(ChopImageText,i,image->rows);
+      MagickMonitor(ChopImageText,i,image->rows);
   }
   return(chop_image);
 }
@@ -264,7 +264,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
   /*
     Clone first next in sequence.
   */
-  coalesce_image=CloneImage(image,image->columns,image->rows,True,exception);
+  coalesce_image=CloneImage(image,0,0,True,exception);
   if (coalesce_image == (Image *) NULL)
     return((Image *) NULL);
   GetPageInfo(&coalesce_image->page);
@@ -273,8 +273,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
   */
   for (next=image->next; next != (Image *) NULL; next=next->next)
   {
-    coalesce_image->next=CloneImage(coalesce_image,coalesce_image->columns,
-      coalesce_image->rows,True,exception);
+    coalesce_image->next=CloneImage(coalesce_image,0,0,True,exception);
     if (coalesce_image->next == (Image *) NULL)
       {
         DestroyImages(coalesce_image);
@@ -334,7 +333,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
 MagickExport Image *CropImage(Image *image,const RectangleInfo *crop_info,
   ExceptionInfo *exception)
 {
-#define CropImageText  "  Cropping image...  "
+#define CropImageText  "  Crop image...  "
 
   Image
     *crop_image;
@@ -349,9 +348,6 @@ MagickExport Image *CropImage(Image *image,const RectangleInfo *crop_info,
     *crop_indexes,
     *indexes;
 
-  register int
-    x;
-
   register PixelPacket
     *p,
     *q;
@@ -393,76 +389,16 @@ MagickExport Image *CropImage(Image *image,const RectangleInfo *crop_info,
     }
   else
     {
-      int
-        x_border,
-        y_border;
-
-      PixelPacket
-        corners[3];
-
       /*
         Set bounding box to the image dimensions.
       */
-      x_border=page.x;
-      y_border=page.y;
-      page.width=0;
-      page.height=0;
-      page.x=image->columns;
-      page.y=image->rows;
-      corners[0]=GetOnePixel(image,0,0);
-      corners[1]=GetOnePixel(image,image->columns-1,0);
-      corners[2]=GetOnePixel(image,0,image->rows-1);
-      for (y=0; y < (int) image->rows; y++)
-      {
-        p=GetImagePixels(image,0,y,image->columns,1);
-        if (p == (PixelPacket *) NULL)
-          break;
-        if (image->matte)
-          for (x=0; x < (int) image->columns; x++)
-          {
-            if (p->opacity != corners[0].opacity)
-              if (x < page.x)
-                page.x=x;
-            if (p->opacity != corners[1].opacity)
-              if (x > (int) page.width)
-                page.width=x;
-            if (p->opacity != corners[0].opacity)
-              if (y < page.y)
-                page.y=y;
-            if (p->opacity != corners[2].opacity)
-              if (y > (int) page.height)
-                page.height=y;
-            p++;
-          }
-        else
-          for (x=0; x < (int) image->columns; x++)
-          {
-            if (!ColorMatch(*p,corners[0],image->fuzz))
-              if (x < page.x)
-                page.x=x;
-            if (!ColorMatch(*p,corners[1],image->fuzz))
-              if (x > (int) page.width)
-                page.width=x;
-            if (!ColorMatch(*p,corners[0],image->fuzz))
-              if (y < page.y)
-                page.y=y;
-            if (!ColorMatch(*p,corners[2],image->fuzz))
-              if (y > (int) page.height)
-                page.height=y;
-            p++;
-          }
-      }
-      if ((page.width != 0) || (page.height != 0))
-        {
-          page.width-=page.x-1;
-          page.height-=page.y-1;
-        }
-      page.width+=x_border*2;
-      page.height+=y_border*2;
-      page.x-=x_border;
+      page=GetImageBoundingBox(image);
+      page.width+=crop_info->x*2;
+      page.height+=crop_info->y*2;
+      page.x-=crop_info->x;
       if (page.x < 0)
         page.x=0;
-      page.y-=y_border;
+      page.y-=crop_info->y;
       if (page.y < 0)
         page.y=0;
       if ((((int) page.width+page.x) > (int) image->columns) ||
@@ -500,7 +436,7 @@ MagickExport Image *CropImage(Image *image,const RectangleInfo *crop_info,
     if (!SyncImagePixels(crop_image))
       break;
     if (QuantumTick(y,crop_image->rows))
-      ProgressMonitor(CropImageText,y,crop_image->rows-1);
+      MagickMonitor(CropImageText,y,crop_image->rows-1);
   }
   if (y < (int) crop_image->rows)
     {
@@ -668,7 +604,7 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
   /*
     Clone first next in sequence.
   */
-  deconstruct_image=CloneImage(image,image->columns,image->rows,True,exception);
+  deconstruct_image=CloneImage(image,0,0,True,exception);
   if (deconstruct_image == (Image *) NULL)
     {
       LiberateMemory((void **) &bounds);
@@ -727,7 +663,7 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
 */
 MagickExport Image *FlipImage(Image *image,ExceptionInfo *exception)
 {
-#define FlipImageText  "  Flipping image...  "
+#define FlipImageText  "  Flip image...  "
 
   Image
     *flip_image;
@@ -782,7 +718,7 @@ MagickExport Image *FlipImage(Image *image,ExceptionInfo *exception)
     if (status == False)
       break;
     if (QuantumTick(y,flip_image->rows))
-      ProgressMonitor(FlipImageText,y,flip_image->rows);
+      MagickMonitor(FlipImageText,y,flip_image->rows);
   }
   return(flip_image);
 }
@@ -820,7 +756,7 @@ MagickExport Image *FlipImage(Image *image,ExceptionInfo *exception)
 */
 MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
 {
-#define FlopImageText  "  Flopping image...  "
+#define FlopImageText  "  Flop image...  "
 
   Image
     *flop_image;
@@ -876,7 +812,7 @@ MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
     if (status == False)
       break;
     if (QuantumTick(y,flop_image->rows))
-      ProgressMonitor(FlopImageText,y,flop_image->rows);
+      MagickMonitor(FlopImageText,y,flop_image->rows);
   }
   return(flop_image);
 }
@@ -892,11 +828,14 @@ MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method ProfileImage removes or adds a ICC or IPTC profile to an image.
+%  Method ProfileImage removes or adds a ICC, IPTC, or generic profile to an
+%  image.  If the profile name is specified it is deleted from the image.  If
+%  a filename is specified, one or more profiles are read and added to the
+%  image.
 %
 %  The format of the ProfileImage method is:
 %
-%      unsigned int ProfileImage(Image *image,const ProfileType type,
+%      unsigned int ProfileImage(Image *image,const char *profile_name,
 %        const char *filename)
 %
 %  A description of each parameter follows:
@@ -906,79 +845,81 @@ MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
 %
 %    o image: The address of a structure of type Image.
 %
-%    o type: Specifies the type of profile to add or remove.
+%    o profile_name: Specifies the type of profile to add or remove.
 %
 %    o filename: Specifies the filename of the ICC or IPTC profile.
 %
 %
 */
-MagickExport unsigned int ProfileImage(Image *image,const ProfileType type,
+MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
   const char *filename)
 {
   Image
-    *profile;
+    *profile_image;
 
   ImageInfo
     *image_info;
 
+  register int
+    i,
+    j;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (filename == (const char *) NULL)
     {
       /*
-        Remove a ICC or IPTC profile from the image.
+        Remove a ICC, IPTC, or generic profile from the image.
       */
-      switch (type)
-      {
-        case ICMProfile:
+      if (LocaleCompare("icm",profile_name) == 0)
         {
           if (image->color_profile.length != 0)
             LiberateMemory((void **) &image->color_profile.info);
           image->color_profile.length=0;
           image->color_profile.info=(unsigned char *) NULL;
-          break;
         }
-        case IPTCProfile:
+      if ((LocaleCompare("8bim",profile_name) == 0) ||
+          (LocaleCompare("iptc",profile_name) == 0))
         {
           if (image->iptc_profile.length != 0)
             LiberateMemory((void **) &image->iptc_profile.info);
           image->iptc_profile.length=0;
           image->iptc_profile.info=(unsigned char *) NULL;
-          break;
         }
-        default:
-          break;
+      for (i=0; i < image->generic_profiles; i++)
+      {
+        if (LocaleCompare(image->generic_profile[i].name,profile_name) != 0)
+          continue;
+        if (image->generic_profile[i].name != (char *) NULL)
+          LiberateMemory((void **) &image->generic_profile[i].name);
+        if (image->iptc_profile.length != 0)
+          LiberateMemory((void **) &image->generic_profile[i].info);
+        image->generic_profiles--;
+        for (j=i; j < image->generic_profiles; j++)
+          image->generic_profile[j]=image->generic_profile[j+1];
+        i--;
       }
       return(True);
     }
   /*
-    Add a ICC or IPTC profile to the image.
+    Add a ICC, IPTC, or generic profile to the image.
   */
   image_info=CloneImageInfo((ImageInfo *) NULL);
   (void) strcpy(image_info->filename,filename);
-  profile=ReadImage(image_info,&image->exception);
+  profile_image=ReadImage(image_info,&image->exception);
   DestroyImageInfo(image_info);
-  if (profile == (Image *) NULL)
+  if (profile_image == (Image *) NULL)
     return(False);
-  if (LocaleCompare("iptc",profile->magick) == 0)
+  if (profile_image->iptc_profile.length > 0)
     {
       if (image->iptc_profile.length != 0)
         LiberateMemory((void **) &image->iptc_profile.info);
-      image->iptc_profile.length=profile->iptc_profile.length;
-      image->iptc_profile.info=profile->iptc_profile.info;
-      profile->iptc_profile.length=0;
-      profile->iptc_profile.info=(unsigned char *) NULL;
+      image->iptc_profile.length=profile_image->iptc_profile.length;
+      image->iptc_profile.info=profile_image->iptc_profile.info;
+      profile_image->iptc_profile.length=0;
+      profile_image->iptc_profile.info=(unsigned char *) NULL;
     }
-  if (LocaleCompare("8bim",profile->magick) == 0)
-    {
-      if (image->iptc_profile.length != 0)
-        LiberateMemory((void **) &image->iptc_profile.info);
-      image->iptc_profile.length=profile->iptc_profile.length;
-      image->iptc_profile.info=profile->iptc_profile.info;
-      profile->iptc_profile.length=0;
-      profile->iptc_profile.info=(unsigned char *) NULL;
-    }
-  if (LocaleCompare("icm",profile->magick) == 0)
+  if (profile_image->color_profile.length > 0)
     {
       if (image->color_profile.length != 0)
         {
@@ -1018,8 +959,9 @@ MagickExport unsigned int ProfileImage(Image *image,const ProfileType type,
           */
           image_profile=cmsOpenProfileFromMem(image->color_profile.info,
             image->color_profile.length);
-          transform_profile=cmsOpenProfileFromMem(profile->color_profile.info,
-            profile->color_profile.length);
+          transform_profile=cmsOpenProfileFromMem(
+            profile_image->color_profile.info,
+            profile_image->color_profile.length);
           if ((image_profile == (cmsHPROFILE) NULL) ||
               (transform_profile == (cmsHPROFILE) NULL))
             ThrowBinaryException(ResourceLimitWarning,"Unable to manage color",
@@ -1068,12 +1010,45 @@ MagickExport unsigned int ProfileImage(Image *image,const ProfileType type,
 #endif
           LiberateMemory((void **) &image->color_profile.info);
         }
-      image->color_profile.length=profile->color_profile.length;
-      image->color_profile.info=profile->color_profile.info;
-      profile->color_profile.length=0;
-      profile->color_profile.info=(unsigned char *) NULL;
+      image->color_profile.length=profile_image->color_profile.length;
+      image->color_profile.info=profile_image->color_profile.info;
+      profile_image->color_profile.length=0;
+      profile_image->color_profile.info=(unsigned char *) NULL;
     }
-  DestroyImage(profile);
+  if (profile_image->generic_profiles > 0)
+    {
+      unsigned int
+        number_profiles;
+
+      number_profiles=image->generic_profiles+profile_image->generic_profiles;
+      if (image->generic_profile == (ProfileInfo *) NULL)
+        image->generic_profile=(ProfileInfo *)
+          AcquireMemory(number_profiles*sizeof(ProfileInfo));
+      else
+        ReacquireMemory((void **) &image->generic_profile,
+          number_profiles*sizeof(ProfileInfo));
+      if (image->generic_profile == (ProfileInfo *) NULL)
+        {
+          image->generic_profiles=0;
+          DestroyImage(profile_image);
+          ThrowBinaryException(ResourceLimitWarning,"Memory allocation failed",
+            (char *) NULL);
+        }
+      j=image->generic_profiles;
+      for (i=0; i < profile_image->generic_profiles; i++)
+      {
+        image->generic_profile[j].name=profile_image->generic_profile[i].name;
+        image->generic_profile[j].length=
+          profile_image->generic_profile[i].length;
+        image->generic_profile[j].info=profile_image->generic_profile[i].info;
+        profile_image->generic_profile[i].name=(char *) NULL;
+        profile_image->generic_profile[i].length=0;
+        profile_image->generic_profile[i].info=(unsigned char *) NULL;
+        j++;
+      }
+      image->generic_profiles=number_profiles;
+    }
+  DestroyImage(profile_image);
   return(True);
 }
 
@@ -1117,7 +1092,7 @@ MagickExport unsigned int ProfileImage(Image *image,const ProfileType type,
 MagickExport Image *RollImage(Image *image,const int x_offset,
   const int y_offset,ExceptionInfo *exception)
 {
-#define RollImageText  "  Rolling image...  "
+#define RollImageText  "  Roll image...  "
 
   Image
     *roll_image;
@@ -1182,7 +1157,7 @@ MagickExport Image *RollImage(Image *image,const int x_offset,
         break;
     }
     if (QuantumTick(y,image->rows))
-      ProgressMonitor(RollImageText,y,image->rows);
+      MagickMonitor(RollImageText,y,image->rows);
   }
   return(roll_image);
 }
@@ -1352,16 +1327,16 @@ MagickExport void TransformImage(Image **image,const char *crop_geometry,
   if ((transform_image->columns != width) || (transform_image->rows != height))
     {
       Image
-        *zoom_image;
+        *resize_image;
 
       /*
         Zoom image.
       */
-      zoom_image=ZoomImage(transform_image,width,height,&(*image)->exception);
-      if (zoom_image != (Image *) NULL)
+      resize_image=ZoomImage(transform_image,width,height,&(*image)->exception);
+      if (resize_image != (Image *) NULL)
         {
           DestroyImage(transform_image);
-          transform_image=zoom_image;
+          transform_image=resize_image;
         }
     }
   *image=transform_image;
