@@ -87,13 +87,19 @@ MagickExport char *AllocateString(const char *source)
   char
     *destination;
 
-  if (source == (char *) NULL)
-    return((char *) NULL);
-  destination=(char *) AcquireMemory(Extent(source)+MaxTextExtent);
+  unsigned int
+    length;
+
+  length=MaxTextExtent;
+  if (source != (char *) NULL)
+    length+=Extent(source);
+  destination=(char *) AcquireMemory(length);
   if (destination == (char *) NULL)
     MagickError(ResourceLimitError,"Unable to allocate string",
       "Memory allocation failed");
-  (void) strcpy(destination,source);
+  *destination='\0';
+  if (source != (char *) NULL)
+    (void) strcpy(destination,source);
   return(destination);
 }
 
@@ -710,6 +716,42 @@ MagickExport void FormatString(char *string,const char *format,...)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t E x e c u t i o n P a t h                                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method GetExecutionPath function returns the pathname of the executable
+%  that started the process.
+%
+%  The format of the GetExecutionPath method is:
+%
+%      char *GetExecutionPath(const char *path)
+%
+%  A description of each parameter follows:
+%
+%    o execution_path: Method GetExecutionPath returns the pathname of the
+%      executable that started the process.
+%
+%    o path: This character string is returned if no method is available to
+%      determine the pathname of the executable.
+%
+%
+*/
+MagickExport char *GetExecutionPath(const char *path)
+{
+#if defined(WIN32)
+  return(NTGetExecutionPath());
+#endif
+  return(AllocateString(path));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t G e o m e t r y                                                     %
 %                                                                             %
 %                                                                             %
@@ -1200,12 +1242,12 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
 {
   char
     color[MaxTextExtent],
-    filename[MaxTextExtent],
     **colorlist,
+    *path,
     text[MaxTextExtent];
 
   FILE
-    *database;
+    *file;
 
   int
     blue,
@@ -1229,12 +1271,14 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
     Open database.
   */
   *number_colors=0;
-  FormatString(filename,"%s%s%s",SetClientPath((char *) NULL),
-    DirectorySeparator,"rgb.txt");
-  database=fopen(filename,"r");
-  if (database == (FILE *) NULL)
-     database=fopen(RGBColorDatabase,"r");
-  if (database == (FILE *) NULL)
+  file=(FILE *) NULL;
+  path=GetMagickConfigurePath("rgb.txt");
+  if (path != (char *) NULL)
+    {
+      file=fopen(path,"r");
+      LiberateMemory((void **) &path);
+    }
+  if (file == (FILE *) NULL)
     {
       register const ColorlistInfo
         *p;
@@ -1245,8 +1289,7 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
       for (p=XColorlist; p->name != (char *) NULL; p++)
         if (GlobExpression(p->name,pattern))
           {
-            colorlist[*number_colors]=(char *)
-              AcquireMemory(Extent(p->name)+1);
+            colorlist[*number_colors]=(char *) AcquireMemory(Extent(p->name)+1);
             if (colorlist[*number_colors] == (char *) NULL)
               break;
             (void) strcpy(colorlist[*number_colors],p->name);
@@ -1254,7 +1297,7 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
           }
       return(colorlist);
     }
-  while (fgets(text,MaxTextExtent,database) != (char *) NULL)
+  while (fgets(text,MaxTextExtent,file) != (char *) NULL)
   {
     count=sscanf(text,"%d %d %d %[^\n]\n",&red,&green,&blue,color);
     if (count != 4)
@@ -1267,7 +1310,7 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
             ReacquireMemory((void **) &colorlist,max_colors*sizeof(char *));
             if (colorlist == (char **) NULL)
               {
-                (void) fclose(database);
+                (void) fclose(file);
                 return((char **) NULL);
               }
           }
@@ -1278,7 +1321,7 @@ MagickExport char **ListColors(const char *pattern,int *number_colors)
         (*number_colors)++;
       }
   }
-  (void) fclose(database);
+  (void) fclose(file);
   /*
     Sort colorlist in ascending order.
   */
@@ -1785,11 +1828,13 @@ MagickExport int ParseGeometry(const char *geometry,int *x,int *y,
     bounds;
 
   mask=NoValue;
-  if ((geometry == (const char *) NULL) || (*geometry == '\0'))
+  if (geometry == (const char *) NULL)
     return(mask);
   p=(char *) geometry;
   while (isspace((int) *p))
     p++;
+  if (*p == '\0')
+    return(mask);
   if (*p == '=')
     p++;
   if (LocaleCompare(p,"0x0") == 0)
@@ -1989,10 +2034,7 @@ MagickExport char *PostscriptGeometry(const char *page)
   /*
     Allocate page geometry memory.
   */
-  geometry=(char *) AcquireMemory(Extent(page)+MaxTextExtent);
-  if (geometry == (char *) NULL)
-    MagickError(ResourceLimitError,"Unable to translate page geometry",
-      "Memory allocation failed");
+  geometry=AllocateString(page);
   *geometry='\0';
   if (page == (char *) NULL)
     return(geometry);
@@ -2089,7 +2131,7 @@ MagickExport char *SetClientName(const char *name)
 MagickExport char *SetClientPath(const char *path)
 {
   static char
-    client_path[MaxTextExtent] = DelegatePath;
+    client_path[MaxTextExtent] = MagickConfigurePath;
 
   if (path == (char *) NULL)
     return(client_path);
@@ -2504,12 +2546,11 @@ MagickExport void TemporaryFilename(char *filename)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method Tokenizer is a generalized, finite state token parser.  It
-%  extracts tokens one at a time from a string of characters.  The
-%  characters used for white space, for break characters, and for quotes
-%  can be specified.  Also, characters in the string can be preceded by
-%  a specifiable escape character which removes any special meaning the
-%  character may have.
+%  Method Tokenizer is a generalized, finite state token parser.  It extracts
+%  tokens one at a time from a string of characters.  The characters used for
+%  white space, for break characters, and for quotes can be specified.  Also,
+%  characters in the string can be preceded by a specifiable escape character
+%  which removes any special meaning the character may have.
 %
 %  Here is some terminology:
 %
@@ -2517,18 +2558,17 @@ MagickExport void TemporaryFilename(char *filename)
 %      characters.
 %
 %    o white space: Apace that gets ignored (except within quotes or when
-%      escaped), like blanks and tabs. in addition, white space terminates
-%      a non-quoted token.
+%      escaped), like blanks and tabs. in addition, white space terminates a
+%      non-quoted token.
 %
 %    o break set: One or more characters that separates non-quoted tokens.
-%      Commas are a common break character. The usage of break characters
-%      to signal the end of a token is the same as that of white space,
-%      except multiple break characters with nothing or only white space
-%      between generate a null token for each two break characters
-%      together.
+%      Commas are a common break character. The usage of break characters to
+%      signal the end of a token is the same as that of white space, except
+%      multiple break characters with nothing or only white space between
+%      generate a null token for each two break characters together.
 %
-%      For example, if blank is set to be the white space and comma is set
-%      to be the break character, the line
+%      For example, if blank is set to be the white space and comma is set to
+%      be the break character, the line
 %
 %        A, B, C ,  , DEF
 %
@@ -2540,12 +2580,12 @@ MagickExport void TemporaryFilename(char *filename)
 %        4)  "" (the null string)
 %        5)  "DEF"
 %
-%    o Quote character: A character that, when surrounding a group of
-%      other characters, causes the group of characters to be treated as a
-%      single token, no matter how many white spaces or break characters
-%      exist in the group. Also, a token always terminates after the
-%      closing quote. For example, if ' is the quote character, blank is
-%      white space, and comma is the break character, the following string
+%    o Quote character: A character that, when surrounding a group of other
+%      characters, causes the group of characters to be treated as a single
+%      token, no matter how many white spaces or break characters exist in
+%      the group. Also, a token always terminates after the closing quote.
+%      For example, if ' is the quote character, blank is white space, and
+%      comma is the break character, the following string
 %
 %        A, ' B, CD'EF GHI
 %
@@ -2675,31 +2715,30 @@ static int sindex(char c,char *string)
 static void StoreToken(TokenInfo *token_info,char *string,int max_token_length,
   char c)
 {
-  if ((token_info->offset < 0) || (token_info->offset >= ( max_token_length-1)))
+  register int
+    i;
+
+  if ((token_info->offset < 0) || (token_info->offset >= (max_token_length-1)))
     return;
+  i=token_info->offset++;
+  string[i]=c;
   if (token_info->state == IN_QUOTE)
-    string[token_info->offset]=c;
-  else
-    switch (token_info->flag & 0x03)
+    return;
+  switch (token_info->flag & 0x03)
+  {
+    case 1:
     {
-      case 1:
-      {
-        string[token_info->offset]=toupper(c);
-        break;
-      }
-      case 2:
-      {
-        string[token_info->offset]=tolower(c);
-        break;
-      }
-      default:
-      {
-        string[token_info->offset]=c;
-        break;
-      }
+      string[i]=toupper(c);
+      break;
     }
-  token_info->offset++;
-  return;
+    case 2:
+    {
+      string[i]=tolower(c);
+      break;
+    }
+    default:
+      break;
+  }
 }
 
 MagickExport int Tokenizer(TokenInfo *token_info,unsigned flag,char *token,
@@ -2707,8 +2746,7 @@ MagickExport int Tokenizer(TokenInfo *token_info,unsigned flag,char *token,
   char escape,char *breaker,int *next,char *quoted)
 {
   char
-    c,
-    nc;
+    c;
 
   register int
     i;
@@ -2720,8 +2758,9 @@ MagickExport int Tokenizer(TokenInfo *token_info,unsigned flag,char *token,
   token_info->state=IN_WHITE;
   token_info->quote=False;
   token_info->flag=flag;
-  for (token_info->offset=0; (c=line[*next]) != 0; (*next)++)
+  for (token_info->offset=0; line[*next] != 0; (*next)++)
   {
+    c=line[*next];
     i=sindex(c,break_set);
     if (i >= 0)
       {
@@ -2800,8 +2839,7 @@ MagickExport int Tokenizer(TokenInfo *token_info,unsigned flag,char *token,
       }
     if (c == escape)
       {
-        nc=line[(*next)+1];
-        if (nc == 0)
+        if (line[(*next)+1] == 0)
           {
             *breaker=0;
             StoreToken(token_info,token,max_token_length,c);
@@ -2821,7 +2859,8 @@ MagickExport int Tokenizer(TokenInfo *token_info,unsigned flag,char *token,
           case IN_QUOTE:
           {
             (*next)++;
-            StoreToken(token_info,token,max_token_length,nc);
+            c=line[*next];
+            StoreToken(token_info,token,max_token_length,c);
             break;
           }
           case IN_OZONE:
@@ -2925,7 +2964,7 @@ MagickExport char *TranslateText(const ImageInfo *image_info,Image *image,
             Read text from a file.
           */
           length=MaxTextExtent;
-          text=(char *) AcquireMemory(length);
+          text=AllocateString((char *) NULL);
           for (q=text; text != (char *) NULL; q++)
           {
             c=fgetc(file);
@@ -2949,21 +2988,12 @@ MagickExport char *TranslateText(const ImageInfo *image_info,Image *image,
           *q='\0';
         }
     }
-  /*
-    Allocate and initialize image text.
-  */
-  length=Extent(text)+MaxTextExtent;
-  translated_text=(char *) AcquireMemory(length);
-  if (translated_text == (char *) NULL)
-    MagickError(ResourceLimitError,"Unable to translate text",
-      "Memory allocation failed");
-  clone_info=CloneImageInfo(image_info);
-  if ((clone_info == (ImageInfo *) NULL))
-    MagickError(ResourceLimitError,"Unable to translate text",
-      "Memory allocation failed");
   /*
     Translate any embedded format characters.
   */
+  length=Extent(text)+MaxTextExtent;
+  translated_text=AllocateString(text);
+  clone_info=CloneImageInfo(image_info);
   p=text;
   for (q=translated_text; *p != '\0'; p++)
   {
@@ -3180,6 +3210,9 @@ MagickExport char *TranslateText(const ImageInfo *image_info,Image *image,
         char
           key[MaxTextExtent];
 
+        int
+          offset;
+
         ImageAttribute
           *attribute;
 
@@ -3192,18 +3225,33 @@ MagickExport char *TranslateText(const ImageInfo *image_info,Image *image,
         attribute=GetImageAttribute(image,key);
         if (attribute != (ImageAttribute *) NULL)
           {
-            (void) strcpy(q,attribute->value);
-            q+=Extent(attribute->value);
-          }
-        else
-          {
-            attribute=GetImageInfoAttribute(clone_info,image,key);
-            if (attribute != (ImageAttribute *) NULL)
+            offset=Extent(attribute->value);
+            if ((q-translated_text+offset) >= (int) length)
               {
-                (void) strcpy(q,attribute->value);
-                q+=Extent(attribute->value);
+                length+=(offset+MaxTextExtent);
+                ReacquireMemory((void **) &translated_text,length);
+                if (translated_text == (char *) NULL)
+                  break;
+                q=translated_text+Extent(translated_text);
               }
+            (void) strcpy(q,attribute->value);
+            q+=offset;
+            break;
           }
+        attribute=GetImageInfoAttribute(clone_info,image,key);
+        if (attribute == (ImageAttribute *) NULL)
+          break;
+        offset=Extent(attribute->value);
+        if ((q-translated_text+offset) >= (int) length)
+          {
+            length+=(offset+MaxTextExtent);
+            ReacquireMemory((void **) &translated_text,length);
+            if (translated_text == (char *) NULL)
+              break;
+            q=translated_text+Extent(translated_text);
+          }
+        (void) strcpy(q,attribute->value);
+        q+=offset;
         break;
       }
       case '%':
