@@ -9,11 +9,9 @@
 %               C      O   O  N  NN   V V   E      R R      T                 %
 %                CCCC   OOO   N   N    V    EEEEE  R  R     T                 %
 %                                                                             %
-%                                                                             %
 %                Convert an image from one format to another.                 %
 %                                                                             %
 %                                                                             %
-%                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                April 1992                                   %
@@ -60,12 +58,12 @@
 %    -antialias           remove pixel-aliasing
 %    -append              append an image sequence
 %    -average             average an image sequence
-%    -blur order          apply a filter to blur the image
+%    -blur geometry       blur the image
 %    -border geometry     surround image with a border of color
 %    -bordercolor color   border color
 %    -box color           color for annotation bounding box
 %    -cache threshold     number of megabytes available to the pixel cache
-%    -charcoal order      simulate a charcoal drawing
+%    -charcoal radius     simulate a charcoal drawing
 %    -coalesce            merge a sequence of images
 %    -colorize value      colorize the image with the fill color
 %    -colors value        preferred number of colors in the image
@@ -84,8 +82,8 @@
 %    -dispose method      GIF disposal method
 %    -dither              apply Floyd/Steinberg error diffusion to image
 %    -draw string         annotate the image with a graphic primitive
-%    -edge order          apply a filter to detect edges in the image
-%    -emboss order        emboss an image
+%    -edge radius         apply a filter to detect edges in the image
+%    -emboss radius       emboss an image
 %    -enhance             apply a digital filter to enhance a noisy image
 %    -equalize            perform histogram equalization to an image
 %    -fill color          color to use when filling a graphic primitive
@@ -96,7 +94,7 @@
 %    -frame geometry      surround image with an ornamental border
 %    -fuzz distance       colors within this distance are considered equal
 %    -gamma value         level of gamma correction
-%    -gaussian geometry   gaussian blur an image
+%    -gaussian geometry   blur the image
 %    -geometry geometry   perferred size or location of the image
 %    -gravity type        vertical and horizontal text placement
 %    -implode amount      implode image pixels about the center
@@ -108,7 +106,7 @@
 %    -loop iterations     add Netscape loop extension to your GIF animation
 %    -map filename        transform image colors to match this set of colors
 %    -matte               store matte channel if the image has one
-%    -median order        apply a median filter to the image
+%    -median radius       apply a median filter to the image
 %    -modulate value      vary the brightness, saturation and hue
 %    -monochrome          transform image to black and white
 %    -morph value         morph an image sequence
@@ -134,7 +132,7 @@
 %    -seed value          pseudo-random number generator seed value
 %    -segment values      segment an image
 %    -shade degrees       shade the image using a distant light source
-%    -sharpen order       apply a filter to sharpen the image
+%    -sharpen geometry    sharpen the image
 %    -shear geometry      slide one edge of the image along the X or Y axis
 %    -size geometry       width and height of image
 %    -solarize threshold  negate all pixels above the threshold level
@@ -143,6 +141,7 @@
 %    -swirl degrees       swirl image pixels about the center
 %    -texture filename    name of texture to tile onto the image background
 %    -threshold value     threshold the image
+%    -tile filename       tile image when filling a graphic primitive
 %    -transparent color   make this color transparent within the image
 %    -treedepth value     depth of the color color tree
 %    -units type          PixelsPerInch, PixelsPerCentimeter, or Undefined
@@ -257,12 +256,12 @@ static void Usage()
       "-antialias           remove pixel-aliasing",
       "-append              append an image sequence",
       "-average             average an image sequence",
-      "-blur order          apply a filter to blur the image",
+      "-blur geometry       blur the image",
       "-border geometry     surround image with a border of color",
       "-bordercolor color   border color",
       "-box color           color for annotation bounding box",
       "-cache threshold     megabytes of memory available to the pixel cache",
-      "-charcoal order      simulate a charcoal drawing",
+      "-charcoal radius     simulate a charcoal drawing",
       "-coalesce            merge a sequence of images",
       "-colorize value      colorize the image with the fill color",
       "-colors value        preferred number of colors in the image",
@@ -281,8 +280,8 @@ static void Usage()
       "-dispose method      GIF disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-draw string         annotate the image with a graphic primitive",
-      "-edge order          apply a filter to detect edges in the image",
-      "-emboss order        emboss an image",
+      "-edge radius         apply a filter to detect edges in the image",
+      "-emboss radius       emboss an image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
       "-fill color          color to use when filling a graphic primitive",
@@ -306,7 +305,7 @@ static void Usage()
       "-loop iterations     add Netscape loop extension to your GIF animation",
       "-map filename        transform image colors to match this set of colors",
       "-matte               store matte channel if the image has one",
-      "-median order        apply a median filter to the image",
+      "-median radius       apply a median filter to the image",
       "-modulate value      vary the brightness, saturation, and hue",
       "-monochrome          transform image to black and white",
       "-morph value         morph an image sequence",
@@ -332,7 +331,7 @@ static void Usage()
       "-segment values      segment an image",
       "-seed value          pseudo-random number generator seed value",
       "-shade degrees       shade the image using a distant light source",
-      "-sharpen order       apply a filter to sharpen the image",
+      "-sharpen geometry    sharpen the image",
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-size geometry       width and height of image",
       "-solarize threshold  negate all pixels above the threshold level",
@@ -341,6 +340,7 @@ static void Usage()
       "-swirl degrees       swirl image pixels about the center",
       "-texture filename    name of texture to tile onto the image background",
       "-threshold value     threshold the image",
+      "-tile filename       tile image when filling a graphic primitive",
       "-transparent color   make this color transparent within the image",
       "-treedepth value     depth of the color color tree",
       "-units type          Inch, Centimeter, or Undefined",
@@ -491,8 +491,8 @@ int main(int argc,char **argv)
         next_image=ReadImage(image_info,&exception);
         if (next_image == (Image *) NULL)
           {
-            MagickWarning(exception.severity,exception.message,
-              exception.qualifier);
+            MagickWarning(exception.severity,exception.reason,
+              exception.description);
             continue;
           }
         status=MogrifyImages(image_info,i,argv,&next_image);
@@ -511,7 +511,7 @@ int main(int argc,char **argv)
           }
       }
     else
-      switch(*(option+1))
+      switch (*(option+1))
       {
         case 'a':
         {
@@ -562,14 +562,11 @@ int main(int argc,char **argv)
                 }
               break;
             }
-          if (LocaleNCompare("blur",option+1,3) == 0)
+          if (LocaleCompare("blur",option+1) == 0)
             {
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
-                }
+              i++;
+              if ((i == argc) || !sscanf(argv[i],"%d",&x))
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("border",option+1,7) == 0)
@@ -625,7 +622,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -656,7 +653,7 @@ int main(int argc,char **argv)
             }
           if (LocaleNCompare("colorspace",option+1,7) == 0)
             {
-              if (*option == '-')
+              if ((*option == '-') || (*option == '+'))
                 {
                   i++;
                   if (i == argc)
@@ -853,7 +850,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -863,7 +860,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -997,7 +994,7 @@ int main(int argc,char **argv)
             {
               i++;
               if ((i == argc) || !sscanf(argv[i],"%d",&x))
-                MagickError(OptionError,"Missing width",option);
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("geometry",option+1,2) == 0)
@@ -1573,12 +1570,9 @@ int main(int argc,char **argv)
             }
           if (LocaleNCompare("sharpen",option+1,5) == 0)
             {
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
-                }
+              i++;
+              if ((i == argc) || !sscanf(argv[i],"%d",&x))
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("shear",option+1,3) == 0)
@@ -1672,6 +1666,13 @@ int main(int argc,char **argv)
                 }
               break;
             }
+          if (LocaleNCompare("tile",option+1,4) == 0)
+            {
+              i++;
+              if (i == argc)
+                MagickError(OptionError,"Missing tile",option);
+              break;
+            }
           if (LocaleNCompare("transparent",option+1,7) == 0)
             {
               if (*option == '-')
@@ -1759,7 +1760,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode != UndefinedTransmitType))
                 MagickError(OptionError,"Missing blob buffer",option);
               param1=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=BlobTransmitType;
               break;
             }
@@ -1769,7 +1770,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode != UndefinedTransmitType))
                 MagickError(OptionError,"Missing blob length",option);
               param2=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=BlobTransmitType;
               break;
             }
@@ -1779,7 +1780,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode != UndefinedTransmitType))
                 MagickError(OptionError,"Missing stream method",option);
               param1=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=StreamTransmitType;
               break;
             }
@@ -1789,7 +1790,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode != UndefinedTransmitType))
                 MagickError(OptionError,"Missing stream context",option);
               param2=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=StreamTransmitType;
               break;
             }
@@ -1799,7 +1800,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode>0))
                 MagickError(OptionError,"Missing image info",option);
               param1=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=ImageTransmitType;
               break;
             }
@@ -1809,7 +1810,7 @@ int main(int argc,char **argv)
               if ((i == argc) && (sendmode != UndefinedTransmitType))
                 MagickError(OptionError,"Missing image",option);
               param2=(void *) argv[i];
-              argv[i]=AllocateString("");
+              argv[i]=AllocateString((char *) NULL);
               sendmode=ImageTransmitType;
               break;
             }
