@@ -57,12 +57,12 @@
 %  Where options include:
 %    -affine matrix       drawing transform matrix
 %    -antialias           remove pixel-aliasing
-%    -blur order          apply a filter to blur the image
+%    -blur geometry       blur the image
 %    -border geometry     surround image with a border of color
 %    -bordercolor color   border color
 %    -box color           color for annotation bounding box
 %    -cache threshold     megabytes of memory available to the pixel cache
-%    -charcoal order      simulate a charcoal drawing
+%    -charcoal radius     simulate a charcoal drawing
 %    -colorize value      colorize the image with the fill color
 %    -colors value        preferred number of colors in the image
 %    -colorspace type     alternate image colorspace
@@ -79,8 +79,8 @@
 %    -dispose method      GIF disposal method
 %    -dither              apply Floyd/Steinberg error diffusion to image
 %    -draw string         annotate the image with a graphic primitive
-%    -edge order          apply a filter to detect edges in the image
-%    -emboss order        emboss an image
+%    -edge radius         apply a filter to detect edges in the image
+%    -emboss radius       emboss an image
 %    -enhance             apply a digital filter to enhance a noisy image
 %    -equalize            perform histogram equalization to an image
 %    -fill color          color to use when filling a graphic primitive
@@ -92,7 +92,7 @@
 %    -frame geometry      surround image with an ornamental border
 %    -fuzz distance       colors within this distance are considered equal
 %    -gamma value         level of gamma correction
-%    -gaussian geometry   gaussian blur an image
+%    -gaussian geometry   blur an image
 %    -geometry geometry   perferred size or location of the image
 %    -implode amount      implode image pixels about the center
 %    -interlace type      None, Line, Plane, or Partition
@@ -102,7 +102,7 @@
 %    -loop iterations     add Netscape loop extension to your GIF animation
 %    -map filename        transform image colors to match this set of colors
 %    -matte               store matte channel if the image has one
-%    -median order        apply a median filter to the image
+%    -median radius       apply a median filter to the image
 %    -modulate value      vary the brightness, saturation, and hue
 %    -monochrome          transform image to black and white
 %    -negate              replace every pixel with its complementary color 
@@ -123,7 +123,7 @@
 %    -seed value          pseudo-random number generator seed value
 %    -segment values      segment an image
 %    -shade degrees       shade the image using a distant light source
-%    -sharpen order       apply a filter to sharpen the image
+%    -sharpen geometry    sharpen the image
 %    -shear geometry      slide one edge of the image along the X or Y axis
 %    -size geometry       width and height of image
 %    -solarize threshold  negate all pixels above the threshold level
@@ -132,6 +132,7 @@
 %    -swirl degrees       swirl image pixels about the center
 %    -texture filename    name of texture to tile onto the image background
 %    -threshold value     threshold the image
+%    -tile filename       tile image when filling a graphic primitive
 %    -transparent color   make this color transparent within the image
 %    -treedepth value     depth of the color color tree
 %    -units type          PixelsPerInch, PixelsPerCentimeter, or Undefined
@@ -183,12 +184,12 @@ static void Usage()
     {
       "-affine matrix       drawing transform matrix",
       "-antialias           remove pixel-aliasing",
-      "-blur order          apply a filter to blur the image",
+      "-blur radius         blur the image",
       "-border geometry     surround image with a border of color",
       "-bordercolor color   border color",
       "-box color           color for annotation bounding box",
       "-cache threshold     megabytes of memory available to the pixel cache",
-      "-charcoal order      simulate a charcoal drawing",
+      "-charcoal radius     simulate a charcoal drawing",
       "-colorize value      colorize the image with the fill color",
       "-colors value        preferred number of colors in the image",
       "-colorspace type     alternate image colorspace",
@@ -205,8 +206,8 @@ static void Usage()
       "-dispose method      GIF disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-draw string         annotate the image with a graphic primitive",
-      "-edge order          apply a filter to detect edges in the image",
-      "-emboss order        emboss an image",
+      "-edge radius          apply a filter to detect edges in the image",
+      "-emboss radius       emboss an image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
       "-fill color          color to use when filling a graphic primitive",
@@ -228,7 +229,7 @@ static void Usage()
       "-loop iterations     add Netscape loop extension to your GIF animation",
       "-map filename        transform image colors to match this set of colors",
       "-matte               store matte channel if the image has one",
-      "-median order        apply a median filter to the image",
+      "-median radius       apply a median filter to the image",
       "-modulate value      vary the brightness, saturation, and hue",
       "-monochrome          transform image to black and white",
       "-negate              replace every pixel with its complementary color ",
@@ -250,7 +251,7 @@ static void Usage()
       "-seed value          pseudo-random number generator seed value",
       "-segment values      segment an image",
       "-shade degrees       shade the image using a distant light source",
-      "-sharpen order       apply a filter to sharpen the image",
+      "-sharpen radius      sharpen the image",
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-size geometry       width and height of image",
       "-solarize threshold  negate all pixels above the threshold level",
@@ -259,6 +260,7 @@ static void Usage()
       "-swirl degrees       swirl image pixels about the center",
       "-texture filename    name of texture to tile onto the image background",
       "-threshold value     threshold the image",
+      "-tile filename       tile image when filling a graphic primitive",
       "-transparent color   make this color transparent within the image",
       "-treedepth value     depth of the color color tree",
       "-units type          PixelsPerInch, PixelsPerCentimeter, or Undefined",
@@ -399,14 +401,11 @@ int main(int argc,char **argv)
                 }
               break;
             }
-          if (LocaleNCompare("blur",option+1,3) == 0)
+          if (LocaleCompare("blur",option+1) == 0)
             {
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
-                }
+              i++;
+              if ((i == argc) || !sscanf(argv[i],"%d",&x))
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("border",option+1,7) == 0)
@@ -462,7 +461,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -680,7 +679,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -690,7 +689,7 @@ int main(int argc,char **argv)
                 {
                   i++;
                   if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
+                    MagickError(OptionError,"Missing radius",option);
                 }
               break;
             }
@@ -833,7 +832,7 @@ int main(int argc,char **argv)
             {
               i++;
               if ((i == argc) || !sscanf(argv[i],"%d",&x))
-                MagickError(OptionError,"Missing width",option);
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("geometry",option+1,2) == 0)
@@ -1030,6 +1029,16 @@ int main(int argc,char **argv)
                 }
               break;
             }
+          if (LocaleNCompare("median",option+1,3) == 0)
+            {
+              if (*option == '-')
+                {
+                  i++;
+                  if ((i == argc) || !sscanf(argv[i],"%d",&x))
+                    MagickError(OptionError,"Missing radius",option);
+                }
+              break;
+            }
           if (LocaleNCompare("monochrome",option+1,4) == 0)
             {
               image_info->monochrome=(*option == '-');
@@ -1262,12 +1271,9 @@ int main(int argc,char **argv)
             }
           if (LocaleNCompare("sharpen",option+1,5) == 0)
             {
-              if (*option == '-')
-                {
-                  i++;
-                  if ((i == argc) || !sscanf(argv[i],"%lf",&sans))
-                    MagickError(OptionError,"Missing order",option);
-                }
+              i++;
+              if ((i == argc) || !sscanf(argv[i],"%d",&x))
+                MagickError(OptionError,"Missing geometry",option);
               break;
             }
           if (LocaleNCompare("shear",option+1,3) == 0)
@@ -1361,6 +1367,13 @@ int main(int argc,char **argv)
                 }
               break;
             }
+          if (LocaleNCompare("tile",option+1,4) == 0)
+            {
+              i++;
+              if (i == argc)
+                MagickError(OptionError,"Missing tile",option);
+              break;
+            }
           if (LocaleNCompare("transparent",option+1,7) == 0)
             {
               if (*option == '-')
@@ -1460,8 +1473,8 @@ int main(int argc,char **argv)
         image=ReadImage(image_info,&exception);
         if (image == (Image *) NULL)
           {
-            MagickWarning(exception.severity,exception.message,
-              exception.qualifier);
+            MagickWarning(exception.severity,exception.reason,
+              exception.description);
             continue;
           }
         if (scene != 0)
